{%- if "AEPg" in api %}
# Endpoint Groups
{%-     for epg in data_to_template['imdata'] %}
## Name: {{ epg.fvAEPg.attributes.name }}
### Alias: {{ epg.fvAEPg.attributes.nameAlias }}
### Description: {{ epg.fvAEPg.attributes.descr }}
### Status: {{ epg.fvAEPg.attributes.status }}
### DN: {{ epg.fvAEPg.attributes.dn }}
### UID: {{ epg.fvAEPg.attributes.uid }}
### Annotation: {{ epg.fvAEPg.attributes.annotation }}
### Child Action: {{ epg.fvAEPg.attributes.childAction }}
### Externally Managed By: {{ epg.fvAEPg.attributes.extMngdBy }}
### Local Owner: {{ epg.fvAEPg.attributes.lcOwn }}
### Monitoring Policy DN: {{ epg.fvAEPg.attributes.monPolDn }}
### User Domain: {{ epg.fvAEPg.attributes.userdom }}
### Configuration
#### Issues: {{ epg.fvAEPg.attributes.configIssues }}
#### State: {{ epg.fvAEPg.attributes.configSt }}
### Exception Tag: {{ epg.fvAEPg.attributes.exceptionTag }}
### Flood On Encapsulation: {{ epg.fvAEPg.attributes.floodOnEncap }}
### Forward Control: {{ epg.fvAEPg.attributes.fwdCtrl }}
### Has Multicast Source: {{ epg.fvAEPg.attributes.hasMcastSource }}
### Is Attribute Based EPG: {{ epg.fvAEPg.attributes.isAttrBasedEPg }}
### Is Shared Service Multicast EPG: {{ epg.fvAEPg.attributes.isSharedSrvMsiteEPg }}
### Match T: {{ epg.fvAEPg.attributes.matchT }}
### PC
#### Enforcement Preference: {{ epg.fvAEPg.attributes.pcEnfPref }}
#### Tag: {{ epg.fvAEPg.attributes.pcTag }}
#### Tag Allocation Source: {{ epg.fvAEPg.attributes.pcTagAllocSrc }}
### Preference Gr Member: {{ epg.fvAEPg.attributes.prefGrMemb }}
### Priority: {{ epg.fvAEPg.attributes.prio }}
### Scope: {{ epg.fvAEPg.attributes.scope }}
### Shutdown: {{ epg.fvAEPg.attributes.shutdown }}
### Trigger State: {{ epg.fvAEPg.attributes.triggerSt }}
### TX ID: {{ epg.fvAEPg.attributes.txId }}
### Modified Timestamp: {{ epg.fvAEPg.attributes.modTs }}
{%-     endfor %}
{%- elif "fvBD" in api %}
# Bridge Domains
{%-     for bd in data_to_template['imdata'] %}
## {{ bd.fvBD.attributes.name }}
### Alias: {{ bd.fvBD.attributes.nameAlias }}
### Description: {{ bd.fvBD.attributes.descr }}
### Status: {{ bd.fvBD.attributes.status }}
### DN: {{ bd.fvBD.attributes.dn }}
### UID: {{ bd.fvBD.attributes.uid }}
### Annotation: {{ bd.fvBD.attributes.annotation }}
### Child Action: {{ bd.fvBD.attributes.childAction }}
### Externally Managed By: {{ bd.fvBD.attributes.extMngdBy }}
### Local Owner: {{ bd.fvBD.attributes.lcOwn }}
### Monitoring Policy DN: {{ bd.fvBD.attributes.monPolDn }}
### User Domain: {{ bd.fvBD.attributes.userdom }}
### Configuration Issues: {{ bd.fvBD.attributes.configIssues }}
### Optimize WAN Bandwidth: {{ bd.fvBD.attributes.OptimizeWanBandwidth }}
### ARP Flood: {{ bd.fvBD.attributes.arpFlood }}
### Broadcast P: {{ bd.fvBD.attributes.bcastP }}
### EP
#### Clear: {{ bd.fvBD.attributes.epClear }}
#### Move Detect Mode: {{ bd.fvBD.attributes.epMoveDetectMode }}
### Host Based Routing: {{ bd.fvBD.attributes.hostBasedRouting }}
### Intersite
#### BUM Traffic Allow: {{ bd.fvBD.attributes.intersiteBumTrafficAllow }}
#### L2 Stretch: {{ bd.fvBD.attributes.intersiteL2Stretch }}
### IP Learning: {{ bd.fvBD.attributes.ipLearning }}
### Limit IP Learn To Subnets: {{ bd.fvBD.attributes.limitIpLearnToSubnets }}
### Link Layer Address: {{ bd.fvBD.attributes.llAddr }}
### MAC: {{ bd.fvBD.attributes.mac }}
### Multicast
#### Allow: {{ bd.fvBD.attributes.mcastAllow }}
#### Destination Packet Allow: {{ bd.fvBD.attributes.multiDstPktAct }}
#### Unknown Action: {{ bd.fvBD.attributes.unkMcastAct }}
#### IPv6
##### Allow: {{ bd.fvBD.attributes.ipv6McastAllow }}
##### Unknown Action: {{ bd.fvBD.attributes.v6unkMcastAct }}
### MTU: {{ bd.fvBD.attributes.mtu }}
### Owner
#### Key: {{ bd.fvBD.attributes.ownerKey }}
#### Tag: {{ bd.fvBD.attributes.ownerTag }}
### PC Tag: {{ bd.fvBD.attributes.pcTag }}
### Scope: {{ bd.fvBD.attributes.scope }}
### Segment: {{ bd.fvBD.attributes.seg }}
### Type: {{ bd.fvBD.attributes.type }}
### Unicast Route: {{ bd.fvBD.attributes.unicastRoute }}
### Unknown MAC Unicast Action: {{ bd.fvBD.attributes.unkMacUcastAct }}
### Virtual MAC: {{ bd.fvBD.attributes.vmac }}
### Modified Timestamp: {{ bd.fvBD.attributes.modTs }}
{%-     endfor %}
{%- elif "fvCtx" in api %}
# Contexts
{%-     for context in data_to_template['imdata'] %}
## {{ context.fvCtx.attributes.name }}
### Alias: {{ context.fvCtx.attributes.nameAlias }}
### Description: {{ context.fvCtx.attributes.descr }}
### Status: {{ context.fvCtx.attributes.status }}
### DN: {{ context.fvCtx.attributes.dn }}
### UID: {{ context.fvCtx.attributes.uid }}
### Annotation: {{ context.fvCtx.attributes.annotation }}
### Child Action: {{ context.fvCtx.attributes.childAction }}
### Externally Managed By: {{ context.fvCtx.attributes.extMngdBy }}
### Local Owner: {{ context.fvCtx.attributes.lcOwn }}
### Monitoring Policy DN: {{ context.fvCtx.attributes.monPolDn }}
### User Domain: {{ context.fvCtx.attributes.userdom }}
### Bridge Domain Enforced Enable: {{ context.fvCtx.attributes.bdEnforcedEnable }}
### IP Data Plane Learning: {{ context.fvCtx.attributes.ipDataPlaneLearning }}
### Known Multicast Action: {{ context.fvCtx.attributes.knwMcastAct }}
### Owner
#### Key: {{ context.fvCtx.attributes.ownerKey }}
#### Tag: {{ context.fvCtx.attributes.ownerTag }}
### PC 
#### Enforce Directory
##### {{ context.fvCtx.attributes.pcEnfDir }}
##### Updated: {{ context.fvCtx.attributes.pcEnfDirUpdated }}
#### Enforce Preference: {{ context.fvCtx.attributes.pcEnfPref }}
#### Tag: {{ context.fvCtx.attributes.pcTag }}
### Scope: {{ context.fvCtx.attributes.scope }}
### Segment: {{ context.fvCtx.attributes.seg }}
### VRF
#### ID: {{ context.fvCtx.attributes.vrfId }}
#### Index: {{ context.fvCtx.attributes.vrfIndex }}
### Modified Timestamp: {{ context.fvCtx.attributes.modTs }}
{%-     endfor %}
{%- elif "Ap" in api %}
# Application Profiles
{%-     for application_profile in data_to_template['imdata'] %}
## {{ application_profile.fvAp.attributes.name }}
### Alias: {{ application_profile.fvAp.attributes.nameAlias }}
### Description: {{ application_profile.fvAp.attributes.descr }}
### Status: {{ application_profile.fvAp.attributes.status }}
### DN: {{ application_profile.fvAp.attributes.dn }}
### UID: {{ application_profile.fvAp.attributes.uid }}
### Annotation: {{ application_profile.fvAp.attributes.annotation }}
### Child Action: {{ application_profile.fvAp.attributes.childAction }}
### Externally Managed By: {{ application_profile.fvAp.attributes.extMngdBy }}
### Local Owner: {{ application_profile.fvAp.attributes.lcOwn }}
### Monitoring Policy DN: {{ application_profile.fvAp.attributes.monPolDn }}
### User Domain: {{ application_profile.fvAp.attributes.userdom }}
### Owner
#### Key: {{ application_profile.fvAp.attributes.ownerKey }}
#### Tag: {{ application_profile.fvAp.attributes.ownerTag }}
### Priority: {{ application_profile.fvAp.attributes.prio }}
### Modified Timestamp: {{ application_profile.fvAp.attributes.modTs }}
{%-     endfor %}
{%- elif "l3extOut" in api %}
# L3Outs
{%-     for l3out in data_to_template['imdata'] %}
## {{ l3out.l3extOut.attributes.name }}
### Alias: {{ l3out.l3extOut.attributes.nameAlias }}
### Description: {{ l3out.l3extOut.attributes.descr }}
### Status: {{ l3out.l3extOut.attributes.status }}
### DN: {{ l3out.l3extOut.attributes.dn }}
### UID: {{ l3out.l3extOut.attributes.uid }}
### Annotation: {{ l3out.l3extOut.attributes.annotation }}
### Child Action: {{ l3out.l3extOut.attributes.childAction }}
### Externally Managed By: {{ l3out.l3extOut.attributes.extMngdBy }}
### Local Owner: {{ l3out.l3extOut.attributes.lcOwn }}
### Monitoring Policy DN: {{ l3out.l3extOut.attributes.monPolDn }}
### User Domain: {{ l3out.l3extOut.attributes.userdom }}
### Owner
#### Key: {{ l3out.l3extOut.attributes.ownerKey }}
#### Tag: {{ l3out.l3extOut.attributes.ownerTag }}
### Priority: {{ l3out.l3extOut.attributes.prio }}
### Enforce Route Control: {{ l3out.l3extOut.attributes.enforceRtctrl }}
### Target DSCP: {{ l3out.l3extOut.attributes.targetDscp }}
### Modified Timestamp: {{ l3out.l3extOut.attributes.modTs }}
{%-     endfor %}
{%- elif "l2extOut" in api %}
# L2Outs
{%-     for l2out in data_to_template['imdata'] %}
## Name: {{ l2out.l2extOut.attributes.name }}
### Name Alias: {{ l2out.l2extOut.attributes.nameAlias }}
### Annotation: {{ l2out.l2extOut.attributes.annotation }}
### Child Action: {{ l2out.l2extOut.attributes.childAction }}
### Description: {{ l2out.l2extOut.attributes.descr }}
### DN: {{ l2out.l2extOut.attributes.dn }}
### Externally Managed By: {{ l2out.l2extOut.attributes.extMngdBy }}
### LC Owner: {{ l2out.l2extOut.attributes.lcOwn }}
### Last Modified: {{ l2out.l2extOut.attributes.modTs }}
### Monitoring Policy DN: {{ l2out.l2extOut.attributes.monPolDn }}
### Owner:
#### Key: {{ l2out.l2extOut.attributes.ownerKey }}
#### Tag: {{ l2out.l2extOut.attributes.ownerTag }}
### Status: {{ l2out.l2extOut.attributes.status }}
### Target DSCP: {{ l2out.l2extOut.attributes.targetDscp }}
### UID: {{ l2out.l2extOut.attributes.uid }}
### User Domain: {{ l2out.l2extOut.attributes.userdom }}
{%-     endfor %}
{%- elif "fvSubnet" in api %}
# Subnets
{%-     for subnet in data_to_template['imdata'] %}
## Name: {{ subnet.fvSubnet.attributes.name }}
## Alias: {{ subnet.fvSubnet.attributes.nameAlias }}
## Annotation: {{ subnet.fvSubnet.attributes.annotation }}
## Child Action: {{ subnet.fvSubnet.attributes.childAction }}
## Config Issues: {{ subnet.fvSubnet.attributes.configIssues }}
## Control: {{ subnet.fvSubnet.attributes.ctrl }}
## Debug Message: {{ subnet.fvSubnet.attributes.debugMessage }}
## Description: {{ subnet.fvSubnet.attributes.descr }}
## DN: {{ subnet.fvSubnet.attributes.dn }}
## Externally Managed By: {{ subnet.fvSubnet.attributes.extMngdBy }}
## IP: {{ subnet.fvSubnet.attributes.ip }}
## IP Data Plane Learning: {{ subnet.fvSubnet.attributes.ipDPLearning }}
## LC Owner: {{ subnet.fvSubnet.attributes.lcOwn }}
## Monitoring Policy DN: {{ subnet.fvSubnet.attributes.monPolDn }}
## Preferred: {{ subnet.fvSubnet.attributes.preferred }}
## Scope: {{ subnet.fvSubnet.attributes.scope }}
## Status: {{ subnet.fvSubnet.attributes.status }}
## UID: {{ subnet.fvSubnet.attributes.uid }}
## User Domain: {{ subnet.fvSubnet.attributes.userdom }}
## Virtual: {{ subnet.fvSubnet.attributes.virtual }}
## Last Modified: {{ subnet.fvSubnet.attributes.modTs }}
{%-     endfor %}
{%- elif "fvCEp" in api %}
# Endpoints
{%-     for endpoint in data_to_template['imdata'] %}
## Name: {{ endpoint.fvCEp.attributes.name }}
### Name Alias: {{ endpoint.fvCEp.attributes.nameAlias }}
### MAC: {{ endpoint.fvCEp.attributes.mac }}
### Annotation: {{ endpoint.fvCEp.attributes.annotation }}
### Base EPG DN: {{ endpoint.fvCEp.attributes.baseEpgDn }}
### Bridge Domain DN: {{ endpoint.fvCEp.attributes.bdDn }}
### Child Action: {{ endpoint.fvCEp.attributes.childAction }}
### Container Name: {{ endpoint.fvCEp.attributes.contName }}
### DN: {{ endpoint.fvCEp.attributes.dn }}
### Encapsulation: {{ endpoint.fvCEp.attributes.encap }}
### ESG Use gDN: {{ endpoint.fvCEp.attributes.esgUsegDn }}
### Externally Managed By: {{ endpoint.fvCEp.attributes.extMngdBy }}
### Fabric Path DN: {{ endpoint.fvCEp.attributes.fabricPathDn }}
### ID: {{ endpoint.fvCEp.attributes.id }}
### ID Endpoint DN: {{ endpoint.fvCEp.attributes.idepdn }}
### LCC: {{ endpoint.fvCEp.attributes.lcC }}
### LC Owner: {{ endpoint.fvCEp.attributes.lcOwn }}
### Multicast Address: {{ endpoint.fvCEp.attributes.mcastAddr }}
### Last Modified: {{ endpoint.fvCEp.attributes.modTs }}
### Monitoring Policy DN: {{ endpoint.fvCEp.attributes.monPolDn }}
### Status: {{ endpoint.fvCEp.attributes.status }}
### UID: {{ endpoint.fvCEp.attributes.uid }}
### User Domain: {{ endpoint.fvCEp.attributes.userdom }}
### UUID: {{ endpoint.fvCEp.attributes.uuid }}
### VMM Source: {{ endpoint.fvCEp.attributes.vmmSrc }}
### VRF DN: {{ endpoint.fvCEp.attributes.vrfDn }}
{%-     endfor %}
{%- elif "fabricNode" in api %}
# Fabric Nodes
{%-     for node in data_to_template['imdata'] %}
## Name: {{ node.fabricNode.attributes.name }}
### Name Alias: {{ node.fabricNode.attributes.nameAlias }}
### AD ST: {{ node.fabricNode.attributes.adSt }}
### Address: {{ node.fabricNode.attributes.address }}
### Annotation: {{ node.fabricNode.attributes.annotation }}
### APIC Type: {{ node.fabricNode.attributes.apicType }}
### Child Action: {{ node.fabricNode.attributes.childAction }}
### Delayed Heartbeat: {{ node.fabricNode.attributes.delayedHeartbeat }}
### DN: {{ node.fabricNode.attributes.dn }}
### Externally Managed By: {{ node.fabricNode.attributes.extMngdBy }}
### Fabric State: {{ node.fabricNode.attributes.fabricSt }}
### ID: {{ node.fabricNode.attributes.id }}
### Last State Modified: {{ node.fabricNode.attributes.lastStateModTs }}
### Local Owner: {{ node.fabricNode.attributes.lcOwn }}
### Last Modified: {{ node.fabricNode.attributes.modTs }}
### Model: {{ node.fabricNode.attributes.model }}
### Monitoring Policy DN: {{ node.fabricNode.attributes.monPolDn }}
### Node Type: {{ node.fabricNode.attributes.nodeType }}
### Role: {{ node.fabricNode.attributes.role }}
### Serial: {{ node.fabricNode.attributes.serial }}
### Status: {{ node.fabricNode.attributes.status }}
### UID: {{ node.fabricNode.attributes.uid }}
### User Domain: {{ node.fabricNode.attributes.userdom }}
### Vendor: {{ node.fabricNode.attributes.vendor }}
### Version: {{ node.fabricNode.attributes.version }}
{%-     endfor %}
{%- elif "l1PhysIf" in api %}
# Physical Interfaces
{%-     for outer_list in data_to_template %}
{%-         for interface in outer_list %}
## ID: {{ interface.l1PhysIf.attributes.id }}
### Admin State: {{ interface.l1PhysIf.attributes.adminSt }}
### Auto Negotiate: {{ interface.l1PhysIf.attributes.autoNeg }}
### Breakout Map: {{ interface.l1PhysIf.attributes.brkoutMap }}
### Bandwidth: {{ interface.l1PhysIf.attributes.bw }}
### Child Action: {{ interface.l1PhysIf.attributes.childAction }}
### Delay: {{ interface.l1PhysIf.attributes.delay }}
### Description: {{ interface.l1PhysIf.attributes.descr }}
### DFE Delay MS: {{ interface.l1PhysIf.attributes.dfeDelayMs }}
### DN: {{ interface.l1PhysIf.attributes.dn }}
### Dot1q EtherType: {{ interface.l1PhysIf.attributes.dot1qEtherType }}
### Eth PM Config:
#### Failed Bmp: {{ interface.l1PhysIf.attributes.ethpmCfgFailedBmp }}
#### FailedTimestamp: {{ interface.l1PhysIf.attributes.ethpmCfgFailedTs }}
#### State: {{ interface.l1PhysIf.attributes.ethpmCfgState }}
### FCOT Channel Number: {{ interface.l1PhysIf.attributes.fcotChannelNumber }}
### FEC Mode: {{ interface.l1PhysIf.attributes.fecMode }}
### Inherited Bandwidth: {{ interface.l1PhysIf.attributes.inhBw }}
### Is Reflective Relay Config Supported: {{ interface.l1PhysIf.attributes.isReflectiveRelayCfgSupported }}
### Layer: {{ interface.l1PhysIf.attributes.layer }}
### Local Owner: {{ interface.l1PhysIf.attributes.lcOwn }}
### Link:
#### Debounce: {{ interface.l1PhysIf.attributes.linkDebounce }}
#### Flap Error:
##### Max: {{ interface.l1PhysIf.attributes.linkFlapErrorMax }}
##### Seconds: {{ interface.l1PhysIf.attributes.linkFlapErrorSeconds }}
#### Log: {{ interface.l1PhysIf.attributes.linkLog }}
### MDIX: {{ interface.l1PhysIf.attributes.mdix }}
### Medium: {{ interface.l1PhysIf.attributes.medium }}
### Last Modified: {{ interface.l1PhysIf.attributes.modTs }}
### Mode: {{ interface.l1PhysIf.attributes.mode }}
### Monitoring Policy DN: {{ interface.l1PhysIf.attributes.monPolDn }}
### MTU: {{ interface.l1PhysIf.attributes.mtu }}
### Name: {{ interface.l1PhysIf.attributes.name }}
### Path S Description: {{ interface.l1PhysIf.attributes.pathSDescr }}
### Port Physical Media Type: {{ interface.l1PhysIf.attributes.portPhyMediaType }}
### Port T: {{ interface.l1PhysIf.attributes.portT }}
### Priority Flow Control: {{ interface.l1PhysIf.attributes.prioFlowCtrl }}
### Reflective Relay Enabled: {{ interface.l1PhysIf.attributes.reflectiveRelayEn }}
### Router MAC: {{ interface.l1PhysIf.attributes.routerMac }}
### SNMP Trap State: {{ interface.l1PhysIf.attributes.snmpTrapSt }}
### Span Mode: {{ interface.l1PhysIf.attributes.spanMode }}
### Speed: {{ interface.l1PhysIf.attributes.speed }}
### Status: {{ interface.l1PhysIf.attributes.status }}
### Switching State: {{ interface.l1PhysIf.attributes.switchingSt }}
### Trunk Log: {{ interface.l1PhysIf.attributes.trunkLog }}
### Usage: {{ interface.l1PhysIf.attributes.usage }}
{%-         endfor %}
{%-     endfor %}
{%- elif "infraAccPortP" in api %}
# Leaf Interface Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.infraAccPortP.attributes.name }}
### Name Alias: {{ profile.infraAccPortP.attributes.nameAlias }}
### Annotation: {{ profile.infraAccPortP.attributes.annotation }}
### Child Action: {{ profile.infraAccPortP.attributes.childAction }}
### Description: {{ profile.infraAccPortP.attributes.descr }}
### DN: {{ profile.infraAccPortP.attributes.dn }}
### Externally Managed By: {{ profile.infraAccPortP.attributes.extMngdBy }}
### Local Owner: {{ profile.infraAccPortP.attributes.lcOwn }}
### Last Modified: {{ profile.infraAccPortP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.infraAccPortP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.infraAccPortP.attributes.ownerKey }}
#### Tag: {{ profile.infraAccPortP.attributes.ownerTag }}
### Status: {{ profile.infraAccPortP.attributes.status }}
### UID: {{ profile.infraAccPortP.attributes.uid }}
### User Domain: {{ profile.infraAccPortP.attributes.userdom }}
{%-     endfor %}
{%- elif "infraSpAccPortP" in api %}
# Spine Interface Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.infraSpAccPortP.attributes.name }}
### Name Alias: {{ profile.infraSpAccPortP.attributes.nameAlias }}
### Annotation: {{ profile.infraSpAccPortP.attributes.annotation }}
### Child Action: {{ profile.infraSpAccPortP.attributes.childAction }}
### Description: {{ profile.infraSpAccPortP.attributes.descr }}
### DN: {{ profile.infraSpAccPortP.attributes.dn }}
### Externally Managed By: {{ profile.infraSpAccPortP.attributes.extMngdBy }}
### Local Owner: {{ profile.infraSpAccPortP.attributes.lcOwn }}
### Last Modified: {{ profile.infraSpAccPortP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.infraSpAccPortP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.infraSpAccPortP.attributes.ownerKey }}
#### Tag: {{ profile.infraSpAccPortP.attributes.ownerTag }}
### Status: {{ profile.infraSpAccPortP.attributes.status }}
### UID: {{ profile.infraSpAccPortP.attributes.uid }}
### User Domain: {{ profile.infraSpAccPortP.attributes.userdom }}
{%-     endfor %}
{%- elif "infraNodeP" in api %}
# Leaf Switch Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.infraNodeP.attributes.name }}
### Name Alias: {{ profile.infraNodeP.attributes.nameAlias }}
### Annotation: {{ profile.infraNodeP.attributes.annotation }}
### Child Action: {{ profile.infraNodeP.attributes.childAction }}
### Description: {{ profile.infraNodeP.attributes.descr }}
### DN: {{ profile.infraNodeP.attributes.dn }}
### Externally Managed By: {{ profile.infraNodeP.attributes.extMngdBy }}
### Local Owner: {{ profile.infraNodeP.attributes.lcOwn }}
### Last Modified: {{ profile.infraNodeP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.infraNodeP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.infraNodeP.attributes.ownerKey }}
#### Tag: {{ profile.infraNodeP.attributes.ownerTag }}
### Status: {{ profile.infraNodeP.attributes.status }}
### UID: {{ profile.infraNodeP.attributes.uid }}
### User Domain: {{ profile.infraNodeP.attributes.userdom }}
{%-     endfor %}
{%- elif "infraSpineP" in api %}
# Spine Switch Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.infraSpineP.attributes.name }}
### Name Alias: {{ profile.infraSpineP.attributes.nameAlias }}
### Annotation: {{ profile.infraSpineP.attributes.annotation }}
### Child Action: {{ profile.infraSpineP.attributes.childAction }}
### Description: {{ profile.infraSpineP.attributes.descr }}
### DN: {{ profile.infraSpineP.attributes.dn }}
### Externally Managed By: {{ profile.infraSpineP.attributes.extMngdBy }}
### Local Owner: {{ profile.infraSpineP.attributes.lcOwn }}
### Last Modified: {{ profile.infraSpineP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.infraSpineP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.infraSpineP.attributes.ownerKey }}
#### Tag: {{ profile.infraSpineP.attributes.ownerTag }}
### Status: {{ profile.infraSpineP.attributes.status }}
### UID: {{ profile.infraSpineP.attributes.uid }}
### User Domain: {{ profile.infraSpineP.attributes.userdom }}
{%-     endfor %}
{%- elif "fvnsVlanInstP" in api %}
# VLAN Pools
{%-     for pool in data_to_template['imdata'] %}
## Name: {{ pool.fvnsVlanInstP.attributes.name }}
### Name Alias: {{ pool.fvnsVlanInstP.attributes.nameAlias }}
### Allocation Mode: {{ pool.fvnsVlanInstP.attributes.allocMode }}
### Annotation: {{ pool.fvnsVlanInstP.attributes.annotation }}
### Child Action: {{ pool.fvnsVlanInstP.attributes.childAction }}
### Configuration Issues: {{ pool.fvnsVlanInstP.attributes.configIssues }}
### Description: {{ pool.fvnsVlanInstP.attributes.descr }}
### DN: {{ pool.fvnsVlanInstP.attributes.dn }}
### Externally Managed By: {{ pool.fvnsVlanInstP.attributes.extMngdBy }}
### Local Owner: {{ pool.fvnsVlanInstP.attributes.lcOwn }}
### Last Modified: {{ pool.fvnsVlanInstP.attributes.modTs }}
### Monitoring Policy DN: {{ pool.fvnsVlanInstP.attributes.monPolDn }}
### Owner
#### Key: {{ pool.fvnsVlanInstP.attributes.ownerKey }}
#### Tag: {{ pool.fvnsVlanInstP.attributes.ownerTag }}
### Status: {{ pool.fvnsVlanInstP.attributes.status }}
### UID: {{ pool.fvnsVlanInstP.attributes.uid }}
### User Domain: {{ pool.fvnsVlanInstP.attributes.userdom }}
{%-     endfor %}
{%- elif "infraAttEntityP" in api %}
# Attachable Access Entity Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.infraAttEntityP.attributes.name }}
### Name Alias: {{ profile.infraAttEntityP.attributes.nameAlias }}
### Allocation Mode: {{ profile.infraAttEntityP.attributes.allocMode }}
### Annotation: {{ profile.infraAttEntityP.attributes.annotation }}
### Child Action: {{ profile.infraAttEntityP.attributes.childAction }}
### Configuration Issues: {{ profile.infraAttEntityP.attributes.configIssues }}
### Description: {{ profile.infraAttEntityP.attributes.descr }}
### DN: {{ profile.infraAttEntityP.attributes.dn }}
### Externally Managed By: {{ profile.infraAttEntityP.attributes.extMngdBy }}
### Local Owner: {{ profile.infraAttEntityP.attributes.lcOwn }}
### Last Modified: {{ profile.infraAttEntityP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.infraAttEntityP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.infraAttEntityP.attributes.ownerKey }}
#### Tag: {{ profile.infraAttEntityP.attributes.ownerTag }}
### Status: {{ profile.infraAttEntityP.attributes.status }}
### UID: {{ profile.infraAttEntityP.attributes.uid }}
### User Domain: {{ profile.infraAttEntityP.attributes.userdom }}
{%-     endfor %}
{%- elif "vzBrCP" in api %}
# Contracts
{%-     for contract in data_to_template['imdata'] %}
## Name: {{ contract.vzBrCP.attributes.name }}
### Name Alias: {{ contract.vzBrCP.attributes.nameAlias }}
### Access Privilege: {{ contract.vzBrCP.attributes.accessPrivilege }}
### Annotation: {{ contract.vzBrCP.attributes.annotation }}
### Child Action: {{ contract.vzBrCP.attributes.childAction }}
### Configuration Issues: {{ contract.vzBrCP.attributes.configIssues }}
### Description: {{ contract.vzBrCP.attributes.descr }}
### DN: {{ contract.vzBrCP.attributes.dn }}
### Externally Managed By: {{ contract.vzBrCP.attributes.extMngdBy }}
### Intent: {{ contract.vzBrCP.attributes.intent }}
### Local Owner: {{ contract.vzBrCP.attributes.lcOwn }}
### Last Modified: {{ contract.vzBrCP.attributes.modTs }}
### Monitoring Policy DN: {{ contract.vzBrCP.attributes.monPolDn }}
### Owner
#### Key: {{ contract.vzBrCP.attributes.ownerKey }}
#### Tag: {{ contract.vzBrCP.attributes.ownerTag }}
### Priority: {{ contract.vzBrCP.attributes.prio }}
### Re Evaluate All: {{ contract.vzBrCP.attributes.reevaluateAll }}
### Scope: {{ contract.vzBrCP.attributes.scope }}
### Status: {{ contract.vzBrCP.attributes.status }}
### Targer DSCP: {{ contract.vzBrCP.attributes.targetDscp }}
### UID: {{ contract.vzBrCP.attributes.uid }}
### User Domain: {{ contract.vzBrCP.attributes.userdom }}
{%-     endfor %}
{%- elif "vzEntry" in api %}
# Filters
{%-     for entry in data_to_template['imdata'] %}
## Name: {{ entry.vzEntry.attributes.name }}
### Name Alias: {{ entry.vzEntry.attributes.nameAlias }}
### Access Privilege: {{ entry.vzEntry.attributes.accessPrivilege }}
### Annotation: {{ entry.vzEntry.attributes.annotation }}
### Apply To Fragments: {{ entry.vzEntry.attributes.applyToFrag }}
### ARP OPC: {{ entry.vzEntry.attributes.arpOpc }}
### Child Action: {{ entry.vzEntry.attributes.childAction }}
### Destination
#### From Port: {{ entry.vzEntry.attributes.dFromPort }}
#### To Port: {{ entry.vzEntry.attributes.dToPort }}
### Description: {{ entry.vzEntry.attributes.descr }}
### DN: {{ entry.vzEntry.attributes.dn }}
### EtherType: {{ entry.vzEntry.attributes.etherT }}
### Externally Managed By: {{ entry.vzEntry.attributes.extMngdBy }}
### ICMP
#### v4 T: {{ entry.vzEntry.attributes.icmpv4T }}
#### v6 T: {{ entry.vzEntry.attributes.icmpv6T }}
### Local Owner: {{ entry.vzEntry.attributes.lcOwn }}
### Match DSCP: {{ entry.vzEntry.attributes.matchDscp }}
### Last Modified: {{ entry.vzEntry.attributes.modTs }}
### Monitoring Policy DN: {{ entry.vzEntry.attributes.monPolDn }}
### Protocol: {{ entry.vzEntry.attributes.prot }}
### Source
#### From Port: {{ entry.vzEntry.attributes.sFromPort }}
#### To Port: {{ entry.vzEntry.attributes.sToPort }}
### Stateful: {{ entry.vzEntry.attributes.stateful }}
### Status: {{ entry.vzEntry.attributes.status }}
### TCP Rules: {{ entry.vzEntry.attributes.tcpRules }}
### UID: {{ entry.vzEntry.attributes.uid }}
### User Domain: {{ entry.vzEntry.attributes.userdom }}
{%-     endfor %}
{%- elif "physDomP" in api %}
# Physical Domains
{%-     for domain in data_to_template['imdata'] %}
## Name: {{ domain.physDomP.attributes.name }}
### Name Alias: {{ domain.physDomP.attributes.nameAlias }}
### Annotation: {{ domain.physDomP.attributes.annotation }}
### Child Action: {{ domain.physDomP.attributes.childAction }}
### Configuration Issues: {{ domain.physDomP.attributes.configIssues }}
### DN: {{ domain.physDomP.attributes.dn }}
### Externally Managed By: {{ domain.physDomP.attributes.extMngdBy }}
### Local Owner: {{ domain.physDomP.attributes.lcOwn }}
### Last Modified: {{ domain.physDomP.attributes.modTs }}
### Monitoring Policy DN: {{ domain.physDomP.attributes.monPolDn }}
### Owner
#### Key: {{ domain.physDomP.attributes.ownerKey }}
#### Tag: {{ domain.physDomP.attributes.ownerTag }}
### Status: {{ domain.physDomP.attributes.status }}
### UID: {{ domain.physDomP.attributes.uid }}
### User Domain: {{ domain.physDomP.attributes.userdom }}
{%-     endfor %}
{%- elif "l3extDomP" in api %}
# L3 Domains
{%-     for domain in data_to_template['imdata'] %}
## Name: {{ domain.l3extDomP.attributes.name }}
### Name Alias: {{ domain.l3extDomP.attributes.nameAlias }}
### Annotation: {{ domain.l3extDomP.attributes.annotation }}
### Child Action: {{ domain.l3extDomP.attributes.childAction }}
### Configuration Issues: {{ domain.l3extDomP.attributes.configIssues }}
### DN: {{ domain.l3extDomP.attributes.dn }}
### Externally Managed By: {{ domain.l3extDomP.attributes.extMngdBy }}
### Local Owner: {{ domain.l3extDomP.attributes.lcOwn }}
### Last Modified: {{ domain.l3extDomP.attributes.modTs }}
### Monitoring Policy DN: {{ domain.l3extDomP.attributes.monPolDn }}
### Owner
#### Key: {{ domain.l3extDomP.attributes.ownerKey }}
#### Tag: {{ domain.l3extDomP.attributes.ownerTag }}
### Status: {{ domain.l3extDomP.attributes.status }}
### UID: {{ domain.l3extDomP.attributes.uid }}
### User Domain: {{ domain.l3extDomP.attributes.userdom }}
{%-     endfor %}
{%- elif "qosClass" in api %}
# QOS Classes
{%-     for class in data_to_template['imdata'] %}
## Name: {{ class.qosClass.attributes.name }}
### Name Alias: {{ class.qosClass.attributes.nameAlias }}
### Admin: {{ class.qosClass.attributes.admin }}
### Annotation: {{ class.qosClass.attributes.annotation }}
### Child Action: {{ class.qosClass.attributes.childAction }}
### Description: {{ class.qosClass.attributes.descr }}
### DN: {{ class.qosClass.attributes.dn }}
### Externally Managed By: {{ class.qosClass.attributes.extMngdBy }}
### Local Owner: {{ class.qosClass.attributes.lcOwn }}
### Last Modified: {{ class.qosClass.attributes.modTs }}
### MTU: {{ class.qosClass.attributes.mtu }}
### Owner
#### Key: {{ class.qosClass.attributes.ownerKey }}
#### Tag: {{ class.qosClass.attributes.ownerTag }}
### Priority: {{ class.qosClass.attributes.prio }}
### Status: {{ class.qosClass.attributes.status }}
### UID: {{ class.qosClass.attributes.uid }}
### User Domain: {{ class.qosClass.attributes.userdom }}
{%-     endfor %}
{%- elif "faultSummary" in api %}
# Fault Summary 
{%-     for fault in data_to_template['imdata'] %}
## Cause: {{ fault.faultSummary.attributes.cause }}
### Child Action: {{ fault.faultSummary.attributes.childAction }}
### Code: {{ fault.faultSummary.attributes.code }}
### Count: {{ fault.faultSummary.attributes.count }}
### Description: {{ fault.faultSummary.attributes.descr }}
### DN: {{ fault.faultSummary.attributes.dn }}
### Domain: {{ fault.faultSummary.attributes.domain }}
### Non
#### Acknowledged: {{ fault.faultSummary.attributes.nonAcked }}
#### Delegated: {{ fault.faultSummary.attributes.nonDelegated }}
#### Delagated And Acknowledged: {{ fault.faultSummary.attributes.nonDelegatedAndNonAcked }}
### Rule: {{ fault.faultSummary.attributes.rule }}
### Severity: {{ fault.faultSummary.attributes.severity }}
### Status: {{ fault.faultSummary.attributes.status }}
### Subject: {{ fault.faultSummary.attributes.subject }}
### Type: {{ fault.faultSummary.attributes.type }}
{%-     endfor %}
{%- elif "aaaModLR" in api %}
# Audit Log
{%-     for log in data_to_template['imdata'] %}
## ID: {{ log.aaaModLR.attributes.id }}
### Affected: {{ log.aaaModLR.attributes.affected }}
### Cause: {{ log.aaaModLR.attributes.cause }}
### Change Set: {{ log.aaaModLR.attributes.changeSet }}
### Child Action: {{ log.aaaModLR.attributes.childAction }}
### Client Tag: {{ log.aaaModLR.attributes.clientTag }}
### Code: {{ log.aaaModLR.attributes.code }}
### Created: {{ log.aaaModLR.attributes.created }}
### Description: {{ log.aaaModLR.attributes.descr }}
### DN: {{ log.aaaModLR.attributes.dn }}
### IND: {{ log.aaaModLR.attributes.ind }}
### Last Modified: {{ log.aaaModLR.attributes.modTs }}
### Session ID: {{ log.aaaModLR.attributes.sessionId }}
### Severity: {{ log.aaaModLR.attributes.severity }}
### Status: {{ log.aaaModLR.attributes.status }}
### Trigger: {{ log.aaaModLR.attributes.trig }}
### TX ID: {{ log.aaaModLR.attributes.txId }}
### User: {{ log.aaaModLR.attributes.user }}
{%-     endfor %}
{%- elif "fvIp" in api %}
# IP Addresses
{%-     for ip in data_to_template['imdata'] %}
## {{ ip.fvIp.attributes.addr }}
### Annotation: {{ ip.fvIp.attributes.annotation }}
### Base EPG DN: {{ ip.fvIp.attributes.baseEpgDn }}
### Bridge Domain DN: {{ ip.fvIp.attributes.bdDn }}
### Child Action: {{ ip.fvIp.attributes.childAction }}
### Created: {{ ip.fvIp.attributes.createTs }}
### Debug MAC Message: {{ ip.fvIp.attributes.debugMACMessage }}
### ESG Use gDN: {{ ip.fvIp.attributes.esgUsegDn }}
### Externally Managed By: {{ ip.fvIp.attributes.extMngdBy }}
### Fabric Path DN: {{ ip.fvIp.attributes.fabricPathDn }}
### Flags: {{ ip.fvIp.attributes.flags }}
### Local Owner: {{ ip.fvIp.attributes.lcOwn }}
### Last Modified: {{ ip.fvIp.attributes.modTs }}
### Monitoring Policy DN: {{ ip.fvIp.attributes.monPolDn }}
### DN: {{ ip.fvIp.attributes.dn }}
### Status: {{ ip.fvIp.attributes.status }}
### UID: {{ ip.fvIp.attributes.uid }}
### User Domain: {{ ip.fvIp.attributes.userdom }}
### VRF DN: {{ ip.fvIp.attributes.vrfDn }}
{%-     endfor %}
{%- elif "eventRecord" in api %}
# Events
{%-     for event in data_to_template['imdata'] %}
## ID: {{ event.eventRecord.attributes.id }}
### Affected: {{ event.eventRecord.attributes.affected }}
### Cause: {{ event.eventRecord.attributes.cause }}
### Change Set: {{ event.eventRecord.attributes.changeSet }}
### Child Action: {{ event.eventRecord.attributes.childAction }}
### Code: {{ event.eventRecord.attributes.code }}
### Created: {{ event.eventRecord.attributes.created }}
### Description: {{ event.eventRecord.attributes.descr }}
### DN: {{ event.eventRecord.attributes.dn }}
### IND: {{ event.eventRecord.attributes.ind }}
### Last Modified: {{ event.eventRecord.attributes.modTs }}
### Severity: {{ event.eventRecord.attributes.severity }}
### Status: {{ event.eventRecord.attributes.status }}
### Trigger: {{ event.eventRecord.attributes.trig }}
### TX ID: {{ event.eventRecord.attributes.txId }}
### User: {{ event.eventRecord.attributes.user }}
{%-     endfor %}
{%- elif "licenseEntitlement" in api %}
# License Entitlements
{%-     for license in data_to_template['imdata'] %}
## Name: {{ license.licenseEntitlement.attributes.name }}</th>
### Auth Status: {{ license.licenseEntitlement.attributes.authStatus }}
### Child Action: {{ license.licenseEntitlement.attributes.childAction }}
### Count: {{ license.licenseEntitlement.attributes.count }}
### Description: {{ license.licenseEntitlement.attributes.descr }}
### DN: {{ license.licenseEntitlement.attributes.dn }}
### Local Owner: {{ license.licenseEntitlement.attributes.lcOwn }}
### Last Modified: {{ license.licenseEntitlement.attributes.modTs }}
### Status: {{ license.licenseEntitlement.attributes.status }}
### Tag: {{ license.licenseEntitlement.attributes.tag }}
### Version: {{ license.licenseEntitlement.attributes.version }}
{%-     endfor %}
{%- elif "bgpRRNodePEp" in api %}
# BGP Route Reflectors
{%-     for rr in data_to_template['imdata'] %}
## Name: {{ rr.bgpRRNodePEp.attributes.name }}
### Name Alias: {{ rr.bgpRRNodePEp.attributes.nameAlias }}
### Annotation: {{ rr.bgpRRNodePEp.attributes.annotation }}
### Child Action: {{ rr.bgpRRNodePEp.attributes.childAction }}
### Description: {{ rr.bgpRRNodePEp.attributes.descr }}
### DN: {{ rr.bgpRRNodePEp.attributes.dn }}
### Externally Managed By: {{ rr.bgpRRNodePEp.attributes.extMngdBy }}
### ID: {{ rr.bgpRRNodePEp.attributes.id }}
### Local Owner: {{ rr.bgpRRNodePEp.attributes.lcOwn }}
### Last Modified: {{ rr.bgpRRNodePEp.attributes.modTs }}
### Monitoring Policy DN: {{ rr.bgpRRNodePEp.attributes.monPolDn }}
### POD ID: {{ rr.bgpRRNodePEp.attributes.podId }}
### Status: {{ rr.bgpRRNodePEp.attributes.status }}
### UID: {{ rr.bgpRRNodePEp.attributes.uid }}
### User Domain: {{ rr.bgpRRNodePEp.attributes.userdom }}
{%-     endfor %}
{%- elif "infraPortS" in api %}
# Interface Policies
{%-     for policy in data_to_template['imdata'] %}
{%-         if "infraSHPortS" in policy%}
## Name: {{ policy.infraSHPortS.attributes.name }}
### Name Alias: {{ policy.infraSHPortS.attributes.nameAlias }}
### Annotation: {{ policy.infraSHPortS.attributes.annotation }}
### Child Action: {{ policy.infraSHPortS.attributes.childAction }}
### Description: {{ policy.infraSHPortS.attributes.descr }}
### DN: {{ policy.infraSHPortS.attributes.dn }}
### Externally Managed By: {{ policy.infraSHPortS.attributes.extMngdBy }}
### Loca Owner: {{ policy.infraSHPortS.attributes.lcOwn }}
### Last Modified: {{ policy.infraSHPortS.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraSHPortS.attributes.monPolDn }}
### Owner
#### Key: {{ policy.infraSHPortS.attributes.ownerKey }}
#### Tag: {{ policy.infraSHPortS.attributes.ownerTag }}
### Status: {{ policy.infraSHPortS.attributes.status }}
### Type: {{ policy.infraSHPortS.attributes.type }}
### UID: {{ policy.infraSHPortS.attributes.uid }}
{%-         else %}
## Name: {{ policy.infraHPortS.attributes.name }}
### Name Alias: {{ policy.infraHPortS.attributes.nameAlias }}
### Annotation: {{ policy.infraHPortS.attributes.annotation }}
### Child Action: {{ policy.infraHPortS.attributes.childAction }}
### Description: {{ policy.infraHPortS.attributes.descr }}
### DN: {{ policy.infraHPortS.attributes.dn }}
### Externally Managed By: {{ policy.infraHPortS.attributes.extMngdBy }}
### Local Owner: {{ policy.infraHPortS.attributes.lcOwn }}
### Last Modified: {{ policy.infraHPortS.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraHPortS.attributes.monPolDn }}
### Owner
#### Key: {{ policy.infraHPortS.attributes.ownerKey }}
#### Tag: {{ policy.infraHPortS.attributes.ownerTag }}
### Status: {{ policy.infraHPortS.attributes.status }}
### Type: {{ policy.infraHPortS.attributes.type }}
### UID: {{ policy.infraHPortS.attributes.uid }}
### User Domain: {{ policy.infraHPortS.attributes.userdom }}
{%-         endif %}
{%-     endfor %}
{%- elif "infraProfile" in api %}
# Interface Profiles
{%-     for policy in data_to_template['imdata'] %}
{%-         if policy.infraAccPortP %}
## Name: {{ policy.infraAccPortP.attributes.name }}
### Name Alias: {{ policy.infraAccPortP.attributes.nameAlias }}
### Annotation: {{ policy.infraAccPortP.attributes.annotation }}
### Child Action: {{ policy.infraAccPortP.attributes.childAction }}
### Description: {{ policy.infraAccPortP.attributes.descr }}
### DN: {{ policy.infraAccPortP.attributes.dn }}
### Externally Managed By: {{ policy.infraAccPortP.attributes.extMngdBy }}
### Local Owner: {{ policy.infraAccPortP.attributes.lcOwn }}
### Last Modified: {{ policy.infraAccPortP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraAccPortP.attributes.monPolDn }}
### Owner
#### Key: {{ policy.infraAccPortP.attributes.ownerKey }}
#### Tag: {{ policy.infraAccPortP.attributes.ownerTag }}
### Status: {{ policy.infraAccPortP.attributes.status }}
### Type: {{ policy.infraAccPortP.attributes.type }}
### UID: {{ policy.infraAccPortP.attributes.uid }}
### User Domain: {{ policy.infraAccPortP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraAttEntityP %}
## Name: {{ policy.infraAttEntityP.attributes.name }}
### Name Alias: {{ policy.infraAttEntityP.attributes.nameAlias }}
### Annotation: {{ policy.infraAttEntityP.attributes.annotation }}
### Child Action: {{ policy.infraAttEntityP.attributes.childAction }}
### Description: {{ policy.infraAttEntityP.attributes.descr }}
### DN: {{ policy.infraAttEntityP.attributes.dn }}
### Externally Managed By: {{ policy.infraAttEntityP.attributes.extMngdBy }}
### Local Owner: {{ policy.infraAttEntityP.attributes.lcOwn }}
### Last Modified: {{ policy.infraAttEntityP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraAttEntityP.attributes.monPolDn }}
### Owner
#### Key: {{ policy.infraAttEntityP.attributes.ownerKey }}
#### Tag: {{ policy.infraAttEntityP.attributes.ownerTag }}
### Status: {{ policy.infraAttEntityP.attributes.status }}
### Type: {{ policy.infraAttEntityP.attributes.type }}
### UID: {{ policy.infraAttEntityP.attributes.uid }}
### User Domain: {{ policy.infraAttEntityP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraFexP %}
## Name: {{ policy.infraFexP.attributes.name }}
### Name Alias: {{ policy.infraFexP.attributes.nameAlias }}
### Annotation: {{ policy.infraFexP.attributes.annotation }}
### Child Action: {{ policy.infraFexP.attributes.childAction }}
### Description: {{ policy.infraFexP.attributes.descr }}
### DN: {{ policy.infraFexP.attributes.dn }}
### Externally Managed By: {{ policy.infraFexP.attributes.extMngdBy }}
### Local Owner: {{ policy.infraFexP.attributes.lcOwn }}
### Last Modified: {{ policy.infraFexP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraFexP.attributes.monPolDn }}
### Owner
#### Key: {{ policy.infraFexP.attributes.ownerKey }}
#### Tag: {{ policy.infraFexP.attributes.ownerTag }}
### Status: {{ policy.infraFexP.attributes.status }}
### Type: {{ policy.infraFexP.attributes.type }}
### UID: {{ policy.infraFexP.attributes.uid }}
### User Domain: {{ policy.infraFexP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraFuncP %}
## Name: {{ policy.infraFuncP.attributes.name }}
### Name Alias: {{ policy.infraFuncP.attributes.nameAlias }}
### Annotation: {{ policy.infraFuncP.attributes.annotation }}
### Child Action: {{ policy.infraFuncP.attributes.childAction }}
### Description: {{ policy.infraFuncP.attributes.descr }}
### DN: {{ policy.infraFuncP.attributes.dn }}
### Externally Managed By: {{ policy.infraFuncP.attributes.extMngdBy }}
### Local Owner: {{ policy.infraFuncP.attributes.lcOwn }}
### Last Modified: {{ policy.infraFuncP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraFuncP.attributes.monPolDn }}
### Owner
#### Key: {{ policy.infraFuncP.attributes.ownerKey }}
#### Tag: {{ policy.infraFuncP.attributes.ownerTag }}
### Status: {{ policy.infraFuncP.attributes.status }}
### Type: {{ policy.infraFuncP.attributes.type }}
### UID: {{ policy.infraFuncP.attributes.uid }}
### User Domain: {{ policy.infraFuncP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraNodeP %}
## Name: {{ policy.infraNodeP.attributes.name }}
### Name Alias: {{ policy.infraNodeP.attributes.nameAlias }}
### Annotation: {{ policy.infraNodeP.attributes.annotation }}
### Child Action: {{ policy.infraNodeP.attributes.childAction }}
### Description: {{ policy.infraNodeP.attributes.descr }}
### DN: {{ policy.infraNodeP.attributes.dn }}
### Externally Managed By: {{ policy.infraNodeP.attributes.extMngdBy }}
### Local Owner: {{ policy.infraNodeP.attributes.lcOwn }}
### Last Modified: {{ policy.infraNodeP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraNodeP.attributes.monPolDn }}
### Owner
#### Key: {{ policy.infraNodeP.attributes.ownerKey }}
#### Tag: {{ policy.infraNodeP.attributes.ownerTag }}
### Status: {{ policy.infraNodeP.attributes.status }}
### Type: {{ policy.infraNodeP.attributes.type }}
### UID: {{ policy.infraNodeP.attributes.uid }}
### User Domain: {{ policy.infraNodeP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraPodP %}
## Name: {{ policy.infraPodP.attributes.name }}
### Name Alias: {{ policy.infraPodP.attributes.nameAlias }}
### Annotation: {{ policy.infraPodP.attributes.annotation }}
### Child Action: {{ policy.infraPodP.attributes.childAction }}
### Description: {{ policy.infraPodP.attributes.descr }}
### DN: {{ policy.infraPodP.attributes.dn }}
### Externally Managed By: {{ policy.infraPodP.attributes.extMngdBy }}
### Local Owner: {{ policy.infraPodP.attributes.lcOwn }}
### Last Modified: {{ policy.infraPodP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraPodP.attributes.monPolDn }}
### Owner
#### Key: {{ policy.infraPodP.attributes.ownerKey }}
#### Tag: {{ policy.infraPodP.attributes.ownerTag }}
### Status: {{ policy.infraPodP.attributes.status }}
### Type: {{ policy.infraPodP.attributes.type }}
### UID: {{ policy.infraPodP.attributes.uid }}
### User Domain: {{ policy.infraPodP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraSpAccPortP %}
## Name: {{ policy.infraSpAccPortP.attributes.name }}
### Name Alias: {{ policy.infraSpAccPortP.attributes.nameAlias }}
### Annotation: {{ policy.infraSpAccPortP.attributes.annotation }}
### Child Action: {{ policy.infraSpAccPortP.attributes.childAction }}
### Description: {{ policy.infraSpAccPortP.attributes.descr }}
### DN: {{ policy.infraSpAccPortP.attributes.dn }}
### Externally Managed By: {{ policy.infraSpAccPortP.attributes.extMngdBy }}
### Local Owner: {{ policy.infraSpAccPortP.attributes.lcOwn }}
### Last Modified: {{ policy.infraSpAccPortP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraSpAccPortP.attributes.monPolDn }}
### Owner
#### Key: {{ policy.infraSpAccPortP.attributes.ownerKey }}
#### Tag: {{ policy.infraSpAccPortP.attributes.ownerTag }}
### Status: {{ policy.infraSpAccPortP.attributes.status }}
### Type: {{ policy.infraSpAccPortP.attributes.type }}
### UID: {{ policy.infraSpAccPortP.attributes.uid }}
### User Domain: {{ policy.infraSpAccPortP.attributes.userdom }}
{%-         endif %}
{%-         if policy.infraSpineP %}
## Name: {{ policy.infraSpineP.attributes.name }}
### Name Alias: {{ policy.infraSpineP.attributes.nameAlias }}
### Annotation: {{ policy.infraSpineP.attributes.annotation }}
### Child Action: {{ policy.infraSpineP.attributes.childAction }}
### Description: {{ policy.infraSpineP.attributes.descr }}
### DN: {{ policy.infraSpineP.attributes.dn }}
### Externally Managed By: {{ policy.infraSpineP.attributes.extMngdBy }}
### Local Owner: {{ policy.infraSpineP.attributes.lcOwn }}
### Last Modified: {{ policy.infraSpineP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraSpineP.attributes.monPolDn }}
### Owner
#### Key: {{ policy.infraSpineP.attributes.ownerKey }}
#### Tag: {{ policy.infraSpineP.attributes.ownerTag }}
### Status: {{ policy.infraSpineP.attributes.status }}
### Type: {{ policy.infraSpineP.attributes.type }}
### UID: {{ policy.infraSpineP.attributes.uid }}
### User Domain: {{ policy.infraSpineP.attributes.userdom }}
{%-         endif %}
{%-     endfor %}
{%- elif "fabricPod" in api %}
# Fabric Pods
{%-     for pod in data_to_template['imdata'] %}
## ID: {{ pod.fabricPod.attributes.id }}
### Child Action: {{ pod.fabricPod.attributes.childAction }}
### DN: {{ pod.fabricPod.attributes.dn }}
### Local Owner: {{ pod.fabricPod.attributes.lcOwn }}
### Last Timestamp: {{ pod.fabricPod.attributes.modTs }}
### Monitoring Policy DN: {{ pod.fabricPod.attributes.monPolDn }}
### Pod Type: {{ pod.fabricPod.attributes.podType }}
### Status: {{ pod.fabricPod.attributes.status }}
{%-     endfor %}
{%- elif "fabricPath" in api %}
{%-     if "Ep" in api %}
{%-         if "Cont" in api %}
# Fabric Path Endpoint Containers
{%-             for container in data_to_template['imdata'] %}
## Node ID: {{ container.fabricPathEpCont.attributes.nodeId }}
### DN: {{ container.fabricPathEpCont.attributes.dn }}
### Child Action: {{ container.fabricPathEpCont.attributes.childAction }}
### Local Owner: {{ container.fabricPathEpCont.attributes.lcOwn }}
### Last Modified: {{ container.fabricPathEpCont.attributes.modTs }}
### Monitoring Policy DN: {{ container.fabricPathEpCont.attributes.monPolDn }}
### Status: {{ container.fabricPathEpCont.attributes.status }}
{%-             endfor %}
{%-         else %}
# Fabric Path Endpoints<
{%-             for endpoint in data_to_template['imdata'] %}
## Name: {{ endpoint.fabricPathEp.attributes.name }}
### Child Action: {{ endpoint.fabricPathEp.attributes.childAction }}
### Description: {{ endpoint.fabricPathEp.attributes.descr }}
### DN: {{ endpoint.fabricPathEp.attributes.dn }}
### Types
#### Lag: {{ endpoint.fabricPathEp.attributes.lagT }}
#### Path: {{ endpoint.fabricPathEp.attributes.pathT }}
### Local Owner: {{ endpoint.fabricPathEp.attributes.lcOwn }}
### Last Modified: {{ endpoint.fabricPathEp.attributes.modTs }}
### Monitoring Policy DN: {{ endpoint.fabricPathEp.attributes.monPolDn }}
### Status: {{ endpoint.fabricPathEp.attributes.status }}
{%-             endfor %}
{%-         endif %}
{%-     else %}
# Fabric Paths
{%-         for path in data_to_template['imdata'] %}
## DN: {{ path.fabricPath.attributes.dn }}
### Nodes
#### 1: {{ path.fabricPath.attributes.n1 }}
#### 2: {{ path.fabricPath.attributes.n2 }}
### Child Action: {{ path.fabricPath.attributes.childAction }}
### Local Owner: {{ path.fabricPath.attributes.lcOwn }}
### Last Modified: {{ path.fabricPath.attributes.modTs }}
### Monitoring Policy DN: {{ path.fabricPath.attributes.monPolDn }}
### Status: {{ path.fabricPath.attributes.status }}
{%-         endfor %}
{%-     endif %}
{%- elif "rtctrlSubjP" in api %}
# Prefix List
{%-     for outer_list in data_to_template %}
{%-         for prefix_list in outer_list %}
## Name: {{ prefix_list.rtctrlSubjP.attributes.name }}
### Annotation: {{ prefix_list.rtctrlSubjP.attributes.annotation }}
### Child Action: {{ prefix_list.rtctrlSubjP.attributes.childAction }}
### Description: {{ prefix_list.rtctrlSubjP.attributes.description }}
### DN: {{ prefix_list.rtctrlSubjP.attributes.dn }}
### Externally Managed By: {{ prefix_list.rtctrlSubjP.attributes.extMngdBy }}
### Local Owner: {{ prefix_list.rtctrlSubjP.attributes.lcOwn }}
### Last Modified: {{ prefix_list.rtctrlSubjP.attributes.modTs }}
### Name Alias: {{ prefix_list.rtctrlSubjP.attributes.nameAlias }}
### Status: {{ prefix_list.rtctrlSubjP.attributes.status }}
### UID: {{ prefix_list.rtctrlSubjP.attributes.uid }}
### User Domain: {{ prefix_list.rtctrlSubjP.attributes.userdom }}
{%-         endfor %}
{%-     endfor %}
{%- elif "rtctrlMatchRtDest" in api %}
# Prefix List Detailed
{%-     for outer_list in data_to_template %}
{%-         for prefix_list_detailed in outer_list %}
## Name: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.name }}
### Aggregate: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.aggregate }}
### Annotation: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.annotation }}
### Child Action: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.childAction }}
### Description: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.descr }}
### DN: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.dn }}
### Externally Managed By: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.extMngdBy }}
### fromPfxLen: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.fromPfxLen }}
### IP: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.ip }}
### Local Owner: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.lcOwn }}
### Last Modified: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.modTs }}
### Name Alias: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.nameAlias }}
### Status: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.status }}
### toPfxLen: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.toPfxLen }}
### Type: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.type }}
### UID: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.uid }}
### User Domain: {{ prefix_list_detailed.rtctrlMatchRtDest.attributes.userdom }}
{%-         endfor %}
{%-     endfor %}
{%- elif "Tenant" in api %}
# Tenants
{%-     for tenant in data_to_template['imdata'] %}
## {{ tenant.fvTenant.attributes.name }}
### Alias: {{ tenant.fvTenant.attributes.nameAlias }}
### Description: {{ tenant.fvTenant.attributes.descr }}
### Status: {{ tenant.fvTenant.attributes.status }}
### DN: {{ tenant.fvTenant.attributes.dn }}
### UID: {{ tenant.fvTenant.attributes.uid }}
### Annotation: {{ tenant.fvTenant.attributes.annotation }}
### Child Action: {{ tenant.fvTenant.attributes.childAction }}
### Externally Managed By: {{ tenant.fvTenant.attributes.extMngdBy }}
### Local Owner: {{ tenant.fvTenant.attributes.lcOwn }}
### Monitoring Policy DN: {{ tenant.fvTenant.attributes.monPolDn }}
### Owner
#### Key: {{ tenant.fvTenant.attributes.ownerKey }}
#### Tag: {{ tenant.fvTenant.attributes.ownerTag }}
### User Domain: {{ tenant.fvTenant.attributes.userdom }}
### Modified Timestamp: {{ tenant.fvTenant.attributes.modTs }}
{%-     endfor %}
{%- elif "aaaUser" in api %}
# Users
{%-     for user in data_to_template['imdata'] %}
## Name: {{ user.aaaUser.attributes.name }}
### Name Alias: {{ user.aaaUser.attributes.nameAlias }}
### Account Status: {{ user.aaaUser.attributes.accountStatus }}
### Annotation: {{ user.aaaUser.attributes.annotation }}
### Cert Attribute: {{ user.aaaUser.attributes.certAttribute }}
### Child Action: {{ user.aaaUser.attributes.childAction }}
### Clear Password History: {{ user.aaaUser.attributes.clearPwdHistory }}
### Description: {{ user.aaaUser.attributes.descr }}
### DN: {{ user.aaaUser.attributes.dn }}
### Email: {{ user.aaaUser.attributes.email }}
### Expiration: {{ user.aaaUser.attributes.expiration }}
### Expires: {{ user.aaaUser.attributes.expires }}
### Externally Managed By: {{ user.aaaUser.attributes.extMngdBy }}
### Identity
#### First Name: {{ user.aaaUser.attributes.firstName }}
#### Last Name: {{ user.aaaUser.attributes.lastName }}
#### Phone: {{ user.aaaUser.attributes.phone }}
### Local Owner: {{ user.aaaUser.attributes.lcOwn }}
### Last Modified: {{ user.aaaUser.attributes.modTs }}
### Monitoring Policy DN: {{ user.aaaUser.attributes.monPolDn }}
### OPT
#### Enable: {{ user.aaaUser.attributes.otpenable }}
#### Enforced: {{ user.aaaUser.attributes.otpenf }}
#### Key: {{ user.aaaUser.attributes.otpkey }}
### Owner
#### Key: {{ user.aaaUser.attributes.ownerKey }}
#### Tag: {{ user.aaaUser.attributes.ownerTag }}
### Password
#### Life Time: {{ user.aaaUser.attributes.pwdLifeTime }}
#### Update Required: {{ user.aaaUser.attributes.pwdUpdateRequired }}
### RBAC
#### String: {{ user.aaaUser.attributes.rbacString }}
#### Restricted User: {{ user.aaaUser.attributes.restrictedRbacUser }}
### Status: {{ user.aaaUser.attributes.status }}
### UID: {{ user.aaaUser.attributes.uid }}
### UNIX User ID: {{ user.aaaUser.attributes.unixUserId }}
### User Domain: {{ user.aaaUser.attributes.userdom }}
{%-     endfor %}
{%- elif "aaaDomain" in api %}
# Security Domains
{%-     for domain in data_to_template['imdata'] %}
## Name: {{ domain.aaaDomain.attributes.name }}
### Name Alias: {{ domain.aaaDomain.attributes.nameAlias }}
### Annotation: {{ domain.aaaDomain.attributes.annotation }}
### Child Action: {{ domain.aaaDomain.attributes.childAction }}
### Description: {{ domain.aaaDomain.attributes.descr }}
### DN: {{ domain.aaaDomain.attributes.dn }}
### Externally Managed By: {{ domain.aaaDomain.attributes.extMngdBy }}
### Local Owner: {{ domain.aaaDomain.attributes.lcOwn }}
### Last Modified: {{ domain.aaaDomain.attributes.modTs }}
### Owner
#### Key: {{ domain.aaaDomain.attributes.ownerKey }}
#### Tag: {{ domain.aaaDomain.attributes.ownerTag }}
### Restricted RBAC Domain: {{ domain.aaaDomain.attributes.restrictedRbacDomain }}
### Status: {{ domain.aaaDomain.attributes.status }}
### UID: {{ domain.aaaDomain.attributes.uid }}
### User Domain: {{ domain.aaaDomain.attributes.userdom }}
{%-     endfor %}
{%- elif "vzSubj" in api %}
# Contract Subjects
{%-     for subject in data_to_template['imdata'] %}
## Name: {{ subject.vzSubj.attributes.name }}
### Name Alias: {{ subject.vzSubj.attributes.nameAlias }}
### Access Privilege: {{ subject.vzSubj.attributes.accessPrivilege }}
### Annotation: {{ subject.vzSubj.attributes.annotation }}
### Child Action: {{ subject.vzSubj.attributes.childAction }}
### Configuration Issues: {{ subject.vzSubj.attributes.configIssues }}
### Match T
#### Consumer: {{ subject.vzSubj.attributes.consMatchT }}
#### Provider: {{ subject.vzSubj.attributes.provMatchT }}
### Description: {{ subject.vzSubj.attributes.descr }}
### DN: {{ subject.vzSubj.attributes.dn }}
### Externally Managed By: {{ subject.vzSubj.attributes.extMngdBy }}
### Local Onwer: {{ subject.vzSubj.attributes.lcOwn }}
### Last Modified: {{ subject.vzSubj.attributes.modTs }}
### Monitoring Policy DN: {{ subject.vzSubj.attributes.monPolDn }}
### Priority: {{ subject.vzSubj.attributes.prio }}
### Reverse Filter Ports: {{ subject.vzSubj.attributes.revFltPorts }}
### Status: {{ subject.vzSubj.attributes.status }}
### Target DSCP: {{ subject.vzSubj.attributes.targetDscp }}
### UID: {{ subject.vzSubj.attributes.uid }}
### User Domain: {{ subject.vzSubj.attributes.userdom }}
{%-     endfor %}
{%- elif "topology/health" in api %}
# Fabric Total Health
{%-     for score in data_to_template['imdata'] %}
## Score
### Change: {{ score.fabricHealthTotal.attributes.chng }}
### Current: {{ score.fabricHealthTotal.attributes.cur }}
### Previous: {{ score.fabricHealthTotal.attributes.prev }}
### TW: {{ score.fabricHealthTotal.attributes.twScore }}
## Child Action: {{ score.fabricHealthTotal.attributes.childAction }}
## DN: {{ score.fabricHealthTotal.attributes.dn }}
## Local Owner: {{ score.fabricHealthTotal.attributes.lcOwn }}
## Maximum Severity: {{ score.fabricHealthTotal.attributes.maxSev }}
## Timestamps
### Last Modified: {{ score.fabricHealthTotal.attributes.modTs }}
### Last Updated: {{ score.fabricHealthTotal.attributes.updTs }}
## Status: {{ score.fabricHealthTotal.attributes.status }}
{%-     endfor %}
{%- elif "pkiFabricNodeSSLCertificate" in api %}
# Fabric Node SSL Certificates
{%-     for cert in data_to_template['imdata'] %}
## Name: {{ cert.pkiFabricNodeSSLCertificate.attributes.name }}
### Name Alias: {{ cert.pkiFabricNodeSSLCertificate.attributes.nameAlias }}
### Authority Key Identifier: {{ cert.pkiFabricNodeSSLCertificate.attributes.authorityKeyIdentifier }}
### Child Action: {{ cert.pkiFabricNodeSSLCertificate.attributes.childAction }}
### Data: {{ cert.pkiFabricNodeSSLCertificate.attributes.data | replace("\n"," ") }}
### Description: {{ cert.pkiFabricNodeSSLCertificate.attributes.descr }}
### DN: {{ cert.pkiFabricNodeSSLCertificate.attributes.dn }}
### Expired Certificate: {{ cert.pkiFabricNodeSSLCertificate.attributes.expiredCertificate }}
### Invalid
#### Issuer: {{ cert.pkiFabricNodeSSLCertificate.attributes.invalidIssuer }}
#### Signing CA For Certificate: {{ cert.pkiFabricNodeSSLCertificate.attributes.invalidSigningCAForCertificate }}
#### Subject Format: {{ cert.pkiFabricNodeSSLCertificate.attributes.invalidSubjectFormat }}
### Issuer: {{ cert.pkiFabricNodeSSLCertificate.attributes.issuer }}
### Key Size: {{ cert.pkiFabricNodeSSLCertificate.attributes.keySize }}
### Local Owner: {{ cert.pkiFabricNodeSSLCertificate.attributes.lcOwn }}
### Message: {{ cert.pkiFabricNodeSSLCertificate.attributes.message }}
### Last Modified: {{ cert.pkiFabricNodeSSLCertificate.attributes.modTs }}
### Monitoring Policy DN: {{ cert.pkiFabricNodeSSLCertificate.attributes.monPolDn }}
### Node
#### ID: {{ cert.pkiFabricNodeSSLCertificate.attributes.nodeId }}
#### Type: {{ cert.pkiFabricNodeSSLCertificate.attributes.nodeType }}
### Owner:
#### Key: {{ cert.pkiFabricNodeSSLCertificate.attributes.ownerKey }}
#### Tag: {{ cert.pkiFabricNodeSSLCertificate.attributes.ownerTag }}
### Public Key Algorithm: {{ cert.pkiFabricNodeSSLCertificate.attributes.publicKeyAlgorithm }}
### Serial Number: {{ cert.pkiFabricNodeSSLCertificate.attributes.serialNumber }}
### Signature Algorithm: {{ cert.pkiFabricNodeSSLCertificate.attributes.signatureAlgorithm }}
### Status: {{ cert.pkiFabricNodeSSLCertificate.attributes.status }}
### Subject
#### Subject: {{ cert.pkiFabricNodeSSLCertificate.attributes.subject }}
#### Subject Key Identifier: {{ cert.pkiFabricNodeSSLCertificate.attributes.subjectKeyIdentifier }}
### Validate
#### Certificate: {{ cert.pkiFabricNodeSSLCertificate.attributes.validCertificate }}
#### Validity Not After: {{ cert.pkiFabricNodeSSLCertificate.attributes.validityNotAfter }}
#### Validity Not Before: {{ cert.pkiFabricNodeSSLCertificate.attributes.validityNotBefore }}
### Version: {{ cert.pkiFabricNodeSSLCertificate.attributes.version }}
{%-     endfor %}
{%- elif "tn-" and "health" in api %}
# Tenant Health
{%-     for outer_list in data_to_template %}
{%-         for tenant in outer_list %}
## DN: {{ tenant.healthInst.attributes.dn }}
### Scores
#### Change: {{ tenant.healthInst.attributes.chng }}</td>
#### Current: {{ tenant.healthInst.attributes.cur }}
#### Previous: {{ tenant.healthInst.attributes.prev }}
#### TW Score: {{ tenant.healthInst.attributes.twScore }}
### Child Action: {{ tenant.healthInst.attributes.childAction }}
### Maximum Severity: {{ tenant.healthInst.attributes.maxSev }}
### Timestamps
#### Last Modified: {{ tenant.healthInst.attributes.modTs }}
#### Last Updated: {{ tenant.healthInst.attributes.updTs }}
### Status: {{ tenant.healthInst.attributes.status }}
{%-         endfor %}
{%-     endfor %}
{%- elif "firmwareCtrlrRunning" in api %}
# Fabric Membership
{%-     for member in data_to_template['imdata'] %}
## DN: {{ member.firmwareCtrlrRunning.attributes.dn }}
### Child Action: {{ member.firmwareCtrlrRunning.attributes.childAction }}
### Description: {{ member.firmwareCtrlrRunning.attributes.descr }}
### Internal Label: {{ member.firmwareCtrlrRunning.attributes.internalLabel }}
### Local Owner: {{ member.firmwareCtrlrRunning.attributes.lcOwn }}
### Last Modified: {{ member.firmwareCtrlrRunning.attributes.modTs }}
### Mode: {{ member.firmwareCtrlrRunning.attributes.mode }}
### Status: {{ member.firmwareCtrlrRunning.attributes.status }}
### TPM In Use: {{ member.firmwareCtrlrRunning.attributes.tpmInUse }}
### Timestamp: {{ member.firmwareCtrlrRunning.attributes.ts }}
### Type: {{ member.firmwareCtrlrRunning.attributes.type }}
### Version: {{ member.firmwareCtrlrRunning.attributes.version }}
{%-     endfor %}
{%- elif "topSystem" in api %}
{%-     if "?" not in api %}
# topSystem
{%-         for topSystem in data_to_template['imdata'] %}
## {{ topSystem.topSystem.attributes.name }}
### Address: {{ topSystem.topSystem.attributes.address }}
### Bootstrap State: {{ topSystem.topSystem.attributes.bootstrapState }}
### Child Action: {{ topSystem.topSystem.attributes.childAction }}
### Cluster Time Diff: {{ topSystem.topSystem.attributes.clusterTimeDiff }}
### Configuration Issues: {{ topSystem.topSystem.attributes.configIssues }}
### Control Plane MTU: {{ topSystem.topSystem.attributes.controlPlaneMTU }}
### Current Time: {{ topSystem.topSystem.attributes.currentTime }}
### DN: {{ topSystem.topSystem.attributes.dn }}
### Enforce Subnet Check: {{ topSystem.topSystem.attributes.enforceSubnetCheck }}
### ETEP Address: {{ topSystem.topSystem.attributes.etepAddr }}
### Fabric Domain: {{ topSystem.topSystem.attributes.fabricDomain }}
### Fabric ID: {{ topSystem.topSystem.attributes.fabricId }}
### Fabric MAC: {{ topSystem.topSystem.attributes.fabricMAC }}
### ID: {{ topSystem.topSystem.attributes.id }}
### Inband Mgmt Address: {{ topSystem.topSystem.attributes.inbMgmtAddr }}
### Inband Mgmt Address6: {{ topSystem.topSystem.attributes.inbMgmtAddr }}
### Inband Mgmt Address6 Mask: {{ topSystem.topSystem.attributes.inbMgmtAddr6Mask }}
### Inband Mgmt Address Mask: {{ topSystem.topSystem.attributes.inbMgmtAddrMask }}
### Inband Mgmt Gateway: {{ topSystem.topSystem.attributes.inbMgmtGateway }}
### Inband Mgmt Gateway6: {{ topSystem.topSystem.attributes.inbMgmtGateway6 }}
### Last Reboot Time: {{ topSystem.topSystem.attributes.lastRebootTime }}
### Last Reset Reason: {{ topSystem.topSystem.attributes.lastResetReason }}
### LC Own: {{ topSystem.topSystem.attributes.lcOwn }}
### Modified Timestamp: {{ topSystem.topSystem.attributes.modTs }}
### Mode: {{ topSystem.topSystem.attributes.mode }}
### Monitoring Policy DN: {{ topSystem.topSystem.attributes.monPolDn }}
### Name Alias: {{ topSystem.topSystem.attributes.nameAlias }}
### Node Type: {{ topSystem.topSystem.attributes.nodeType }}
### Out of Band Mgmt Address: {{ topSystem.topSystem.attributes.oobMgmtAddr }}
### Out of Band Mgmt Address6: {{ topSystem.topSystem.attributes.oobMgmtAddr6 }}
### Out of Band Mgmt Address6 Mask: {{ topSystem.topSystem.attributes.oobMgmtAddr6Mask }}
### Out of Band Mgmt Address Mask: {{ topSystem.topSystem.attributes.oobMgmtAddrMask }}
### Out of Band Mgmt Gateway: {{ topSystem.topSystem.attributes.oobMgmtGateway }}
### Out of Band Mgmt Gateway6: {{ topSystem.topSystem.attributes.oobMgmtGateway6 }}
### Pod ID: {{ topSystem.topSystem.attributes.podId }}
### Remote Network ID: {{ topSystem.topSystem.attributes.remoteNetworkId }}
### Remote Node: {{ topSystem.topSystem.attributes.remoteNode }}
### RL Oper Pod ID: {{ topSystem.topSystem.attributes.rlOperPodId }}
### RL Routable Mode: {{ topSystem.topSystem.attributes.rlRoutableMode }}
### RL Direct Mode: {{ topSystem.topSystem.attributes.rldirectMode }}
### Role: {{ topSystem.topSystem.attributes.role }}
### Serial Number: {{ topSystem.topSystem.attributes.serial }}
### Server Type: {{ topSystem.topSystem.attributes.serverType }}
### Site ID: {{ topSystem.topSystem.attributes.siteId }}
### State: {{ topSystem.topSystem.attributes.state }}
### Status: {{ topSystem.topSystem.attributes.status }}
### System Uptime: {{ topSystem.topSystem.attributes.systemUpTime }}
### TEP Pool: {{ topSystem.topSystem.attributes.tepPool }}
### Unicast XR EP Learn Disable: {{ topSystem.topSystem.attributes.unicastXrEpLearnDisable }}
### Version: {{ topSystem.topSystem.attributes.version }}
### Virtual Mode: {{ topSystem.topSystem.attributes.virtualMode }}
{%-         endfor %}
{%-     endif %}
{%- elif "vnsMDev" in api %}
# Device Packages
{%-     for package in data_to_template['imdata'] %}
## Vendor: {{ package.vnsMDev.attributes.vendor }}
### Annotation: {{ package.vnsMDev.attributes.annotation }}
### Audit On Busy: {{ package.vnsMDev.attributes.auditOnBusy }}
### Child Action: {{ package.vnsMDev.attributes.childAction }}
### DN: {{ package.vnsMDev.attributes.dn }}
### Externally Managed By: {{ package.vnsMDev.attributes.extMngdBy }}
### Function Mask: {{ package.vnsMDev.attributes.funcMask }}
### Local Owner: {{ package.vnsMDev.attributes.lcOwn }}
### Managed: {{ package.vnsMDev.attributes.managed }}
### Last Modified: {{ package.vnsMDev.attributes.modTs }}
### Mode: {{ package.vnsMDev.attributes.model }}
### Monitoring Policy DN: {{ package.vnsMDev.attributes.monPolDn }}
### Status: {{ package.vnsMDev.attributes.status }}
### UID: {{ package.vnsMDev.attributes.uid }}
### User Domain: {{ package.vnsMDev.attributes.userdom }}
### Version: {{ package.vnsMDev.attributes.version }}
{%-     endfor %}
{%- elif "cnwAggrIf" in api %}
# Cluster Aggregate Interfaces
{%-     for interface in data_to_template['imdata'] %}
## {{ interface.cnwAggrIf.attributes.name }}
### Admin State: {{ interface.cnwAggrIf.attributes.adminSt }}</td>
### Auto Negotiate: {{ interface.cnwAggrIf.attributes.autoNeg }}</td>
### Bandwidth: {{ interface.cnwAggrIf.attributes.bw }}</td>
### Child Action: {{ interface.cnwAggrIf.attributes.childAction }}</td>
### Delay: {{ interface.cnwAggrIf.attributes.delay }}</td>
### Description: {{ interface.cnwAggrIf.attributes.descr }}</td>
### DN: {{ interface.cnwAggrIf.attributes.dn }}</td>
### Dot1q Ether Type: {{ interface.cnwAggrIf.attributes.dot1qEtherType }}</td>
### FCOT Channel Number: {{ interface.cnwAggrIf.attributes.fcotChannelNumber }}</td>
### ID: {{ interface.cnwAggrIf.attributes.id }}</td>
### Inherited Bandwidth: {{ interface.cnwAggrIf.attributes.inhBw }}</td>
### Is Reflective Relay Config Supported: {{ interface.cnwAggrIf.attributes.isReflectiveRelayCfgSupported }}</td>
### Layer: {{ interface.cnwAggrIf.attributes.layer }}</td>
### Local Owner: {{ interface.cnwAggrIf.attributes.lcOwn }}</td>
### Link Debounce: {{ interface.cnwAggrIf.attributes.linkDebounce }}</td>
### Link Log: {{ interface.cnwAggrIf.attributes.linkLog }}</td>
### MDIX: {{ interface.cnwAggrIf.attributes.mdix }}</td>
### Medium: {{ interface.cnwAggrIf.attributes.medium }}</td>
### Last Modified: {{ interface.cnwAggrIf.attributes.modTs }}</td>
### Mode: {{ interface.cnwAggrIf.attributes.mode }}</td>
### Monitoring Policy DN: {{ interface.cnwAggrIf.attributes.monPolDn }}</td>
### MTU: {{ interface.cnwAggrIf.attributes.mtu }}</td>
### Oper State: {{ interface.cnwAggrIf.attributes.operSt }}</td>
### Path S Description: {{ interface.cnwAggrIf.attributes.pathSDescr }}</td>
### Port T: {{ interface.cnwAggrIf.attributes.portT }}</td>
### Priority Flow Control: {{ interface.cnwAggrIf.attributes.prioFlowCtrl }}</td>
### Reflective Relay Enable: {{ interface.cnwAggrIf.attributes.reflectiveRelayEn }}</td>
### Router MAC: {{ interface.cnwAggrIf.attributes.routerMac }}</td>
### SNMP Trap State: {{ interface.cnwAggrIf.attributes.snmpTrapSt }}</td>
### Span Mode: {{ interface.cnwAggrIf.attributes.spanMode }}</td>
### Speed: {{ interface.cnwAggrIf.attributes.speed }}</td>
### Status: {{ interface.cnwAggrIf.attributes.status }}</td>
### Switching State: {{ interface.cnwAggrIf.attributes.switchingSt }}</td>
### Trunk Log: {{ interface.cnwAggrIf.attributes.trunkLog }}</td>
### Usage: {{ interface.cnwAggrIf.attributes.usage }}</td>
{%-     endfor %}
{%- elif "l3Inst" in api %}
# Layer3 Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.l3Inst.attributes.name }}
### Admin State: {{ interface.l3Inst.attributes.adminState }}
### BGP
#### RD: {{ interface.l3Inst.attributes.bgpRd }}
#### RD Display: {{ interface.l3Inst.attributes.bgpRdDisp }}
### Child Action: {{ interface.l3Inst.attributes.childAction }}
### Timestamps
#### Created: {{ interface.l3Inst.attributes.createTs }}
#### Last Changed: {{ interface.l3Inst.attributes.lastChgdTs }}
#### Modified: {{ interface.l3Inst.attributes.modTs }}
### CTX PKey: {{ interface.l3Inst.attributes.ctxPKey }}
### DN: {{ interface.l3Inst.attributes.dn }}
### Domain ID: {{ interface.l3Inst.attributes.domainId }}
### Encapsulation: {{ interface.l3Inst.attributes.encap }}
### GSDB CTX: {{ interface.l3Inst.attributes.gsdbCtx }}
### ID: {{ interface.l3Inst.attributes.id }}
### L3 VM Config
#### Failed Bmp: {{ interface.l3Inst.attributes.l3vmCfgFailedBmp }}
#### Failed Timestamp: {{ interface.l3Inst.attributes.l3vmCfgFailedTs }}
#### State: {{ interface.l3Inst.attributes.l3vmCfgState }}
### Local Owner: {{ interface.l3Inst.attributes.lcOwn }}
### Monitoring Policy DN: {{ interface.l3Inst.attributes.monPolDn }}
### MPLS VPN Label Index: {{ interface.l3Inst.attributes.mplsVPNLabelIndex }}
### Oper State
#### Old Quality: {{ interface.l3Inst.attributes.oldOperStQual }}
#### Quality: {{ interface.l3Inst.attributes.operStQual }}
#### State: {{ interface.l3Inst.attributes.operState }}
### Oui: {{ interface.l3Inst.attributes.oui }}
### Pending: {{ interface.l3Inst.attributes.pending }}
### Port Control Bmp: {{ interface.l3Inst.attributes.prtclBmp }}
### Resource ID: {{ interface.l3Inst.attributes.resourceId }}
### Scope: {{ interface.l3Inst.attributes.scope }}
### Status: {{ interface.l3Inst.attributes.status }}
### TIB
#### v4
##### ID: {{ interface.l3Inst.attributes.v4TibId }}
##### Name:  {{ interface.l3Inst.attributes.v4TibName }}
##### Oper State
###### Old Quality: {{ interface.l3Inst.attributes.v4TibOldOperStQual }}
###### Quality: {{ interface.l3Inst.attributes.v4TibOperStQual }}
###### State: {{ interface.l3Inst.attributes.v4TibOperState }}
##### Pending: {{ interface.l3Inst.attributes.v4TibPending }}
##### Valid: {{ interface.l3Inst.attributes.v4TibValid }}
#### v6
##### ID: {{ interface.l3Inst.attributes.v6TibId }}
##### Name: {{ interface.l3Inst.attributes.v6TibName }}
##### Oper State
###### Old Quality: {{ interface.l3Inst.attributes.v6TibOldOperStQual }}
###### Quality: {{ interface.l3Inst.attributes.v6TibOperStQual }}
###### State: {{ interface.l3Inst.attributes.v6TibOperState }}
##### Pending: {{ interface.l3Inst.attributes.v6TibPending }}
##### Valid: {{ interface.l3Inst.attributes.v6TibValid }}
### VPN ID: {{ interface.l3Inst.attributes.vpnId }}
{%-     endfor %}
{%- elif "actrlEntity" in api %}
# Access Control Entities
{%-     for acl in data_to_template['imdata'] %}
## Name: {{ acl.actrlEntity.attributes.name }}
### Admin State: {{ acl.actrlEntity.attributes.adminSt }}
### Child Action: {{ acl.actrlEntity.attributes.childAction }}
### DN: {{ acl.actrlEntity.attributes.dn }}
### Local Owner: {{ acl.actrlEntity.attributes.lcOwn }}
### Last Modified: {{ acl.actrlEntity.attributes.modTs }}
### Monitoring Policy DN: {{ acl.actrlEntity.attributes.monPolDn }}
### Operational
#### Error: {{ acl.actrlEntity.attributes.operErr }}
#### State: {{ acl.actrlEntity.attributes.operSt }}
### Status: {{ acl.actrlEntity.attributes.status }}
{%-     endfor %}
{%- elif "actrlInst" in api %}
# Access Control Instances
{%-     for acl in data_to_template['imdata'] %}
## Name: {{ acl.actrlInst.attributes.name }}
### Acc Control: {{ acl.actrlInst.attributes.accCtrl }}
### Admin State: {{ acl.actrlInst.attributes.adminSt }}
### Child Action: {{ acl.actrlInst.attributes.childAction }}
### Control: {{ acl.actrlInst.attributes.ctrl }}
### DN: {{ acl.actrlInst.attributes.dn }}
### Local Owner: {{ acl.actrlInst.attributes.lcOwn }}
### Log Clr Interval: {{ acl.actrlInst.attributes.logClrIntvl }}
### Last Modified: {{ acl.actrlInst.attributes.modTs }}
### Monitoring Policy DN: {{ acl.actrlInst.attributes.monPolDn }}
### Operational State: {{ acl.actrlInst.attributes.operErr }}
### Status: {{ acl.actrlInst.attributes.status }}
{%-     endfor %}
{%- elif "actrlRule" in api %}
# Access Control Rules
{%-     for acl in data_to_template['imdata'] %}
## Name: {{ acl.actrlRule.attributes.name }}
### Name Alias: {{ acl.actrlRule.attributes.nameAlias }}
### Action: {{ acl.actrlRule.attributes.action }}
### Access Control Configuration
#### Failed Bmp: {{ acl.actrlRule.attributes.actrlCfgFailedBmp }}
#### Failed Timestamp: {{ acl.actrlRule.attributes.actrlCfgFailedTs }}
#### State: {{ acl.actrlRule.attributes.actrlCfgState }}
### Child Action: {{ acl.actrlRule.attributes.childAction }}
### Contract Name: {{ acl.actrlRule.attributes.ctrctName }}
### PC Tags
#### Destination: {{ acl.actrlRule.attributes.dPcTag }}
#### Source: {{ acl.actrlRule.attributes.sPcTag }}
### Description: {{ acl.actrlRule.attributes.descr }}
### Direction: {{ acl.actrlRule.attributes.direction }}
### DN: {{ acl.actrlRule.attributes.dn }}
### Filter ID: {{ acl.actrlRule.attributes.fltId }}
### ID: {{ acl.actrlRule.attributes.id }}
### Intent: {{ acl.actrlRule.attributes.intent }}
### Local Owner: {{ acl.actrlRule.attributes.lcOwn }}
### Mark DSCP: {{ acl.actrlRule.attributes.markDscp }}
### Last Modified: {{ acl.actrlRule.attributes.modTs }}
### Monitoring Policy DN: {{ acl.actrlRule.attributes.monPolDn }}
### Operational
#### State: {{ acl.actrlRule.attributes.operSt }}
#### State Quality: {{ acl.actrlRule.attributes.operStQual }}
### Priority: {{ acl.actrlRule.attributes.prio }}
### QOS Group: {{ acl.actrlRule.attributes.qosGrp }}
### Scope ID: {{ acl.actrlRule.attributes.scopeId }}
### Status: {{ acl.actrlRule.attributes.status }}
### Type: {{ acl.actrlRule.attributes.type }}
{%-     endfor %}
{%- elif "actrlScope" in api %}
# Access Control Scopes
{%-     for acl in data_to_template['imdata'] %}
## Name: {{ acl.actrlScope.attributes.name }}
### Name Alias: {{ acl.actrlScope.attributes.nameAlias }}
### Child Action: {{ acl.actrlScope.attributes.childAction }}
### Description: {{ acl.actrlScope.attributes.descr }}
### DN: {{ acl.actrlScope.attributes.dn }}
### ID: {{ acl.actrlScope.attributes.id }}
### Local Owner: {{ acl.actrlScope.attributes.lcOwn }}
### Last Modified: {{ acl.actrlScope.attributes.modTs }}
### Monitoring Policy DN: {{ acl.actrlScope.attributes.monPolDn }}
### Security Label: {{ acl.actrlScope.attributes.secLbl }}
### Status: {{ acl.actrlScope.attributes.status }}
{%-     endfor %}
{%- elif "cnwPhysIf" in api %}
# Cluster Physical Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.cnwPhysIf.attributes.name }}
### Admin State: {{ interface.cnwPhysIf.attributes.adminSt }}
### Annotation: {{ interface.cnwPhysIf.attributes.annotation }}
### Auto Negotiate: {{ interface.cnwPhysIf.attributes.autoNeg }}
### Bandwidth: {{ interface.cnwPhysIf.attributes.bw }}
### Child Action: {{ interface.cnwPhysIf.attributes.childAction }}
### Delay: {{ interface.cnwPhysIf.attributes.delay }}
### Description: {{ interface.cnwPhysIf.attributes.descr }}
### Device ID: {{ interface.cnwPhysIf.attributes.deviceId }}
### DN: {{ interface.cnwPhysIf.attributes.dn }}
### Dot1q Ether Type: {{ interface.cnwPhysIf.attributes.dot1qEtherType }}
### Externally Managed By: {{ interface.cnwPhysIf.attributes.extMngdBy }}
### FCOT Channel Number: {{ interface.cnwPhysIf.attributes.fcotChannelNumber }}
### ID: {{ interface.cnwPhysIf.attributes.id }}
### Inherited Bandwidth: {{ interface.cnwPhysIf.attributes.inhBw }}
### Is Reflective Relay Config Supported: {{ interface.cnwPhysIf.attributes.isReflectiveRelayCfgSupported }}
### Layer: {{ interface.cnwPhysIf.attributes.layer }}
### Local Owner: {{ interface.cnwPhysIf.attributes.lcOwn }}
### Link Debounce: {{ interface.cnwPhysIf.attributes.linkDebounce }}
### Link Log: {{ interface.cnwPhysIf.attributes.linkLog }}
### MDIX: {{ interface.cnwPhysIf.attributes.mdix }}
### Medium: {{ interface.cnwPhysIf.attributes.medium }}
### Last Modified: {{ interface.cnwPhysIf.attributes.modTs }}
### Mode: {{ interface.cnwPhysIf.attributes.mode }}
### Monitoring Policy DN: {{ interface.cnwPhysIf.attributes.monPolDn }}
### MTU: {{ interface.cnwPhysIf.attributes.mtu }}
### Oper State: {{ interface.cnwPhysIf.attributes.operSt }}
### Path S Description: {{ interface.cnwPhysIf.attributes.pathSDescr }}
### Port T: {{ interface.cnwPhysIf.attributes.portT }}
### Priority Flow Control: {{ interface.cnwPhysIf.attributes.prioFlowCtrl }}
### Reflective Relay Enable: {{ interface.cnwPhysIf.attributes.reflectiveRelayEn }}
### Router MAC: {{ interface.cnwPhysIf.attributes.routerMac }}
### SNMP Trap State: {{ interface.cnwPhysIf.attributes.snmpTrapSt }}
### Span Mode: {{ interface.cnwPhysIf.attributes.spanMode }}
### Speed: {{ interface.cnwPhysIf.attributes.speed }}
### Status: {{ interface.cnwPhysIf.attributes.status }}
### Switching State: {{ interface.cnwPhysIf.attributes.switchingSt }}
### Trunk Log: {{ interface.cnwPhysIf.attributes.trunkLog }}
### UID: {{ interface.cnwPhysIf.attributes.uid }}
### Usage: {{ interface.cnwPhysIf.attributes.usage }}
### User Domain: {{ interface.cnwPhysIf.attributes.userdom }}
### Vendor ID: {{ interface.cnwPhysIf.attributes.vendorId }}
### Wiring Issues: {{ interface.cnwPhysIf.attributes.wiringIssues }}
{%-     endfor %}
{%- elif "compCtrlr" in api %}
# Compute Controllers
{%-     for controller in data_to_template['imdata'] %}
## Name: {{ controller.compCtrlr.attributes.name }}
### Name Alias: {{ controller.compCtrlr.attributes.nameAlias }}
### Access Mode: {{ controller.compCtrlr.attributes.accessMode }}
### API Version: {{ controller.compCtrlr.attributes.apiVer }}
### AVE 
#### Switching Active: {{ controller.compCtrlr.attributes.aveSwitchingActive }}
#### Time Out:  {{ controller.compCtrlr.attributes.aveTimeOut }}
### Child Action: {{ controller.compCtrlr.attributes.childAction }}
### CIMC Version: {{ controller.compCtrlr.attributes.cimcVersion }}
### Control
#### Knob: {{ controller.compCtrlr.attributes.ctrlKnob }}
#### rP Key: {{ controller.compCtrlr.attributes.ctrlrPKey }}
### Deployment Issues: {{ controller.compCtrlr.attributes.deployIssues }}
### Description: {{ controller.compCtrlr.attributes.descr }}
### DN: {{ controller.compCtrlr.attributes.dn }}
### Domain Name: {{ controller.compCtrlr.attributes.domName }}
### DVS Version: {{ controller.compCtrlr.attributes.dvsVersion }}
### Enable
#### AVE: {{ controller.compCtrlr.attributes.enableAVE }}
#### Tag: {{ controller.compCtrlr.attributes.enableTag }}
#### VM Folder: {{ controller.compCtrlr.attributes.enableVmFolder }}
### EP Ret Time: {{ controller.compCtrlr.attributes.epRetTime }}
### Host Or IP: {{ controller.compCtrlr.attributes.hostOrIp }}
### ID: {{ controller.compCtrlr.attributes.id }}
### Inventory
#### Start Timestamp: {{ controller.compCtrlr.attributes.inventoryStartTS }}
#### Trigger State: {{ controller.compCtrlr.attributes.inventoryTrigSt }}
### Issues: {{ controller.compCtrlr.attributes.issues }}
### Key: {{ controller.compCtrlr.attributes.key }}
### Lag Policy Name: {{ controller.compCtrlr.attributes.lagPolicyName }}
### Last 
#### Event
##### Collector ID: {{ controller.compCtrlr.attributes.lastEventCollectorId }}
##### ID: {{ controller.compCtrlr.attributes.lastEventId }}
##### Timestamp: {{ controller.compCtrlr.attributes.lastEventTS }}
#### Inventory
##### State: {{ controller.compCtrlr.attributes.lastInventorySt }}
##### Timestamp: {{ controller.compCtrlr.attributes.lastInventoryTS }}
### Local Owner: {{ controller.compCtrlr.attributes.lcOwn }}
### Max Worker Q Size: {{ controller.compCtrlr.attributes.maxWorkerQSize }}
### Last Modified: {{ controller.compCtrlr.attributes.modTs }}
### Mode: {{ controller.compCtrlr.attributes.mode }}
### Model: {{ controller.compCtrlr.attributes.model }}
### Monitoring Policy DN: {{ controller.compCtrlr.attributes.monPolDn }}
### Oper State: {{ controller.compCtrlr.attributes.operSt }}
### Port: {{ controller.compCtrlr.attributes.port }}
### Remote
#### Error Message: {{ controller.compCtrlr.attributes.remoteErrMsg }}
#### Oper Issues: {{ controller.compCtrlr.attributes.remoteOperIssues }}
### Rev: {{ controller.compCtrlr.attributes.rev }}
### Root Cont Name: {{ controller.compCtrlr.attributes.rootContName }}
### Scope: {{ controller.compCtrlr.attributes.scope }}
### Ser: {{ controller.compCtrlr.attributes.ser }}
### Set
#### Deployment Issues: {{ controller.compCtrlr.attributes.setDeployIssues }}
#### Oper Issues: {{ controller.compCtrlr.attributes.setRemoteOperIssues }}
### Status: {{ controller.compCtrlr.attributes.status }}
### Unset
#### Deployment Issues: {{ controller.compCtrlr.attributes.unsetDeployIssues }}
#### Oper Issues: {{ controller.compCtrlr.attributes.unsetRemoteOperIssues }}
### User: {{ controller.compCtrlr.attributes.usr }}
### Vendor: {{ controller.compCtrlr.attributes.vendor }}
### vSphere
#### PHA: {{ controller.compCtrlr.attributes.vspherePHA }}
#### Tag: {{ controller.compCtrlr.attributes.vsphereTag }}
### VXLAN Deployment Preferred: {{ controller.compCtrlr.attributes.vxlanDeplPref }}
{%-     endfor %}
{%- elif "compDom" in api %}
# Compute Domains
{%-     for domain in data_to_template['imdata'] %}
## Name: {{ domain.compDom.attributes.name }}
### Name Alias: {{ domain.compDom.attributes.nameAlias }}
### Child Action: {{ domain.compDom.attributes.childAction }}
### Description: {{ domain.compDom.attributes.descr }}
### DN: {{ domain.compDom.attributes.dn }}
### Enable AVE: {{ domain.compDom.attributes.enableAVE }}
### ID: {{ domain.compDom.attributes.id }}
### Issues: {{ domain.compDom.attributes.issues }}
### Local Owner: {{ domain.compDom.attributes.lcOwn }}
### Last Modified: {{ domain.compDom.attributes.modTs }}
### Mode: {{ domain.compDom.attributes.mode }}
### Monitoring Policy DN: {{ domain.compDom.attributes.monPolDn }}
### Status: {{ domain.compDom.attributes.status }}
{%-     endfor %}
{%- elif "compEpPD" in api %}
# Compute Endpoint Policy Description
{%-     for policy in data_to_template['imdata'] %}
## Name: {{ policy.compEpPD.attributes.name }}
### Name Alias: {{ policy.compEpPD.attributes.nameAlias }}
### Allocation Mode: {{ policy.compEpPD.attributes.allocMode }}
### Bridge Domain DN: {{ policy.compEpPD.attributes.bdDn }}
### Binding Type: {{ policy.compEpPD.attributes.bindingType }}
### Block All Ports: {{ policy.compEpPD.attributes.blockAllPorts }}
### Configured Delimeter: {{ policy.compEpPD.attributes.cfgdDelimiter }}
### Child Action: {{ policy.compEpPD.attributes.childAction }}
### Class Preference: {{ policy.compEpPD.attributes.classPref }}
### Configuration Flags: {{ policy.compEpPD.attributes.configFlags }}
### Controller Enabled: {{ policy.compEpPD.attributes.crtrnEnabled }}
### Context DN: {{ policy.compEpPD.attributes.ctxDn }}
### Custom EPG Name: {{ policy.compEpPD.attributes.customEpgName }}
### Deployment Issues: {{ policy.compEpPD.attributes.deployIssues }}
### Description: {{ policy.compEpPD.attributes.descr }}
### DN: {{ policy.compEpPD.attributes.dn }}
### Encapsulation
#### Encapsulation: {{ policy.compEpPD.attributes.encap }}
#### Allocated Key: {{ policy.compEpPD.attributes.encapAllocKey }}
#### Changed: {{ policy.compEpPD.attributes.encapChanged }}
#### Context: {{ policy.compEpPD.attributes.encapCtx }}
#### Mode: {{ policy.compEpPD.attributes.encapMode }}
#### Mode Override: {{ policy.compEpPD.attributes.encapModeOverride }}
### EPG
#### COS: {{ policy.compEpPD.attributes.epgCos }}
#### COS Preference: {{ policy.compEpPD.attributes.epgCosPref }}
#### PKey: {{ policy.compEpPD.attributes.epgPKey }}
### EPP DN: {{ policy.compEpPD.attributes.eppDn }}
### Fault D Key: {{ policy.compEpPD.attributes.faultDKey }}
### Forged Transmit: {{ policy.compEpPD.attributes.forgedTransmit }}
### ID: {{ policy.compEpPD.attributes.id }}
### ID Consumer DN: {{ policy.compEpPD.attributes.idConsumerDn }}
### Inherited: {{ policy.compEpPD.attributes.inherited }}
### Instr Immediacy: {{ policy.compEpPD.attributes.instrImedcy }}
### Intra Sec Conf: {{ policy.compEpPD.attributes.intraSecConf }}
### Issues: {{ policy.compEpPD.attributes.issues }}
### Lag Policy Name: {{ policy.compEpPD.attributes.lagPolicyName }}
### Load Balance Algorithm: {{ policy.compEpPD.attributes.lbAlgo }}
### Local Owner: {{ policy.compEpPD.attributes.lcOwn }}
### MAC Change: {{ policy.compEpPD.attributes.macChange }}
### Multicast Address: {{ policy.compEpPD.attributes.mcastAddr }}
### Last Modified: {{ policy.compEpPD.attributes.modTs }}
### Monitoring Policy DN: {{ policy.compEpPD.attributes.monPolDn }}
### Netflow
#### Direction: {{ policy.compEpPD.attributes.netflowDir }}
#### Preference: {{ policy.compEpPD.attributes.netflowPref }}
### Number Ports: {{ policy.compEpPD.attributes.numPorts }}
### Operational
#### Delimeter: {{ policy.compEpPD.attributes.operDelimiter }}
#### Flags: {{ policy.compEpPD.attributes.operFlags }}
### PC Enforced Preference: {{ policy.compEpPD.attributes.pcEnfPref }}
### Port Allocation: {{ policy.compEpPD.attributes.portAllocation }}
### Primary Encapsulation
#### Primary Encapsulation: {{ policy.compEpPD.attributes.primaryEncap }}
#### Inner: {{ policy.compEpPD.attributes.primaryEncapInner }}
### Prom Mode: {{ policy.compEpPD.attributes.promMode }}
### Remote 
#### Error Message: {{ policy.compEpPD.attributes.remoteErrMsg }}
#### Oper Issues: {{ policy.compEpPD.attributes.remoteOperIssues }}
### Res Immediacy: {{ policy.compEpPD.attributes.resImedcy }}
### Secondary Encapsulation Inner: {{ policy.compEpPD.attributes.secondaryEncapInner }}
### Stats Collection State: {{ policy.compEpPD.attributes.statsCollectionState }}
### Status: {{ policy.compEpPD.attributes.status }}
### Switching Mode: {{ policy.compEpPD.attributes.switchingMode }}
### TX ID: {{ policy.compEpPD.attributes.txId }}
### Type: {{ policy.compEpPD.attributes.type }}
### Untagged: {{ policy.compEpPD.attributes.untagged }}
### Update Timestamp: {{ policy.compEpPD.attributes.updateTs }}
### VNET Only: {{ policy.compEpPD.attributes.vnetOnly }}
### VXLAN Deployment Preferred: {{ policy.compEpPD.attributes.vxlanDeplPref }}
{%-     endfor %}
{%- elif "compProv" in api %}
# Compute Providers
{%-     for provider in data_to_template['imdata'] %}
## Name: {{ provider.compProv.attributes.name }}
### Name Alias: {{ provider.compProv.attributes.nameAlias }}
### Child Action: {{ provider.compProv.attributes.childAction }}
### Description: {{ provider.compProv.attributes.descr }}
### DN: {{ provider.compProv.attributes.dn }}
### ID: {{ provider.compProv.attributes.id }}
### Issues: {{ provider.compProv.attributes.issues }}
### Local Owner: {{ provider.compProv.attributes.lcOwn }}
### Last Modified: {{ provider.compProv.attributes.modTs }}
### Monitoring Policy DN: {{ provider.compProv.attributes.monPolDn }}
### Status: {{ provider.compProv.attributes.status }}
### Vendor: {{ provider.compProv.attributes.vendor }}
{%-     endfor %}
{%- elif "arpAdjEp" in api %}
# ARP Adjacency Endpoints
{%-     for endpoint in data_to_template['imdata'] %}
## Name: {{ endpoint.arpAdjEp.attributes.name }}
### Child Action: {{ endpoint.arpAdjEp.attributes.childAction }}
### DN: {{ endpoint.arpAdjEp.attributes.dn }}
### Interface
#### Interface ID: {{ endpoint.arpAdjEp.attributes.ifId }}
#### Physical Interface ID: {{ endpoint.arpAdjEp.attributes.physIfId }}
### IP: {{ endpoint.arpAdjEp.attributes.ip }}
### MAC: {{ endpoint.arpAdjEp.attributes.mac }}
### Timestamps
#### Last Modified: {{ endpoint.arpAdjEp.attributes.modTs }}
#### Last Updated: {{ endpoint.arpAdjEp.attributes.upTS }}
### Operational State: {{ endpoint.arpAdjEp.attributes.operSt }}
### Status{{ endpoint.arpAdjEp.attributes.status }}
{%-     endfor %}
{%- elif "arpDb" in api %}
# ARP Database
{%-     for entry in data_to_template['imdata'] %}
## Name: {{ entry.arpDb.attributes.name }}
### Child Action: {{ entry.arpDb.attributes.childAction }}
### DN: {{ entry.arpDb.attributes.dn }}
### Last Modified: {{ entry.arpDb.attributes.modTs }}
### Status: {{ entry.arpDb.attributes.status }}
### Type: {{ entry.arpDb.attributes.type }}
{%-     endfor %}
{%- elif "arpDom" in api %}
# ARP Domain
{%-     for domain in data_to_template['imdata'] %}
## Name:  {{ domain.arpDom.attributes.name }}
### Child Action: {{ domain.arpDom.attributes.childAction }}
### DN: {{ domain.arpDom.attributes.dn }}
### Encapsulation: {{ domain.arpDom.attributes.encap }}
### Local Owner: {{ domain.arpDom.attributes.lcOwn }}
### Last Modified: {{ domain.arpDom.attributes.modTs }}
### Monitoring Policy DN: {{ domain.arpDom.attributes.monPolDn }}
### Status: {{ domain.arpDom.attributes.status }}
{%-     endfor %}
{%- elif "arpEntity" in api %}
# ARP Domain
{%-     for entity in data_to_template['imdata'] %}
## Name: {{ entity.arpEntity.attributes.name }}
### Admin State: {{ entity.arpEntity.attributes.adminSt }}
### Child Action: {{ entity.arpEntity.attributes.childAction }}
### DN: {{ entity.arpEntity.attributes.dn }}
### Local Owner: {{ entity.arpEntity.attributes.lcOwn }}
### Last Modified: {{ entity.arpEntity.attributes.modTs }}
### Monitoring Policy DN: {{ entity.arpEntity.attributes.monPolDn }}
### Operational
#### Error: {{ entity.arpEntity.attributes.operErr }}
#### State: {{ entity.arpEntity.attributes.operSt }}
### Status: {{ entity.arpEntity.attributes.status }}
{%-     endfor %}
{%- elif "arpIf" in api %}
# ARP Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.arpIf.attributes.name }}
### Admin State: {{ interface.arpIf.attributes.adminSt }}
### Child Action: {{ interface.arpIf.attributes.childAction }}
### Control: {{ interface.arpIf.attributes.ctrl }}
### Description: {{ interface.arpIf.attributes.descr }}
### DN: {{ interface.arpIf.attributes.dn }}
### ID: {{ interface.arpIf.attributes.id }}
### Local Owner: {{ interface.arpIf.attributes.lcOwn }}
### Last Modified: {{ interface.arpIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.arpIf.attributes.monPolDn }}
### Status: {{ interface.arpIf.attributes.status }}
{%-     endfor %}
{%- elif "arpInst" in api %}
# ARP Instances
{%-     for instance in data_to_template['imdata'] %}
## Name: {{ instance.arpInst.attributes.name }}
### Admin State: {{ instance.arpInst.attributes.adminSt }}
### Child Action: {{ instance.arpInst.attributes.childAction }}
### Control: {{ instance.arpInst.attributes.ctrl }}
### DN: {{ instance.arpInst.attributes.dn }}
### Local Owner: {{ instance.arpInst.attributes.lcOwn }}
### Last Modified: {{ instance.arpInst.attributes.modTs }}
### Monitoring Policy DN: {{ instance.arpInst.attributes.monPolDn }}
### Oper Error: {{ instance.arpInst.attributes.operErr }}
### Status: {{ instance.arpInst.attributes.status }}
{%-     endfor %}
{%- elif "bgpDom" in api %}
{%-     if "Af" in api%}
# BGP Domain Address Families
{%-          for family in data_to_template['imdata'] %}
## Name: {{ family.bgpDomAf.attributes.name }}
### Best Path Timestamps
#### Completed: {{ family.bgpDomAf.attributes.bestPathCmpltTs }}
#### Signature: {{ family.bgpDomAf.attributes.bestPathSigTs }}
### Child Action: {{ family.bgpDomAf.attributes.childAction }}
### Nh Timeout
#### Critial: {{ family.bgpDomAf.attributes.critNhTimeout }}
#### Non-Critical: ### {{ family.bgpDomAf.attributes.nonCritNhTimeout }}
### DN: {{ family.bgpDomAf.attributes.dn }}
### Local Owner: {{ family.bgpDomAf.attributes.lcOwn }}
### ECMP
#### Max: {{ family.bgpDomAf.attributes.maxEcmp }}
#### Max IBGP: {{ family.bgpDomAf.attributes.maxEcmpIbgp }}
### Last Modified: {{ family.bgpDomAf.attributes.modTs }}
### Status: {{ family.bgpDomAf.attributes.status }}
### Table Version: {{ family.bgpDomAf.attributes.tblVer }}
### Type: {{ family.bgpDomAf.attributes.type }}
{%-          endfor %}
{%-     else %}
# ARP Instances
{%-         for domain in data_to_template['imdata'] %}
## Name: {{ domain.bgpDom.attributes.name }}
### BGP Config
#### Failed Bmp: {{ domain.bgpDom.attributes.bgpCfgFailedBmp }}
#### Failed Timestamp: {{ domain.bgpDom.attributes.bgpCfgFailedTs }}
#### State: {{ domain.bgpDom.attributes.bgpCfgState }}
### Child Action: {{ domain.bgpDom.attributes.childAction }}
### Cluster ID: {{ domain.bgpDom.attributes.clusterId }}
### Control: {{ domain.bgpDom.attributes.ctrl }}
### DN: {{ domain.bgpDom.attributes.dn }}
### Encapsulation: {{ domain.bgpDom.attributes.encap }}
### First Path
#### Best Path Delay: {{ domain.bgpDom.attributes.firstBestPathDelay }}
#### Peer Uptime Timestamp: {{ domain.bgpDom.attributes.firstPeerUpTs }}
### Flags: {{ domain.bgpDom.attributes.flags }}
### Hold Interval: {{ domain.bgpDom.attributes.holdIntvl }}
### ka Interval: {{ domain.bgpDom.attributes.kaIntvl }}
### Local Owner: {{ domain.bgpDom.attributes.lcOwn }}
### Max AS Limit: {{ domain.bgpDom.attributes.maxAsLimit }}
### Last Modified: {{ domain.bgpDom.attributes.modTs }}
### Mode: {{ domain.bgpDom.attributes.mode }}
### Monitoring Policy DN: {{ domain.bgpDom.attributes.monPolDn }}
### MSite Cluster ID: {{ domain.bgpDom.attributes.msiteClusterId }}
### Peers
#### Number of Established Peers: {{ domain.bgpDom.attributes.numEstPeers }}
#### Number of Peers: {{ domain.bgpDom.attributes.numPeers }}
### Operational
#### Router ID: {{ domain.bgpDom.attributes.operRtrId }}
#### State: {{ domain.bgpDom.attributes.operSt }}
### RD: {{ domain.bgpDom.attributes.rd }}
### Router ID: {{ domain.bgpDom.attributes.rtrId }}
### Status: {{ domain.bgpDom.attributes.status }}
### Type: {{ domain.bgpDom.attributes.type }}
{%-         endfor %}
{%-     endif %}
{%- elif "bgpEntity" in api %}
# BGP Entities
{%-     for entity in data_to_template['imdata'] %}
## Name: {{ entity.bgpEntity.attributes.name }}
### Admin State: {{ entity.bgpEntity.attributes.adminSt }}
### Child Action: {{ entity.bgpEntity.attributes.childAction }}
### DN: {{ entity.bgpEntity.attributes.dn }}
### Local Owner: {{ entity.bgpEntity.attributes.lcOwn }}
### Last Modified: {{ entity.bgpEntity.attributes.modTs }}
### Monitoring Policy DN: {{ entity.bgpEntity.attributes.monPolDn }}
### Operational
#### Error: {{ entity.bgpEntity.attributes.operErr }}
#### State: {{ entity.bgpEntity.attributes.operSt }}
### Status: {{ entity.bgpEntity.attributes.status }}
{%-     endfor %}
{%- elif "bgpInst" in api %}
{%-     if "InstPol" in api %}
# BGP Instances Policy
{%-         for policy in data_to_template['imdata'] %}
## Name: {{ policy.bgpInstPol.attributes.name }}
### Name Alias: {{ policy.bgpInstPol.attributes.nameAlias }}
### Annotation: {{ policy.bgpInstPol.attributes.annotation }}
### Child Action: {{ policy.bgpInstPol.attributes.childAction }}
### Description: {{ policy.bgpInstPol.attributes.descr }}
### DN: {{ policy.bgpInstPol.attributes.dn }}
### Externally Managed By: {{ policy.bgpInstPol.attributes.extMngdBy }}
### Local Owner: {{ policy.bgpInstPol.attributes.lcOwn }}
### Last Modified: {{ policy.bgpInstPol.attributes.modTs }}
### Monitoring Policy DN: {{ policy.bgpInstPol.attributes.monPolDn }}
### Owner
#### Key: {{ policy.bgpInstPol.attributes.ownerKey }}
#### Tag: {{ policy.bgpInstPol.attributes.ownerTag }}
### Status: {{ policy.bgpInstPol.attributes.status }}
### UID: {{ policy.bgpInstPol.attributes.uid }}
{%-         endfor %}
{%-     else %}
# BGP Instances
{%-         for instance in data_to_template['imdata'] %}
## Name: {{ instance.bgpInst.attributes.name }}
### Activated Timestamp: {{ instance.bgpInst.attributes.activateTs }}
### Admin State: {{ instance.bgpInst.attributes.adminSt }}
### AS Path DB Size: {{ instance.bgpInst.attributes.asPathDbSz }}
### ASN: {{ instance.bgpInst.attributes.asn }}
### Attributes DB Size: {{ instance.bgpInst.attributes.attribDbSz }}
### Child Action: {{ instance.bgpInst.attributes.childAction }}
### Created Timestamp: {{ instance.bgpInst.attributes.createTs }}
### Control: {{ instance.bgpInst.attributes.ctrl }}
### DN: {{ instance.bgpInst.attributes.dn }}
### Local Owner: {{ instance.bgpInst.attributes.lcOwn }}
### SoO
#### Fabric: {{ instance.bgpInst.attributes.fabricSoO }}
#### mSite: {{ instance.bgpInst.attributes.mSiteSoO }}
#### Pod: {{ instance.bgpInst.attributes.podSoO }}
### Memory Alerts: {{ instance.bgpInst.attributes.memAlert }}
### Last Modified: {{ instance.bgpInst.attributes.modTs }}
### Monitoring Policy DN: {{ instance.bgpInst.attributes.monPolDn }}
### Number
#### AS Paths: {{ instance.bgpInst.attributes.numAsPath }}
#### RT Attributes: {{ instance.bgpInst.attributes.numRtAttrib }}
### Oper Error:{{ instance.bgpInst.attributes.operErr }}
### SNMP Trap State: {{ instance.bgpInst.attributes.snmpTrapSt }}
### Spine Role: {{ instance.bgpInst.attributes.spineRole }}
### Status: {{ instance.bgpInst.attributes.status }}
### Support RT: {{ instance.bgpInst.attributes.supprRt }}
### Syslog Level: {{ instance.bgpInst.attributes.syslogLvl }}
### Version: {{ instance.bgpInst.attributes.ver }}
### Wait Done Timestamp: {{ instance.bgpInst.attributes.waitDoneTs }}
{%-         endfor %}
{%-     endif %}
{%- elif "bgpPeer" in api %}
{%-     if "bgpPeerAf" in api %}
# BGP Peer AF Entries
{%-         for af in data_to_template['imdata'] %}
# Name: {{ af.bgpPeerAfEntry.attributes.name }}
### Accepted Paths: {{ af.bgpPeerAfEntry.attributes.acceptedPaths }}
### Child Action: {{ af.bgpPeerAfEntry.attributes.childAction }}
### DN: {{ af.bgpPeerAfEntry.attributes.dn }}
### Eor Received Timestamps
#### First {{ af.bgpPeerAfEntry.attributes.firstEorRcvdTs }}
#### Last: {{ af.bgpPeerAfEntry.attributes.lastEorRcvdTs }}
### Flags: {{ af.bgpPeerAfEntry.attributes.flags }}
### Memory Acc Paths: {{ af.bgpPeerAfEntry.attributes.memAccPaths }}
### Last Modified: {{ af.bgpPeerAfEntry.attributes.modTs }}
### Monitoring Policy DN: {{ af.bgpPeerAfEntry.attributes.monPolDn }}
### Peer Table Version: {{ af.bgpPeerAfEntry.attributes.peerTblVer }}
### Prefix
#### Flushed: {{ af.bgpPeerAfEntry.attributes.pfxFlushed }}
#### Saved: {{ af.bgpPeerAfEntry.attributes.pfxSaved }}
#### Sent: {{ af.bgpPeerAfEntry.attributes.pfxSent }}
### Status: {{ af.bgpPeerAfEntry.attributes.status }}
### Table
#### State: {{ af.bgpPeerAfEntry.attributes.tblSt }}
#### Version {{ af.bgpPeerAfEntry.attributes.tblVer }}
### Type: {{ af.bgpPeerAfEntry.attributes.type }}
{%-         endfor %}
{%-     else %}
{%-         if "bgpPeerEntry" in api %}
# BGP Peer Entries
{%-             for entry in data_to_template['imdata'] %}
## Name: {{ entry.bgpPeerEntry.attributes.name }}
### Address: {{ entry.bgpPeerEntry.attributes.addr }}
### Capabilites
#### Advertised: {{ entry.bgpPeerEntry.attributes.advCap }}
#### Received: {{ entry.bgpPeerEntry.attributes.rcvCap }}
### Child Action: {{ entry.bgpPeerEntry.attributes.childAction }}
### Connection
#### Attempts: {{ entry.bgpPeerEntry.attributes.connAttempts }}
#### Drops: {{ entry.bgpPeerEntry.attributes.connDrop }}
#### Established: {{ entry.bgpPeerEntry.attributes.connEst }}
#### Interface: {{ entry.bgpPeerEntry.attributes.connIf }}
### DN: {{ entry.bgpPeerEntry.attributes.dn }}
### FD: {{ entry.bgpPeerEntry.attributes.fd }}
### Flags: {{ entry.bgpPeerEntry.attributes.flags }}
### Hold Interval: {{ entry.bgpPeerEntry.attributes.holdIntvl }}
### ka Interval: {{ entry.bgpPeerEntry.attributes.kaIntvl }}
### Last Flap Timestamp: {{ entry.bgpPeerEntry.attributes.lastFlapTs }}
### Local
#### IP: {{ entry.bgpPeerEntry.attributes.localIp }}
#### Port: {{ entry.bgpPeerEntry.attributes.localPort }}
### Last Modified: {{ entry.bgpPeerEntry.attributes.modTs }}
### Monitoring Policy DN: {{ entry.bgpPeerEntry.attributes.monPolDn }}
### Oper State: {{ entry.bgpPeerEntry.attributes.operSt }}
### Password Set: {{ entry.bgpPeerEntry.attributes.passwdSet }}
### Peer Index: {{ entry.bgpPeerEntry.attributes.peerIdx }}
### Previous Oper State: {{ entry.bgpPeerEntry.attributes.prevOperSt }}
### Remote Port: {{ entry.bgpPeerEntry.attributes.remotePort }}
### Router ID: {{ entry.bgpPeerEntry.attributes.rtrId }}
### Shut State Quality: {{ entry.bgpPeerEntry.attributes.shutStQual }}
### State Reason: {{ entry.bgpPeerEntry.attributes.stReason }}
### Status: {{ entry.bgpPeerEntry.attributes.status }}
### Type: {{ entry.bgpPeerEntry.attributes.type }}
### Update Elapsed Timestamp: {{ entry.bgpPeerEntry.attributes.updateElapsedTs }}
{%-             endfor %}
{%-         else %}
# BGP Peers
{%-             for peer in data_to_template['imdata'] %}
## Name: {{ peer.bgpPeer.attributes.name }}
### Prefix Peers
#### Active: {{ peer.bgpPeer.attributes.activePfxPeers }}
#### Current: {{ peer.bgpPeer.attributes.curPfxPeers }}
#### Maximum: {{ peer.bgpPeer.attributes.maxPfxPeers }}
#### Total: {{ peer.bgpPeer.attributes.totalPfxPeers }}
### Address: {{ peer.bgpPeer.attributes.addr }}
### Admin State: {{ peer.bgpPeer.attributes.adminSt }}
### ASN: {{ peer.bgpPeer.attributes.asn }}
### BGP Config
#### Failed Bmp: {{ peer.bgpPeer.attributes.bgpCfgFailedBmp }}
#### Failed Timestamp: {{ peer.bgpPeer.attributes.bgpCfgFailedTs }}
#### State: {{ peer.bgpPeer.attributes.bgpCfgState }}
### Child Action: {{ peer.bgpPeer.attributes.childAction }}
### Control: {{ peer.bgpPeer.attributes.ctrl }}
### DN: {{ peer.bgpPeer.attributes.dn }}
### Local Owner: {{ peer.bgpPeer.attributes.lcOwn }}
### Maximum Current Peers: {{ peer.bgpPeer.attributes.maxCurPeers }}
### Last Modified: {{ peer.bgpPeer.attributes.modTs }}
### Monitoring Policy DN: {{ peer.bgpPeer.attributes.monPolDn }}
### Password Set: {{ peer.bgpPeer.attributes.passwdSet }}
### Peer Role: {{ peer.bgpPeer.attributes.peerRole }}
### Private AS Control: {{ peer.bgpPeer.attributes.privateASctrl }}
### Source Interface: {{ peer.bgpPeer.attributes.srcIf }}
### Status: {{ peer.bgpPeer.attributes.status }}
### TTL: {{ peer.bgpPeer.attributes.ttl }}
### Type: {{ peer.bgpPeer.attributes.type }}
{%-             endfor %}
{%-         endif %}
{%-     endif %}
{%- elif "bgpRRP" in api %}
# BGP Route Reflector Policies
{%-     for policy in data_to_template['imdata'] %}
## Name: {{ policy.bgpRRP.attributes.name }}
### Name Alias: {{ policy.bgpRRP.attributes.nameAlias }}
### Annotation: {{ policy.bgpRRP.attributes.annotation }}
### Child Action: {{ policy.bgpRRP.attributes.childAction }}
### Description: {{ policy.bgpRRP.attributes.descr }}
### DN: {{ policy.bgpRRP.attributes.dn }}
### Externally Managed By: {{ policy.bgpRRP.attributes.extMngdBy }}
### Local Owner: {{ policy.bgpRRP.attributes.lcOwn }}
### Last Modified: {{ policy.bgpRRP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.bgpRRP.attributes.monPolDn }}
### Status: {{ policy.bgpRRP.attributes.status }}
### UID: {{ policy.bgpRRP.attributes.uid }}
{%-     endfor %}
{%- elif "cdpAdjEp" in api %}
# CDP Adjacency Endpoints
{%-     for endpoint in data_to_template['imdata'] %}
## Name: {{ endpoint.cdpAdjEp.attributes.name }}
### Capabilites: {{ endpoint.cdpAdjEp.attributes.cap }}
### Child Action: {{ endpoint.cdpAdjEp.attributes.childAction }}
### ID
#### Device: {{ endpoint.cdpAdjEp.attributes.devId }}
#### Platform: {{ endpoint.cdpAdjEp.attributes.platId }}
#### Port: {{ endpoint.cdpAdjEp.attributes.portId }}
### Native VLAN: {{ endpoint.cdpAdjEp.attributes.nativeVlan }}
### DN: {{ endpoint.cdpAdjEp.attributes.dn }}
### Duplex: {{ endpoint.cdpAdjEp.attributes.duplex }}
### Index: {{ endpoint.cdpAdjEp.attributes.index }}
### Last Modified: {{ endpoint.cdpAdjEp.attributes.modTs }}
### Monitoring Policy DN: {{ endpoint.cdpAdjEp.attributes.monPolDn }}
### MTU: {{ endpoint.cdpAdjEp.attributes.mtu }}
### State Quality: {{ endpoint.cdpAdjEp.attributes.stQual }}
### Status: {{ endpoint.cdpAdjEp.attributes.status }}
### System
#### Location: {{ endpoint.cdpAdjEp.attributes.sysLoc }}
#### Name: {{ endpoint.cdpAdjEp.attributes.sysName }}
#### Object ID
##### L: {{ endpoint.cdpAdjEp.attributes.sysObjIdL }}
##### V: {{ endpoint.cdpAdjEp.attributes.sysObjIdV }}
### Version: {{ endpoint.cdpAdjEp.attributes.ver | replace("\n"," ") }}
{%-     endfor %}
{%- elif "cdpEntity" in api %}
# CDP Adjacency Endpoints
{%-     for entity in data_to_template['imdata'] %}
## Name: {{ entity.cdpEntity.attributes.name }}
### Admin State: {{ entity.cdpEntity.attributes.adminSt }}
### Child Action: {{ entity.cdpEntity.attributes.childAction }}
### DN: {{ entity.cdpEntity.attributes.dn }}
### Local Owner: {{ entity.cdpEntity.attributes.lcOwn }}
### Last Modified: {{ entity.cdpEntity.attributes.modTs }}
### Oper
#### Error: {{ entity.cdpEntity.attributes.operErr }}
#### State: {{ entity.cdpEntity.attributes.operSt }}
### Status: {{ entity.cdpEntity.attributes.status }}
{%-     endfor %}
{%- elif "cdpIf" in api %}
# CDP Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.cdpIf.attributes.name }}
### Admin State: {{ interface.cdpIf.attributes.adminSt }}
### Child Action: {{ interface.cdpIf.attributes.childAction }}
### Description: {{ interface.cdpIf.attributes.descr }}
### DN: {{ interface.cdpIf.attributes.dn }}
### ID: {{ interface.cdpIf.attributes.id }}
### Local
#### Owner: {{ interface.cdpIf.attributes.lcOwn }}
#### Description: {{ interface.cdpIf.attributes.locDesc }}
### Last Modified: {{ interface.cdpIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.cdpIf.attributes.monPolDn }}
### Native VLAN: {{ interface.cdpIf.attributes.nativeVlan }}
### Oper
#### State: {{ interface.cdpIf.attributes.operSt }}
#### State Quality: {{ interface.cdpIf.attributes.operStQual }}
### Port Description: {{ interface.cdpIf.attributes.portDesc }}
### Status: {{ interface.cdpIf.attributes.status }}
{%-     endfor %}
{%- elif "cdpInst" in api %}
# CDP Instances
{%-     for instance in data_to_template['imdata'] %}
## Name: {{ instance.cdpInst.attributes.name }}
### Admin State: {{ instance.cdpInst.attributes.adminSt }}
### Child Action: {{ instance.cdpInst.attributes.childAction }}
### Control: {{ instance.cdpInst.attributes.ctrl }}
### Device ID Type: {{ instance.cdpInst.attributes.devIdType }}
### DN: {{ instance.cdpInst.attributes.dn }}
### Hold Interval: {{ instance.cdpInst.attributes.holdIntvl }}
### Local Owner: {{ instance.cdpInst.attributes.lcOwn }}
### Last Modified: {{ instance.cdpInst.attributes.modTs }}
### Monitoring Policy DN: {{ instance.cdpInst.attributes.monPolDn }}
### Number of CDP Hifs: {{ instance.cdpInst.attributes.numCdpHifs }}
### Oper Error: {{ instance.cdpInst.attributes.operErr }}
### Status: {{ instance.cdpInst.attributes.status }}
### System Name: {{ instance.cdpInst.attributes.sysName }}
### TX Frequency: {{ instance.cdpInst.attributes.txFreq }}
### Version: {{ instance.cdpInst.attributes.ver }}
{%-     endfor %}
{%- elif "cdpIntfAddr" in api %}
# CDP Interface Addresses
{%-     for address in data_to_template['imdata'] %}
## Address: {{ address.cdpIntfAddr.attributes.addr }}
### Child Action: {{ address.cdpIntfAddr.attributes.childAction }}
### DN: {{ address.cdpIntfAddr.attributes.dn }}
### Last Modified: {{ address.cdpIntfAddr.attributes.modTs }}
### Status: {{ address.cdpIntfAddr.attributes.status }}
{%-     endfor %}
{%- elif "cdpMgmtAddr" in api %}
# CDP Management Addresses
{%-     for address in data_to_template['imdata'] %}
## Address: {{ address.cdpMgmtAddr.attributes.addr }}
### Child Action: {{ address.cdpMgmtAddr.attributes.childAction }}
### DN: {{ address.cdpMgmtAddr.attributes.dn }}
### Last Modified: {{ address.cdpMgmtAddr.attributes.modTs }}
### Status: {{ address.cdpMgmtAddr.attributes.status }}
{%-     endfor %}
{%- elif "cnwRsMbrIfs" in api %}
# Node RS Member Interfaces
{%-     for interface in data_to_template['imdata'] %}
## tDN: {{ interface.cnwRsMbrIfs.attributes.tDn }}
### Child Action: {{ interface.cnwRsMbrIfs.attributes.childAction }}
### DN: {{ interface.cnwRsMbrIfs.attributes.dn }}
### Force Resolve: {{ interface.cnwRsMbrIfs.attributes.forceResolve }}
### Local Owner: {{ interface.cnwRsMbrIfs.attributes.lcOwn }}
### Last Modified: {{ interface.cnwRsMbrIfs.attributes.modTs }}
### Parent SKey: {{ interface.cnwRsMbrIfs.attributes.parentSKey }}
### rType: {{ interface.cnwRsMbrIfs.attributes.rType }}
### State: {{ interface.cnwRsMbrIfs.attributes.state }}
### State Quality: {{ interface.cnwRsMbrIfs.attributes.stateQual }}
### Status: {{ interface.cnwRsMbrIfs.attributes.status }}
### tCl: {{ interface.cnwRsMbrIfs.attributes.tCl }}
### tSKey: {{ interface.cnwRsMbrIfs.attributes.tSKey }}
### tType: {{ interface.cnwRsMbrIfs.attributes.tType }}
{%-     endfor %}
{%- elif "compRsDomP" in api %}
# Compute RS Domain Policies
{%-     for policy in data_to_template['imdata'] %}
## DN: {{ policy.compRsDomP.attributes.dn }}
### Child Action: {{ policy.compRsDomP.attributes.childAction }}
### Force Resolve: {{ policy.compRsDomP.attributes.forceResolve }}
### Local Owner: {{ policy.compRsDomP.attributes.lcOwn }}
### Last Modified: {{ policy.compRsDomP.attributes.modTs }}
### rType: {{ policy.compRsDomP.attributes.rType }}
### State: {{ policy.compRsDomP.attributes.state }}
### State Quality: {{ policy.compRsDomP.attributes.stateQual }}
### Status: {{ policy.compRsDomP.attributes.status }}
### tCl: {{ policy.compRsDomP.attributes.tCl }}
### tDN: {{ policy.compRsDomP.attributes.tDn }}
### tType: {{ policy.compRsDomP.attributes.tType }}
{%-     endfor %}
{%- elif "eqptBSlot" in api %}
# Equipment Board Slots
{%-     for slot in data_to_template['imdata'] %}
## ID: {{ slot.eqptBSlot.attributes.id }}
### Card Oper State: {{ slot.eqptBSlot.attributes.cardOperSt }}
### Child Action: {{ slot.eqptBSlot.attributes.childAction }}
### Description: {{ slot.eqptBSlot.attributes.descr }}
### DN: {{ slot.eqptBSlot.attributes.dn }}
### Local Owner: {{ slot.eqptBSlot.attributes.lcOwn }}
### Location: {{ slot.eqptBSlot.attributes.loc }}
### Last Modified: {{ slot.eqptBSlot.attributes.modTs }}
### Monitoring Policy DN: {{ slot.eqptBSlot.attributes.monPolDn }}
### Oper State: {{ slot.eqptBSlot.attributes.operSt }}
### Physical ID: {{ slot.eqptBSlot.attributes.physId }}
### Status: {{ slot.eqptBSlot.attributes.status }}
### Type: {{ slot.eqptBSlot.attributes.type }}
{%-     endfor %}
{%- elif "eqptBoard" in api %}
# Equipment Boards
{%-     for board in data_to_template['imdata'] %}
## ID: {{ board.eqptBoard.attributes.id }}
### Child Action: {{ board.eqptBoard.attributes.childAction }}
### CIMC Version: {{ board.eqptBoard.attributes.cimcVersion }}
### Description: {{ board.eqptBoard.attributes.descr }}
### DN: {{ board.eqptBoard.attributes.dn }}
### Hardware Version: {{ board.eqptBoard.attributes.hwVer }}
### Local Owner: {{ board.eqptBoard.attributes.lcOwn }}
### MAC
#### B: {{ board.eqptBoard.attributes.macB }}
#### L: {{ board.eqptBoard.attributes.macL }}
### MFG TM: {{ board.eqptBoard.attributes.mfgTm }}
### Last Modified: {{ board.eqptBoard.attributes.modTs }}
### Model: {{ board.eqptBoard.attributes.model }}
### Monitoring Policy DN: {{ board.eqptBoard.attributes.monPolDn }}
### NumP: {{ board.eqptBoard.attributes.numP }}
### State
#### Oper: {{ board.eqptBoard.attributes.operSt }}
#### Power: {{ board.eqptBoard.attributes.pwrSt }}
#### rd: {{ board.eqptBoard.attributes.rdSt }}
### Revision: {{ board.eqptBoard.attributes.rev }}
### Serial Number: {{ board.eqptBoard.attributes.ser }}
### Status: {{ board.eqptBoard.attributes.status }}
### SW CID: {{ board.eqptBoard.attributes.swCId }}
### Type: {{ board.eqptBoard.attributes.type }}
### Uptime: {{ board.eqptBoard.attributes.upTs }}
### vID: {{ board.eqptBoard.attributes.vId }}
### Vendor: {{ board.eqptBoard.attributes.vendor }}
{%-     endfor %}
{%- elif "eqptCPU" in api %}
# Equipment CPUs
{%-     for cpu in data_to_template['imdata'] %}
## ID: {{ cpu.eqptCPU.attributes.id }}
### Architecture: {{ cpu.eqptCPU.attributes.arch }}
### Child Action: {{ cpu.eqptCPU.attributes.childAction }}
### CIMC Version: {{ cpu.eqptCPU.attributes.cimcVersion }}
### Cores: {{ cpu.eqptCPU.attributes.cores }}
### Cores Enabled: {{ cpu.eqptCPU.attributes.coresEn }}
### Description: {{ cpu.eqptCPU.attributes.descr }}
### DN: {{ cpu.eqptCPU.attributes.dn }}
### MFG TM: {{ cpu.eqptCPU.attributes.mfgTm }}
### Last Modified: {{ cpu.eqptCPU.attributes.modTs }}
### Model: {{ cpu.eqptCPU.attributes.model }}
### Revision: {{ cpu.eqptCPU.attributes.rev }}
### Serial Number: {{ cpu.eqptCPU.attributes.ser }}
### Socket: {{ cpu.eqptCPU.attributes.sock }}
### Speed: {{ cpu.eqptCPU.attributes.speed }}
### Status: {{ cpu.eqptCPU.attributes.status }}
### Threads: {{ cpu.eqptCPU.attributes.thrds }}
### Vendor: {{ cpu.eqptCPU.attributes.vendor }}
{%-     endfor %}
{%- elif "eqptCh" in api %}
# Equipment Chassis
{%-     for chassis in data_to_template['imdata'] %}
## ID: {{ chassis.eqptCh.attributes.id }}
### Child Action: {{ chassis.eqptCh.attributes.childAction }}
### CIMC Version: {{ chassis.eqptCh.attributes.cimcVersion }}
### Configured Role: {{ chassis.eqptCh.attributes.configRole }}
### Description: {{ chassis.eqptCh.attributes.descr }}
### DN: {{ chassis.eqptCh.attributes.dn }}
### Hybrid Mode: {{ chassis.eqptCh.attributes.hybridMode }}
### MFG Timestamp: {{ chassis.eqptCh.attributes.mfgTm }}
### Last Modified: {{ chassis.eqptCh.attributes.modTs }}
### Model: {{ chassis.eqptCh.attributes.model }}
### Monitoring Policy DN: {{ chassis.eqptCh.attributes.monPolDn }}
### Oper State: {{ chassis.eqptCh.attributes.operSt }}
### Oper State Quality: {{ chassis.eqptCh.attributes.operStQual }}
### Revision: {{ chassis.eqptCh.attributes.rev }}
### Role: {{ chassis.eqptCh.attributes.role }}
### Serial Number: {{ chassis.eqptCh.attributes.ser }}
### Status: {{ chassis.eqptCh.attributes.status }}
### vID: {{ chassis.eqptCh.attributes.vId }}
### Vendor: {{ chassis.eqptCh.attributes.vendor }}
### Virtual Mode: {{ chassis.eqptCh.attributes.virtualMode }}
{%-     endfor %}
{%- elif "eqptDimm" in api %}
# Equipment DIMMs
{%-     for dimm in data_to_template['imdata'] %}
## ID: {{ dimm.eqptDimm.attributes.id }}
### Acc: {{ dimm.eqptDimm.attributes.acc }}
### Capacity: {{ dimm.eqptDimm.attributes.cap }}
### Child Action: {{ dimm.eqptDimm.attributes.childAction }}
### CIMC Version: {{ dimm.eqptDimm.attributes.cimcVersion }}
### Description: {{ dimm.eqptDimm.attributes.descr }}
### DN: {{ dimm.eqptDimm.attributes.dn }}
### MFG Timestamp: {{ dimm.eqptDimm.attributes.mfgTm }}
### Last Modified: {{ dimm.eqptDimm.attributes.modTs }}
### Model: {{ dimm.eqptDimm.attributes.model }}
### Oper State: {{ dimm.eqptDimm.attributes.operSt }}
### Revision: {{ dimm.eqptDimm.attributes.rev }}
### Serial Number: {{ dimm.eqptDimm.attributes.ser }}
### Status: {{ dimm.eqptDimm.attributes.status }}
### Type: {{ dimm.eqptDimm.attributes.type }}
### Vendor: {{ dimm.eqptDimm.attributes.vendor }}
{%-     endfor %}
{%- elif "eqptExtCh" in api %}
# Equipment Fabric Extenders
{%-     for fabricextender in data_to_template['imdata'] %}
## ID: {{ fabricextender.eqptExtCh.attributes.id }}
### Child Action: {{ fabricextender.eqptExtCh.attributes.childAction }}
### CIMC Version: {{ fabricextender.eqptExtCh.attributes.cimcVersion }}
### Control FPort SDP Timeout: {{ fabricextender.eqptExtCh.attributes.controlFPortSDPTimeout }}
### Description: {{ fabricextender.eqptExtCh.attributes.descr }}
### DN: {{ fabricextender.eqptExtCh.attributes.dn }}
### External Chassis State: {{ fabricextender.eqptExtCh.attributes.extChSt }}
### MAC Address: {{ fabricextender.eqptExtCh.attributes.macAddr }}
### MFG Timestamp: {{ fabricextender.eqptExtCh.attributes.mfgTm }}
### Last Modified: {{ fabricextender.eqptExtCh.attributes.modTs }}
### Model: {{ fabricextender.eqptExtCh.attributes.model }}
### Monitoring Policy DN: {{ fabricextender.eqptExtCh.attributes.monPolDn }}
### Number of MACs: {{ fabricextender.eqptExtCh.attributes.numMacs }}
### Number of Uplink Ports: {{ fabricextender.eqptExtCh.attributes.numUplinkP }}
### Part Number: {{ fabricextender.eqptExtCh.attributes.partNum }}
### Revision: {{ fabricextender.eqptExtCh.attributes.rev }}
### Serial Number: {{ fabricextender.eqptExtCh.attributes.ser }}
### Status: {{ fabricextender.eqptExtCh.attributes.status }}
### Vendor: {{ fabricextender.eqptExtCh.attributes.vendor }}
{%-     endfor %}
{%- elif "eqptFabP" in api %}
# Equipment Fabric Ports
{%-     for port in data_to_template['imdata'] %}
## ID: {{ port.eqptFabP.attributes.id }}
### Child Action: {{ port.eqptFabP.attributes.childAction }}
### Description: {{ port.eqptFabP.attributes.descr }}
### DN: {{ port.eqptFabP.attributes.dn }}
### Flags: {{ port.eqptFabP.attributes.flags }}
### Last Modified: {{ port.eqptFabP.attributes.modTs }}
### Monitoring Policy DN: {{ port.eqptFabP.attributes.monPolDn }}
### Speed: {{ port.eqptFabP.attributes.speed }}
### Status: {{ port.eqptFabP.attributes.status }}
### Type: {{ port.eqptFabP.attributes.type }}
{%-     endfor %}
{%- elif "eqptFan" in api %}
# Equipment Fans
{%-     for fan in data_to_template['imdata'] %}
## ID: {{ fan.eqptFan.attributes.id }}
### Child Action: {{ fan.eqptFan.attributes.childAction }}
### CIMC Version: {{ fan.eqptFan.attributes.cimcVersion }}
### Description: {{ fan.eqptFan.attributes.descr }}
### Direction: {{ fan.eqptFan.attributes.dir }}
### DN: {{ fan.eqptFan.attributes.dn }}
### Max Speed: {{ fan.eqptFan.attributes.maxSpeed }}
### MFG Timestamp: {{ fan.eqptFan.attributes.mfgTm }}
### Last Modified: {{ fan.eqptFan.attributes.modTs }}
### Model: {{ fan.eqptFan.attributes.model }}
### Monitoring Policy DN: {{ fan.eqptFan.attributes.monPolDn }}
### Oper State: {{ fan.eqptFan.attributes.operSt }}
### Revision: {{ fan.eqptFan.attributes.rev }}
### Serial Number: {{ fan.eqptFan.attributes.ser }}
### Speed: {{ fan.eqptFan.attributes.speed }}
### Status: {{ fan.eqptFan.attributes.status }}
### vID: {{ fan.eqptFan.attributes.vId }}
### Vendor: {{ fan.eqptFan.attributes.vendor }}
{%-     endfor %}
{%- elif "eqptFpga" in api %}
# Equipment Field Programmable Gate Arrays
{%-     for array in data_to_template['imdata'] %}
## ID: {{ array.eqptFpga.attributes.id }}
### Child Action: {{ array.eqptFpga.attributes.childAction }}
### CIMC Version: {{ array.eqptFpga.attributes.cimcVersion }}
### Description: {{ array.eqptFpga.attributes.descr }}
### DN: {{ array.eqptFpga.attributes.dn }}
### MFG Timestamp: {{ array.eqptFpga.attributes.mfgTm }}
### Last Modified: {{ array.eqptFpga.attributes.modTs }}
### Model: {{ array.eqptFpga.attributes.model }}
### Monitoring Policy DN: {{ array.eqptFpga.attributes.monPolDn }}
### Oper State: {{ array.eqptFpga.attributes.operSt }}
### Revision: {{ array.eqptFpga.attributes.rev }}
### Serial Number: {{ array.eqptFpga.attributes.ser }}
### Status: {{ array.eqptFpga.attributes.status }}
### Type: {{ array.eqptFpga.attributes.type }}
### Vendor: {{ array.eqptFpga.attributes.vendor }}
{%-     endfor %}
{%- elif "eqptFt" in api %}
{%-     if "Slot" in api %}
# Equipment Fan Tray Slots
{%-         for slot in data_to_template['imdata'] %}
## ID: {{ slot.eqptFtSlot.attributes.id }}
### Card Oper State: {{ slot.eqptFtSlot.attributes.cardOperSt }}
### Child Action: {{ slot.eqptFtSlot.attributes.childAction }}
### Description: {{ slot.eqptFtSlot.attributes.descr }}
### DN: {{ slot.eqptFtSlot.attributes.dn }}
### Location: {{ slot.eqptFtSlot.attributes.loc }}
### Last Modified: {{ slot.eqptFtSlot.attributes.modTs }}
### Monitoring Policy DN: {{ slot.eqptFtSlot.attributes.monPolDn }}
### Oper State: {{ slot.eqptFtSlot.attributes.operSt }}
### Physical ID: {{ slot.eqptFtSlot.attributes.physId }}
### Status: {{ slot.eqptFtSlot.attributes.status }}
### Type: {{ slot.eqptFtSlot.attributes.type }}
{%-         endfor %}
{%-     else %}
# Equipment Fan Trays
{%-         for trays in data_to_template['imdata'] %}
## ID: {{ trays.eqptFt.attributes.id }}
### Child Action: {{ trays.eqptFt.attributes.childAction }}
### CIMC Version: {{ trays.eqptFt.attributes.cimcVersion }}
### Description: {{ trays.eqptFt.attributes.descr }}
### DN: {{ trays.eqptFt.attributes.dn }}
### Fan Name: {{ trays.eqptFt.attributes.fanName }}
### Fanlet Fail String: {{ trays.eqptFt.attributes.fanletFailString }}
### Hardware Version: {{ trays.eqptFt.attributes.hwVer }}
### MFG Timestamp: {{ trays.eqptFt.attributes.mfgTm }}
### Last Modified: {{ trays.eqptFt.attributes.modTs }}
### Model: {{ trays.eqptFt.attributes.model }}
### Monitoring Policy DN: {{ trays.eqptFt.attributes.monPolDn }}
### Oper State: {{ trays.eqptFt.attributes.operSt }}
### Revision: {{ trays.eqptFt.attributes.rev }}
### Serial Number: {{ trays.eqptFt.attributes.ser }}
### Status: {{ trays.eqptFt.attributes.status }}
### Vendor: {{ trays.eqptFt.attributes.vendor }}
{%-         endfor %}
{%-     endif %}
{%- elif "eqptIndLed" in api %}
# Equipment Indicator LEDs
{%-     for led in data_to_template['imdata'] %}
## ID: {{ led.eqptIndLed.attributes.id }}
### Child Action: {{ led.eqptIndLed.attributes.childAction }}
### CIMC Version: {{ led.eqptIndLed.attributes.cimcVersion }}
### Color: {{ led.eqptIndLed.attributes.color }}
### Description: {{ led.eqptIndLed.attributes.descr }}
### DN: {{ led.eqptIndLed.attributes.dn }}
### MFG Timestamp: {{ led.eqptIndLed.attributes.mfgTm }}
### Last Modified: {{ led.eqptIndLed.attributes.modTs }}
### Model: {{ led.eqptIndLed.attributes.model }}
### Oper State: {{ led.eqptIndLed.attributes.operSt }}
### Revision: {{ led.eqptIndLed.attributes.rev }}
### Serial Number: {{ led.eqptIndLed.attributes.ser }}
### Status: {{ led.eqptIndLed.attributes.status }}
### Type: {{ led.eqptIndLed.attributes.type }}
### Vendor: {{ led.eqptIndLed.attributes.vendor }}
{%-     endfor %}
{%- elif "eqptLC" in api %}
{%-     if "Slot" in api %}
# Equipment Line Card Slots
{%-         for slot in data_to_template['imdata'] %}
## ID: {{ slot.eqptLCSlot.attributes.id }}
### Card Oper State: {{ slot.eqptLCSlot.attributes.cardOperSt }}
### Child Action: {{ slot.eqptLCSlot.attributes.childAction }}
### Description: {{ slot.eqptLCSlot.attributes.descr }}
### DN: {{ slot.eqptLCSlot.attributes.dn }}
### Location: {{ slot.eqptLCSlot.attributes.loc }}
### Last Modified: {{ slot.eqptLCSlot.attributes.modTs }}
### Monitoring Policy DN: {{ slot.eqptLCSlot.attributes.monPolDn }}
### Oper State: {{ slot.eqptLCSlot.attributes.operSt }}
### Physical ID: {{ slot.eqptLCSlot.attributes.physId }}
### Status: {{ slot.eqptLCSlot.attributes.status }}
### Type: {{ slot.eqptLCSlot.attributes.type }}
{%-         endfor %}
{%-     else %}
# Equipment Line Cards
{%-         for card in data_to_template['imdata'] %}
## ID: {{ card.eqptLC.attributes.id }}
### Child Action: {{ card.eqptLC.attributes.childAction }}
### CIMC Version: {{ card.eqptLC.attributes.cimcVersion }}
### Description: {{ card.eqptLC.attributes.descr }}
### DN: {{ card.eqptLC.attributes.dn }}
### Hardware Version: {{ card.eqptLC.attributes.hwVer }}
### MAC
#### B: {{ card.eqptLC.attributes.macB }}
#### L: {{ card.eqptLC.attributes.macL }}
### MFG Timestamp: {{ card.eqptLC.attributes.mfgTm }}
### Last Modified: {{ card.eqptLC.attributes.modTs }}
### Model: {{ card.eqptLC.attributes.model }}
### Monitoring Policy DN: {{ card.eqptLC.attributes.monPolDn }}
### Number of Ports: {{ card.eqptLC.attributes.numP }}
### State
#### Oper: {{ card.eqptLC.attributes.operSt }}
#### Power: {{ card.eqptLC.attributes.pwrSt }}
#### rd: {{ card.eqptLC.attributes.rdSt }}
### Revision: {{ card.eqptLC.attributes.rev }}
### Serial Number: {{ card.eqptLC.attributes.ser }}
### Status: {{ card.eqptLC.attributes.status }}
### Software CID: {{ card.eqptLC.attributes.swCId }}
### Type: {{ card.eqptLC.attributes.type }}
### Uptime: {{ card.eqptLC.attributes.upTs }}
### vID: {{ card.eqptLC.attributes.vId }}
### Vendor: {{ card.eqptLC.attributes.vendor }}
{%-         endfor %}
{%-     endif %}
{%- elif "eqptLeafP" in api %}
# Equipment Leaf Ports
{%-     for port in data_to_template['imdata'] %}
## ID: {{ port.eqptLeafP.attributes.id }}
### Child Action: {{ port.eqptLeafP.attributes.childAction }}
### Description: {{ port.eqptLeafP.attributes.descr }}
### DN: {{ port.eqptLeafP.attributes.dn }}
### Flags: {{ port.eqptLeafP.attributes.flags }}
### Last Modified: {{ port.eqptLeafP.attributes.modTs }}
### Monitoring Policy DN: {{ port.eqptLeafP.attributes.monPolDn }}
### Speed: {{ port.eqptLeafP.attributes.speed }}
### Status: {{ port.eqptLeafP.attributes.status }}
### Type: {{ port.eqptLeafP.attributes.type }}
{%-     endfor %}
{%- elif "eqptLocLed" in api %}
# Equipment Port Locator LEDs
{%-     for led in data_to_template['imdata'] %}
## ID: {{ led.eqptLocLed.attributes.id }}
### Admin State: {{ led.eqptLocLed.attributes.adminSt }}
### Child Action: {{ led.eqptLocLed.attributes.childAction }}
### CIMC Version: {{ led.eqptLocLed.attributes.cimcVersion }}
### Color: {{ led.eqptLocLed.attributes.color }}
### Description: {{ led.eqptLocLed.attributes.descr }}
### DN: {{ led.eqptLocLed.attributes.dn }}
### MFG Timestamp: {{ led.eqptLocLed.attributes.mfgTm }}
### Last Modified: {{ led.eqptLocLed.attributes.modTs }}
### Model: {{ led.eqptLocLed.attributes.model }}
### Oper State: {{ led.eqptLocLed.attributes.operSt }}
### Revision: {{ led.eqptLocLed.attributes.rev }}
### Serial Number: {{ led.eqptLocLed.attributes.ser }}
### Status: {{ led.eqptLocLed.attributes.status }}
### Type: {{ led.eqptLocLed.attributes.type }}
### Vendor: {{ led.eqptLocLed.attributes.vendor }}
{%-     endfor %}
{%- elif "eqptPsu" in api %}
{%-     if "Slot" in api %}
# Equipment Power Supply Slots
{%-         for slot in data_to_template['imdata'] %}
## ID: {{ slot.eqptPsuSlot.attributes.id }}
### Card Oper State: {{ slot.eqptPsuSlot.attributes.cardOperSt }}
### Child Action: {{ slot.eqptPsuSlot.attributes.childAction }}
### Description: {{ slot.eqptPsuSlot.attributes.descr }}
### DN: {{ slot.eqptPsuSlot.attributes.dn }}
### Location: {{ slot.eqptPsuSlot.attributes.loc }}
### Last Modified: {{ slot.eqptPsuSlot.attributes.modTs }}
### Monitoring Policy DN: {{ slot.eqptPsuSlot.attributes.monPolDn }}
### Oper State: {{ slot.eqptPsuSlot.attributes.operSt }}
### Physical ID: {{ slot.eqptPsuSlot.attributes.physId }}
### Status: {{ slot.eqptPsuSlot.attributes.status }}
### Type: {{ slot.eqptPsuSlot.attributes.type }}
{%-         endfor %}
{%-     else %}
# Equipment Power Supplies
{%-         for psu in data_to_template['imdata'] %}
## ID: {{ psu.eqptPsu.attributes.id }}
### Alarm Reg: {{ psu.eqptPsu.attributes.almReg }}
### Capacity: {{ psu.eqptPsu.attributes.cap }}
### Child Action: {{ psu.eqptPsu.attributes.childAction }}
### CIMC Version: {{ psu.eqptPsu.attributes.cimcVersion }}
### Description: {{ psu.eqptPsu.attributes.descr }}
### DN: {{ psu.eqptPsu.attributes.dn }}
### Drawn Current: {{ psu.eqptPsu.attributes.drawnCurr }}
### Fan Oper State: {{ psu.eqptPsu.attributes.fanOpSt }}
### Hardware Version: {{ psu.eqptPsu.attributes.hwVer }}
### MFG Timestamp: {{ psu.eqptPsu.attributes.mfgTm }}
### Last Modified: {{ psu.eqptPsu.attributes.modTs }}
### Model: {{ psu.eqptPsu.attributes.model }}
### Monitoring Policy DN: {{ psu.eqptPsu.attributes.monPolDn }}
### Oper State: {{ psu.eqptPsu.attributes.operSt }}
### Revision: {{ psu.eqptPsu.attributes.rev }}
### Serial Number: {{ psu.eqptPsu.attributes.ser }}
### Status: {{ psu.eqptPsu.attributes.status }}
### TC: {{ psu.eqptPsu.attributes.tc }}
### vID: {{ psu.eqptPsu.attributes.vId }}
### vSrc: {{ psu.eqptPsu.attributes.vSrc }}
### Vendor: {{ psu.eqptPsu.attributes.vendor }}
### Voltage: {{ psu.eqptPsu.attributes.volt }}
{%-         endfor %}
{%-     endif %}
{%- elif "eqptRsIoPPhysConf" in api %}
# Equipment RS IO Port Physical Configurations
{%-     for port in data_to_template['imdata'] %}
## tSKey: {{ port.eqptRsIoPPhysConf.attributes.tSKey }}
### Child Action: {{ port.eqptRsIoPPhysConf.attributes.childAction }}
### DN: {{ port.eqptRsIoPPhysConf.attributes.dn }}
### Force Resolve: {{ port.eqptRsIoPPhysConf.attributes.forceResolve }}
### Local Owner: {{ port.eqptRsIoPPhysConf.attributes.lcOwn }}
### Last Modified: {{ port.eqptRsIoPPhysConf.attributes.modTs }}
### rType: {{ port.eqptRsIoPPhysConf.attributes.rType }}
### State: {{ port.eqptRsIoPPhysConf.attributes.state }}
### State Quality: {{ port.eqptRsIoPPhysConf.attributes.stateQual }}
### Status: {{ port.eqptRsIoPPhysConf.attributes.status }}
### tCL: {{ port.eqptRsIoPPhysConf.attributes.tCl }}
### tDN: {{ port.eqptRsIoPPhysConf.attributes.tDn }}
### tType: {{ port.eqptRsIoPPhysConf.attributes.tType }}
{%-     endfor %}
{%- elif "eqptSensor" in api %}
# Equipment Sensors
{%-     for sensor in data_to_template['imdata'] %}
## ID: {{ sensor.eqptSensor.attributes.id }}
### Child Action: {{ sensor.eqptSensor.attributes.childAction }}
### CIMC Version: {{ sensor.eqptSensor.attributes.cimcVersion }}
### Description: {{ sensor.eqptSensor.attributes.descr }}
### DN: {{ sensor.eqptSensor.attributes.dn }}
### Thresholds
#### Major: {{ sensor.eqptSensor.attributes.majorThresh }}
#### Minor: {{ sensor.eqptSensor.attributes.minorThresh }}
#### Current: {{ sensor.eqptSensor.attributes.value }}
### MFG Timestamp: {{ sensor.eqptSensor.attributes.mfgTm }}
### Last Modified: {{ sensor.eqptSensor.attributes.modTs }}
### Model: {{ sensor.eqptSensor.attributes.model }}
### Monitoring Policy DN: {{ sensor.eqptSensor.attributes.monPolDn }}
### Oper State: {{ sensor.eqptSensor.attributes.operSt }}
### Revision: {{ sensor.eqptSensor.attributes.rev }}
### Serial Number: {{ sensor.eqptSensor.attributes.ser }}
### Status: {{ sensor.eqptSensor.attributes.status }}
### Type: {{ sensor.eqptSensor.attributes.type }}
### Vendor: {{ sensor.eqptSensor.attributes.vendor }}
{%-     endfor %}
{%- elif "eqptSpCmnBlk" in api %}
# Equipment SP Common Blocks
{%-     for common_block in data_to_template['imdata'] %}
## PD Number: {{ common_block.eqptSpCmnBlk.attributes.pdNum }}
### Part Number: {{ common_block.eqptSpCmnBlk.attributes.prtNum }}
### Child Action: {{ common_block.eqptSpCmnBlk.attributes.childAction }}
### Checksum: {{ common_block.eqptSpCmnBlk.attributes.cksum }}
### CLEI: {{ common_block.eqptSpCmnBlk.attributes.clei }}
### Count: {{ common_block.eqptSpCmnBlk.attributes.count }}
### DN: {{ common_block.eqptSpCmnBlk.attributes.dn }}
### Eng Bits: {{ common_block.eqptSpCmnBlk.attributes.engBits }}
### Hardware Revision
#### Major: {{ common_block.eqptSpCmnBlk.attributes.hwRevMaj }}
#### Minor: {{ common_block.eqptSpCmnBlk.attributes.hwRevMin }}
### Length: {{ common_block.eqptSpCmnBlk.attributes.len }}
### Values
#### Major: {{ common_block.eqptSpCmnBlk.attributes.major }}
#### Minor: {{ common_block.eqptSpCmnBlk.attributes.minor }}
### MFG 
#### Bits: {{ common_block.eqptSpCmnBlk.attributes.mfgBits }}
#### Dev: {{ common_block.eqptSpCmnBlk.attributes.mfgDev }}
### Last Modified: {{ common_block.eqptSpCmnBlk.attributes.modTs }}
### OEM: {{ common_block.eqptSpCmnBlk.attributes.oem }}
### pRevision: {{ common_block.eqptSpCmnBlk.attributes.pRev }}
### Power Consumption: {{ common_block.eqptSpCmnBlk.attributes.pwrCon }}
### RAM FL: {{ common_block.eqptSpCmnBlk.attributes.ramFl }}
### Serial Number: {{ common_block.eqptSpCmnBlk.attributes.serNum }}
### Signature: {{ common_block.eqptSpCmnBlk.attributes.sig }}
### Size: {{ common_block.eqptSpCmnBlk.attributes.size }}
### Status: {{ common_block.eqptSpCmnBlk.attributes.status }}
### Vendor ID: {{ common_block.eqptSpCmnBlk.attributes.vdrId }}
### Version: {{ common_block.eqptSpCmnBlk.attributes.ver }}
{%-     endfor %}
{%- elif "eqptSpromLc" in api %}
# Equipment SPROM LCs
{%-     for lc in data_to_template['imdata'] %}
## ID: {{ lc.eqptSpromLc.attributes.id }}
### Access: {{ lc.eqptSpromLc.attributes.acc }}
### Capacity: {{ lc.eqptSpromLc.attributes.cap }}
### Child Action: {{ lc.eqptSpromLc.attributes.childAction }}
### CIMC Version: {{ lc.eqptSpromLc.attributes.cimcVersion }}
### Description: {{ lc.eqptSpromLc.attributes.descr }}
### DN: {{ lc.eqptSpromLc.attributes.dn }}
### Error Reason: {{ lc.eqptSpromLc.attributes.errRsn }}
### MFG Timestamp: {{ lc.eqptSpromLc.attributes.mfgTm }}
### Last Modified: {{ lc.eqptSpromLc.attributes.modTs }}
### Model: {{ lc.eqptSpromLc.attributes.model }}
### Monitoring Policy DN: {{ lc.eqptSpromLc.attributes.monPolDn }}
### Number Blocks: {{ lc.eqptSpromLc.attributes.numBlk }}
### Oper State: {{ lc.eqptSpromLc.attributes.operSt }}
### Revision: {{ lc.eqptSpromLc.attributes.rev }}
### Serial Number: {{ lc.eqptSpromLc.attributes.ser }}
### Status: {{ lc.eqptSpromLc.attributes.status }}
### Type: {{ lc.eqptSpromLc.attributes.type }}
### Vendor: {{ lc.eqptSpromLc.attributes.vendor }}
{%-     endfor %}
{%- elif "eqptSpromPsu" in api %}
{%-     if "Blk" in api %}
# Equipment SPROM Power Supply Blocks
{%-         for psu_block in data_to_template['imdata'] %}
## DN: {{ psu_block.eqptSpromPsuBlk.attributes.dn }}
### Voltage:
#### c110: {{ psu_block.eqptSpromPsuBlk.attributes.c110v }}
#### c220: {{ psu_block.eqptSpromPsuBlk.attributes.c220v }}
### Child Action: {{ psu_block.eqptSpromPsuBlk.attributes.childAction }}
### Checksum: {{ psu_block.eqptSpromPsuBlk.attributes.cksum }}
### F Bits: {{ psu_block.eqptSpromPsuBlk.attributes.fbits }}
### Length: {{ psu_block.eqptSpromPsuBlk.attributes.len }}
### Last Modified: {{ psu_block.eqptSpromPsuBlk.attributes.modTs }}
### Power Supply CMd
#### 1: {{ psu_block.eqptSpromPsuBlk.attributes.psCMd1 }}
#### 2: {{ psu_block.eqptSpromPsuBlk.attributes.psCMd2 }}
#### 3: {{ psu_block.eqptSpromPsuBlk.attributes.psCMd3 }}
#### 4: {{ psu_block.eqptSpromPsuBlk.attributes.psCMd4 }}
#### Power supply CMxMd
#### 1: {{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd1 }}
#### 2: {{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd2 }}
#### 3: {{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd3 }}
#### 4: {{ psu_block.eqptSpromPsuBlk.attributes.psCMxMd4 }}
### Signature: {{ psu_block.eqptSpromPsuBlk.attributes.sig }}
### smOID: {{ psu_block.eqptSpromPsuBlk.attributes.smOID }}
### Status: {{ psu_block.eqptSpromPsuBlk.attributes.status }}
### Version: {{ psu_block.eqptSpromPsuBlk.attributes.ver }}
{%-         endfor %}
{%-     else %}
# Equipment SPROM LCs
{%-         for psu in data_to_template['imdata'] %}
## ID: {{ psu.eqptSpromPsu.attributes.id }}
### Access: {{ psu.eqptSpromPsu.attributes.acc }}
### Capacity: {{ psu.eqptSpromPsu.attributes.cap }}
### Child Action: {{ psu.eqptSpromPsu.attributes.childAction }}
### CIMC Version: {{ psu.eqptSpromPsu.attributes.cimcVersion }}
### Description: {{ psu.eqptSpromPsu.attributes.descr }}
### DN: {{ psu.eqptSpromPsu.attributes.dn }}
### Error Reason: {{ psu.eqptSpromPsu.attributes.errRsn }}
### MFG Timestamp: {{ psu.eqptSpromPsu.attributes.mfgTm }}
### Last Modified: {{ psu.eqptSpromPsu.attributes.modTs }}
### Model: {{ psu.eqptSpromPsu.attributes.model }}
### Monitoring Policy DN: {{ psu.eqptSpromPsu.attributes.monPolDn }}
### Number Blocks: {{ psu.eqptSpromPsu.attributes.numBlk }}
### Oper State: {{ psu.eqptSpromPsu.attributes.operSt }}
### Revision: {{ psu.eqptSpromPsu.attributes.rev }}
### Serial Number: {{ psu.eqptSpromPsu.attributes.ser }}
### Status: {{ psu.eqptSpromPsu.attributes.status }}
### Type: {{ psu.eqptSpromPsu.attributes.type }}
### Vendor: {{ psu.eqptSpromPsu.attributes.vendor }}
{%-         endfor %}
{%-     endif %}
{%- elif "eqptSpromSup" in api %}
# Equipment SPROM Supervisors
{%-     for sup in data_to_template['imdata'] %}
## ID: {{ sup.eqptSpromSup.attributes.id }}
### Access: {{ sup.eqptSpromSup.attributes.acc }}
### Capacity: {{ sup.eqptSpromSup.attributes.cap }}
### Child Action: {{ sup.eqptSpromSup.attributes.childAction }}
### CIMC Version: {{ sup.eqptSpromSup.attributes.cimcVersion }}
### Description: {{ sup.eqptSpromSup.attributes.descr }}
### DN: {{ sup.eqptSpromSup.attributes.dn }}
### Error Reason: {{ sup.eqptSpromSup.attributes.errRsn }}
### MFG Timestamp: {{ sup.eqptSpromSup.attributes.mfgTm }}
### Last Modified: {{ sup.eqptSpromSup.attributes.modTs }}
### Model: {{ sup.eqptSpromSup.attributes.model }}
### Monitoring Policy DN: {{ sup.eqptSpromSup.attributes.monPolDn }}
### Number Blocks: {{ sup.eqptSpromSup.attributes.numBlk }}
### Oper State: {{ sup.eqptSpromSup.attributes.operSt }}
### Revision: {{ sup.eqptSpromSup.attributes.rev }}
### Serial Number: {{ sup.eqptSpromSup.attributes.ser }}
### Status: {{ sup.eqptSpromSup.attributes.status }}
### Type: {{ sup.eqptSpromSup.attributes.type }}
### Vendor: {{ sup.eqptSpromSup.attributes.vendor }}
{%-     endfor %}
{%- elif "eqptStorage" in api %}
# Equipment Storage
{%-     for storage in data_to_template['imdata'] %}
## Name: {{ storage.eqptStorage.attributes.name }}
### Name Alias: {{ storage.eqptStorage.attributes.nameAlias }}
### Capacity
#### Available:  {{ storage.eqptStorage.attributes.available }}
#### Used: {{ storage.eqptStorage.attributes.used }}
#### Utilized: {{ storage.eqptStorage.attributes.capUtilized }}
### Blocks: {{ storage.eqptStorage.attributes.blocks }}
### Child Action: {{ storage.eqptStorage.attributes.childAction }}
### Device: {{ storage.eqptStorage.attributes.device }}
### DN: {{ storage.eqptStorage.attributes.dn }}
### Fail Reason: {{ storage.eqptStorage.attributes.failReason }}
### File System: {{ storage.eqptStorage.attributes.fileSystem }}
### Firmware Version: {{ storage.eqptStorage.attributes.firmwareVersion }}
### Local Owner: {{ storage.eqptStorage.attributes.lcOwn }}
### Media Wearout: {{ storage.eqptStorage.attributes.mediaWearout }}
### Last Modified: {{ storage.eqptStorage.attributes.modTs }}
### Model: {{ storage.eqptStorage.attributes.model }}
### Monitoring Policy DN: {{ storage.eqptStorage.attributes.monPolDn }}
### Mount: {{ storage.eqptStorage.attributes.mount }}
### Oper State: {{ storage.eqptStorage.attributes.operSt }}
### Serial Number: {{ storage.eqptStorage.attributes.serial }}
### Status: {{ storage.eqptStorage.attributes.status }}
{%-     endfor %}
{%- elif "eqptSupC" in api %}
{%-     if "Slot" in api %}
# Equipment Supervisor Slots
{%-         for slot in data_to_template['imdata'] %}
## ID: {{ slot.eqptSupCSlot.attributes.id }}
### Card Oper State: {{ slot.eqptSupCSlot.attributes.cardOperSt }}
### Child Action: {{ slot.eqptSupCSlot.attributes.childAction }}
### Description: {{ slot.eqptSupCSlot.attributes.descr }}
### DN: {{ slot.eqptSupCSlot.attributes.dn }}
### Location: {{ slot.eqptSupCSlot.attributes.loc }}
### Last Modified: {{ slot.eqptSupCSlot.attributes.modTs }}
### Monitoring Policy DN: {{ slot.eqptSupCSlot.attributes.monPolDn }}
### Oper State: {{ slot.eqptSupCSlot.attributes.operSt }}
### Physical ID: {{ slot.eqptSupCSlot.attributes.physId }}
### Status: {{ slot.eqptSupCSlot.attributes.status }}
### Type: {{ slot.eqptSupCSlot.attributes.type }}
{%-         endfor %}
{%-     else %}
# Equipment Supervisors
{%-         for supervisor in data_to_template['imdata'] %}
## ID: {{ supervisor.eqptSupC.attributes.id }}
### Child Action: {{ supervisor.eqptSupC.attributes.childAction }}
### CIMC Version: {{ supervisor.eqptSupC.attributes.cimcVersion }}
### Description: {{ supervisor.eqptSupC.attributes.descr }}
### DN: {{ supervisor.eqptSupC.attributes.dn }}
### Hardware Version: {{ supervisor.eqptSupC.attributes.hwVer }}
### MAC
#### B: {{ supervisor.eqptSupC.attributes.macB }}
#### L: {{ supervisor.eqptSupC.attributes.macL }}
### MFG Timestamp: {{ supervisor.eqptSupC.attributes.mfgTm }}
### Last Modified: {{ supervisor.eqptSupC.attributes.modTs }}
### Model: {{ supervisor.eqptSupC.attributes.model }}
### Monitoring Policy DN: {{ supervisor.eqptSupC.attributes.monPolDn }}
### Number of Ports: {{ supervisor.eqptSupC.attributes.numP }}
### State
#### Oper: {{ supervisor.eqptSupC.attributes.operSt }}
#### Power: {{ supervisor.eqptSupC.attributes.pwrSt }}
#### rd: {{ supervisor.eqptSupC.attributes.rdSt }}
### Revision: {{ supervisor.eqptSupC.attributes.rev }}
### Serial Number: {{ supervisor.eqptSupC.attributes.ser }}
### Status: {{ supervisor.eqptSupC.attributes.status }}
### Software CID: {{ supervisor.eqptSupC.attributes.swCId }}
### Type: {{ supervisor.eqptSupC.attributes.type }}
### Uptime: {{ supervisor.eqptSupC.attributes.upTs }}
### vID: {{ supervisor.eqptSupC.attributes.vId }}
### Vendor: {{ supervisor.eqptSupC.attributes.vendor }}
{%-         endfor %}
{%-     endif %}
{%- elif "ethpmPhysIf" in api %}
# Ethernet Port Manager Physical Interfaces
{%-     for interface in data_to_template['imdata'] %}
## DN: {{ interface.ethpmPhysIf.attributes.dn }}
### VLAN
#### Access: {{ interface.ethpmPhysIf.attributes.accessVlan }}
#### Allowed: {{ interface.ethpmPhysIf.attributes.allowedVlans }}
#### Primary VLAN: {{ interface.ethpmPhysIf.attributes.primaryVlan }}
#### Native VLAN: {{ interface.ethpmPhysIf.attributes.nativeVlan }}
### Backplane MAC: {{ interface.ethpmPhysIf.attributes.backplaneMac }}
### Bundle
#### Bup ID: {{ interface.ethpmPhysIf.attributes.bundleBupId }}
#### Index: {{ interface.ethpmPhysIf.attributes.bundleIndex }}
### Configured VLAN
#### Access: {{ interface.ethpmPhysIf.attributes.cfgAccessVlan }}
#### Native: {{ interface.ethpmPhysIf.attributes.cfgNativeVlan }}
### Child Action: {{ interface.ethpmPhysIf.attributes.childAction }}
### Current Error Index: {{ interface.ethpmPhysIf.attributes.currErrIndex }}
### Diagnostics: {{ interface.ethpmPhysIf.attributes.diags }}
### Encapsulation: {{ interface.ethpmPhysIf.attributes.encap }}
### Error
#### Display Timer Running: {{ interface.ethpmPhysIf.attributes.errDisTimerRunning }}
#### VLAN Status HT: {{ interface.ethpmPhysIf.attributes.errVlanStatusHt }}
#### VLANs: {{ interface.ethpmPhysIf.attributes.errVlans }}
### Hardware
#### BD ID: {{ interface.ethpmPhysIf.attributes.hwBdId }}
#### Resource ID: {{ interface.ethpmPhysIf.attributes.hwResourceId }}
### Interface Type: {{ interface.ethpmPhysIf.attributes.intfT }}
### IOD: {{ interface.ethpmPhysIf.attributes.iod }}
### Last
#### Errors: {{ interface.ethpmPhysIf.attributes.lastErrors }}
#### Link State Change: {{ interface.ethpmPhysIf.attributes.lastLinkStChg }}
### Media: {{ interface.ethpmPhysIf.attributes.media }}
### Last Modified: {{ interface.ethpmPhysIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.ethpmPhysIf.attributes.monPolDn }}
### Number of SI: {{ interface.ethpmPhysIf.attributes.numOfSI }}
### Oper
#### Bitset: {{ interface.ethpmPhysIf.attributes.operBitset }}
#### DCE Mode: {{ interface.ethpmPhysIf.attributes.operDceMode }}
#### Duplex: {{ interface.ethpmPhysIf.attributes.operDuplex }}
#### EEER
##### RX Wk Time: {{ interface.ethpmPhysIf.attributes.operEEERxWkTime }}
##### TX Wk Time: {{ interface.ethpmPhysIf.attributes.operEEETxWkTime }}
##### State: {{ interface.ethpmPhysIf.attributes.operEEEState }}
#### Error Display Quality: {{ interface.ethpmPhysIf.attributes.operErrDisQual }}
#### FEC Mode: {{ interface.ethpmPhysIf.attributes.operFecMode }}
#### Flow Control: {{ interface.ethpmPhysIf.attributes.operFlowCtrl }}
#### MDIX: {{ interface.ethpmPhysIf.attributes.operMdix }}
#### Mode: {{ interface.ethpmPhysIf.attributes.operMode }}
#### Mode Detail: {{ interface.ethpmPhysIf.attributes.operModeDetail }}
#### Physical Enable State: {{ interface.ethpmPhysIf.attributes.operPhyEnSt }}
#### Router MAC: {{ interface.ethpmPhysIf.attributes.operRouterMac }}
#### Speed: {{ interface.ethpmPhysIf.attributes.operSpeed }}
#### State: {{ interface.ethpmPhysIf.attributes.operSt }}
#### State Quality: {{ interface.ethpmPhysIf.attributes.operStQual }}
#### State Quality Code: {{ interface.ethpmPhysIf.attributes.operStQualCode }}
#### VLANs: {{ interface.ethpmPhysIf.attributes.operVlans }}
### OS Sum: {{ interface.ethpmPhysIf.attributes.osSum }}
### Port Config Wait Flags: {{ interface.ethpmPhysIf.attributes.portCfgWaitFlags }}
### Reset Counter: {{ interface.ethpmPhysIf.attributes.resetCtr }}
### SI List: {{ interface.ethpmPhysIf.attributes.siList }}
### Status: {{ interface.ethpmPhysIf.attributes.status }}
### TX Type: {{ interface.ethpmPhysIf.attributes.txT }}
### Usage: {{ interface.ethpmPhysIf.attributes.usage }}
### User Configured Flags: {{ interface.ethpmPhysIf.attributes.userCfgdFlags }}
### VDC ID: {{ interface.ethpmPhysIf.attributes.vdcId }}
{%-     endfor %}
{%- elif "fabricExtPathEpCont" in api %}
# Fabric Extended Path Endpoint Containers
{%-     for container in data_to_template['imdata'] %}
## DN: {{ container.fabricExtPathEpCont.attributes.dn }}
### Child Action: {{ container.fabricExtPathEpCont.attributes.childAction }}
### Extended Ch ID: {{ container.fabricExtPathEpCont.attributes.extChId }}
### Local Owner: {{ container.fabricExtPathEpCont.attributes.lcOwn }}
### Last Modified: {{ container.fabricExtPathEpCont.attributes.modTs }}
### Monitoring Policy DN: {{ container.fabricExtPathEpCont.attributes.monPolDn }}
### Status: {{ container.fabricExtPathEpCont.attributes.status }}
{%-     endfor %}
{%- elif "fabricInst" in api %}
# Fabric Instances
{%-     for instance in data_to_template['imdata'] %}
## Name: {{ instance.fabricInst.attributes.name }}
### Name Alias: {{ instance.fabricInst.attributes.nameAlias }}
### Annotation: {{ instance.fabricInst.attributes.annotation }}
### Child Action: {{ instance.fabricInst.attributes.childAction }}
### DN: {{ instance.fabricInst.attributes.dn }}
### Externally Managed By: {{ instance.fabricInst.attributes.extMngdBy }}
### Local Owner: {{ instance.fabricInst.attributes.lcOwn }}
### Last Modified: {{ instance.fabricInst.attributes.modTs }}
### Monitoring Policy DN: {{ instance.fabricInst.attributes.monPolDn }}
### Owner
#### Key: {{ instance.fabricInst.attributes.ownerKey }}
#### Tag: {{ instance.fabricInst.attributes.ownerTag }}
### Status: {{ instance.fabricInst.attributes.status }}
### UID: {{ instance.fabricInst.attributes.uid }}
{%-     endfor %}
{%- elif "fabricLink" in api %}
{%-     if "Cont" in api %}
# Fabric Link Containers
{%-         for container in data_to_template['imdata'] %}
## Node: {{ container.fabricLinkCont.attributes.n }}
### DN: {{ container.fabricLinkCont.attributes.dn }}
### Child Action: {{ container.fabricLinkCont.attributes.childAction }}
### Local Owner: {{ container.fabricLinkCont.attributes.lcOwn }}
### Last Modified: {{ container.fabricLinkCont.attributes.modTs }}
### Monitoring Policy DN: {{ container.fabricLinkCont.attributes.monPolDn }}
### Status: {{ container.fabricLinkCont.attributes.status }}
{%-         endfor %}
{%-     else %}
# Fabric Links
{%-         for link in data_to_template['imdata'] %}
## DN: {{ link.fabricLink.attributes.dn }}
### Child Action: {{ link.fabricLink.attributes.childAction }}
### Local Owner: {{ link.fabricLink.attributes.lcOwn }}
### Link State: {{ link.fabricLink.attributes.linkState }}
### Last Modified: {{ link.fabricLink.attributes.modTs }}
### Monitoring Policy DN: {{ link.fabricLink.attributes.monPolDn }}
### Node
#### 1: {{ link.fabricLink.attributes.n1 }}
#### 2: {{ link.fabricLink.attributes.n2 }}
### Port
#### 1: {{ link.fabricLink.attributes.p1 }}
#### 2: {{ link.fabricLink.attributes.p2 }}
### Router
#### 1: {{ link.fabricLink.attributes.r1 }}
#### 2: {{ link.fabricLink.attributes.r2 }}
### Switch
#### 1: {{ link.fabricLink.attributes.s1 }}
#### 2: {{ link.fabricLink.attributes.s2 }}
### Status: {{ link.fabricLink.attributes.status }}
### Wiring Issues: {{ link.fabricLink.attributes.wiringIssues }}
{%-         endfor %}
{%-     endif %}
{%- elif "fabricLooseLink" in api %}
# Fabric Loose Links
{%-     for link in data_to_template['imdata'] %}
## Name: {{ link.fabricLooseLink.attributes.name }}
### Name Alias: {{ link.fabricLooseLink.attributes.nameAlias }}
### Child Action: {{ link.fabricLooseLink.attributes.childAction }}
### Is Edm Managed: {{ link.fabricLooseLink.attributes.isEdmManaged }}
### Local Owner: {{ link.fabricLooseLink.attributes.lcOwn }}
### Last Modified: {{ link.fabricLooseLink.attributes.modTs }}
### DNs
#### DN: {{ link.fabricLooseLink.attributes.dn }}
#### Node: {{ link.fabricLooseLink.attributes.nodeDn }}
#### Port: {{ link.fabricLooseLink.attributes.portDn }}
### Status: {{ link.fabricLooseLink.attributes.status }}
{%-     endfor %}
{%- elif "fabricLooseNode" in api %}
# Fabric Loose Nodes
{%-     for node in data_to_template['imdata'] %}
## Name: {{ node.fabricLooseNode.attributes.name }}
### Name Alias: {{ node.fabricLooseNode.attributes.nameAlias }}
### Child Action: {{ node.fabricLooseNode.attributes.childAction }}
### DN: {{ node.fabricLooseNode.attributes.dn }}
### ID: {{ node.fabricLooseNode.attributes.id }}
### Is Managed: {{ node.fabricLooseNode.attributes.isManaged }}
### Local Owner: {{ node.fabricLooseNode.attributes.lcOwn }}
### Manager Key: {{ node.fabricLooseNode.attributes.mgrKey }}
### Last Modified: {{ node.fabricLooseNode.attributes.modTs }}
### Monitoring Policy DN: {{ node.fabricLooseNode.attributes.monPolDn }}
### Oper Issues: {{ node.fabricLooseNode.attributes.operIssues }}
### Pod ID: {{ node.fabricLooseNode.attributes.podId }}
### Status: {{ node.fabricLooseNode.attributes.status }}
### System
#### Name: {{ node.fabricLooseNode.attributes.sysName }}
#### Description: {{ node.fabricLooseNode.attributes.sysDesc | replace("\n"," ") }}
{%-     endfor %}
{%- elif "fabricProtPathEpCont" in api %}
# Fabric Protected Path Endpoint Containers
{%-     for container in data_to_template['imdata'] %}
## DN: {{ container.fabricProtPathEpCont.attributes.dn }}
### Child Action: {{ container.fabricProtPathEpCont.attributes.childAction }}
### Local Owner: {{ container.fabricProtPathEpCont.attributes.lcOwn }}
### Last Modified: {{ container.fabricProtPathEpCont.attributes.modTs }}
### Monitoring Policy DN: {{ container.fabricProtPathEpCont.attributes.monPolDn }}
### Node
#### AId: {{ container.fabricProtPathEpCont.attributes.nodeAId }}
#### BId: {{ container.fabricProtPathEpCont.attributes.nodeBId }}
### Status: {{ container.fabricProtPathEpCont.attributes.status }}
{%-     endfor %}
{%- elif "fcEntity" in api %}
# Fibre Channel Entities
{%-     for entity in data_to_template['imdata'] %}
## Name: {{ entity.fcEntity.attributes.name }}
### Admin State: {{ entity.fcEntity.attributes.adminSt }}
### Child Action: {{ entity.fcEntity.attributes.childAction }}
### DN: {{ entity.fcEntity.attributes.dn }}
### Last Modified: {{ entity.fcEntity.attributes.modTs }}
### Monitoring Policy DN: {{ entity.fcEntity.attributes.monPolDn }}
### Oper
#### Error: {{ entity.fcEntity.attributes.operErr }}
#### State: {{ entity.fcEntity.attributes.operSt }}
### Status: {{ entity.fcEntity.attributes.status }}
{%-     endfor %}
{%- elif "firmwareCardRunning" in api %}
# Firmware Card Running<
{%-     for card in data_to_template['imdata'] %}
## DN: {{ card.firmwareCardRunning.attributes.dn }}
### Version
#### BIOS: {{ card.firmwareCardRunning.attributes.biosVer }}
#### Expected: {{ card.firmwareCardRunning.attributes.expectedVer }}
#### Interim: {{ card.firmwareCardRunning.attributes.interimVer }}
#### Version: {{ card.firmwareCardRunning.attributes.version }}
### Child Action: {{ card.firmwareCardRunning.attributes.childAction }}
### Description: {{ card.firmwareCardRunning.attributes.descr }}
### Internal Label: {{ card.firmwareCardRunning.attributes.internalLabel }}
### Timestamp
#### Last Modified: {{ card.firmwareCardRunning.attributes.modTs }}
#### Timestamp: {{ card.firmwareCardRunning.attributes.ts }}
### Mode: {{ card.firmwareCardRunning.attributes.mode }}
### Monitoring Policy DN: {{ card.firmwareCardRunning.attributes.monPolDn }}
### Oper State: {{ card.firmwareCardRunning.attributes.operSt }}
### sr Firmware 
#### Flash
##### Rec Version: {{ card.firmwareCardRunning.attributes.srFwFlashRecVer }}
##### Version: {{ card.firmwareCardRunning.attributes.srFwFlashVer }}
#### Image Version: {{ card.firmwareCardRunning.attributes.srFwImageVer }}
#### Running
##### Source: {{ card.firmwareCardRunning.attributes.srFwRunningSrc }}
##### Version: {{ card.firmwareCardRunning.attributes.srFwRunningVer }}
### Status: {{ card.firmwareCardRunning.attributes.status }}
### Type: {{ card.firmwareCardRunning.attributes.type }}
{%-     endfor %}
{%- elif "firmwareCompRunning" in api %}
# Firmware Compute Running
{%-     for compute in data_to_template['imdata'] %}
## DN: {{ compute.firmwareCompRunning.attributes.dn }}
### Child Action: {{ compute.firmwareCompRunning.attributes.childAction }}
### Description: {{ compute.firmwareCompRunning.attributes.descr }}
### Version
#### Expected: {{ compute.firmwareCompRunning.attributes.expectedVer }}
#### Actual: {{ compute.firmwareCompRunning.attributes.version }}
### Internal Label: {{ compute.firmwareCompRunning.attributes.internalLabel }}
### Timestamp
#### Last Modified: {{ compute.firmwareCompRunning.attributes.modTs }}
#### Timestamp: {{ compute.firmwareCompRunning.attributes.ts }}
### Mode: {{ compute.firmwareCompRunning.attributes.mode }}
### Monitoring Policy DN: {{ compute.firmwareCompRunning.attributes.monPolDn }}
### Oper State: {{ compute.firmwareCompRunning.attributes.operSt }}
### Status: {{ compute.firmwareCompRunning.attributes.status }}
### Type: {{ compute.firmwareCompRunning.attributes.type }}
{%-     endfor %}
{%- elif "firmwareRunning" in api %}
# Firmware Running
{%-     for firmware in data_to_template['imdata'] %}
## DN: {{ firmware.firmwareRunning.attributes.dn }}
### BIOS
#### Timestamp: {{ firmware.firmwareRunning.attributes.biosTs }}
#### BIOS Version: {{ firmware.firmwareRunning.attributes.biosVer }}
#### PE Version: {{ firmware.firmwareRunning.attributes.peVer }}
#### Version: {{ firmware.firmwareRunning.attributes.version }}
### Child Action: {{ firmware.firmwareRunning.attributes.childAction }}
### Description: {{ firmware.firmwareRunning.attributes.descr }}
### Internal Label: {{ firmware.firmwareRunning.attributes.internalLabel }}
### File
#### Kickstart: {{ firmware.firmwareRunning.attributes.ksFile }}
#### System: {{ firmware.firmwareRunning.attributes.sysFile }}
### Timestamp
#### Last Modified: {{ firmware.firmwareRunning.attributes.modTs }}
#### Timestamp: {{ firmware.firmwareRunning.attributes.ts }}
### Mode: {{ firmware.firmwareRunning.attributes.mode }}
### sr Firmware
#### Flash
##### Rec Timestamp: {{ firmware.firmwareRunning.attributes.srFwFlashRecTs }}
##### Rec Version: {{ firmware.firmwareRunning.attributes.srFwFlashRecVer }}
##### Timestamp: {{ firmware.firmwareRunning.attributes.srFwFlashTs }}
##### Version: {{ firmware.firmwareRunning.attributes.srFwFlashVer }}
#### Image
##### Timestamp: {{ firmware.firmwareRunning.attributes.srFwImageTs }}
##### Version: {{ firmware.firmwareRunning.attributes.srFwImageVer }}
#### Running
##### Source: {{ firmware.firmwareRunning.attributes.srFwRunningSrc }}
##### Version: {{ firmware.firmwareRunning.attributes.srFwRunningVer }}
### Status: {{ firmware.firmwareRunning.attributes.status }}
### Type: {{ firmware.firmwareRunning.attributes.type }}
{%-     endfor %}
{%- elif "fvEpPCont" in api %}
# Endpoint Profile Containers
{%-     for container in data_to_template['imdata'] %}
## Name: {{ container.fvEpPCont.attributes.name }}
### Name Alias: {{ container.fvEpPCont.attributes.nameAlias }}
### Aggregation Enabled: {{ container.fvEpPCont.attributes.aggrEnabled }}
### Child Action: {{ container.fvEpPCont.attributes.childAction }}
### DN: {{ container.fvEpPCont.attributes.dn }}
### Local Owner: {{ container.fvEpPCont.attributes.lcOwn }}
### Last Modified: {{ container.fvEpPCont.attributes.modTs }}
### Monitoring Policy DN: {{ container.fvEpPCont.attributes.monPolDn }}
### Owner
#### Key: {{ container.fvEpPCont.attributes.ownerKey }}
#### Tag: {{ container.fvEpPCont.attributes.ownerTag }}
### Status: {{ container.fvEpPCont.attributes.status }}
{%-     endfor %}
{%- elif "fvLocale" in api %}
# Locales
{%-     for locale in data_to_template['imdata'] %}
## ID: {{ locale.fvLocale.attributes.id }}
### Bootstrap Triggered: {{ locale.fvLocale.attributes.boostrapTriggered }}
### Child Action: {{ locale.fvLocale.attributes.childAction }}
### Deploy All Ports: {{ locale.fvLocale.attributes.deployAllPorts }}
### DN: {{ locale.fvLocale.attributes.dn }}
### Fabric Ext
#### Control Peering: {{ locale.fvLocale.attributes.fabricExtCtrlPeering }}
#### Intersite Control Peering: {{ locale.fvLocale.attributes.fabricExtIntersiteCtrlPeering }}
#### Intersite Peering: {{ locale.fvLocale.attributes.fabricExtIntersitePeering }}
### First Update Deployed: {{ locale.fvLocale.attributes.firstUpdateDeployed }}
### Instruction Immediacy: {{ locale.fvLocale.attributes.instrImedcy }}
### IP Load Balancer Address
#### v4: {{ locale.fvLocale.attributes.ipv4LbAddr }}
#### v6: {{ locale.fvLocale.attributes.ipv6LbAddr }}
### Local Owner: {{ locale.fvLocale.attributes.lcOwn }}
### Last Modified: {{ locale.fvLocale.attributes.modTs }}
### Mode Misconfiguration: {{ locale.fvLocale.attributes.modeMisconfiguration }}
### Monitoring Policy DN: {{ locale.fvLocale.attributes.monPolDn }}
### Oper State: {{ locale.fvLocale.attributes.operSt }}
### Router
#### ID: {{ locale.fvLocale.attributes.rtrId }}
#### ID Loopback: {{ locale.fvLocale.attributes.rtrIdLoopBack }}
### Status: {{ locale.fvLocale.attributes.status }}
### Summary Needed: {{ locale.fvLocale.attributes.summaryNeeded }}
{%-     endfor %}
{%- elif "fvRsBDToOut" in api %}
# Bridge Domains To Outside
{%-     for bd in data_to_template['imdata'] %}
## UID: {{ bd.fvRsBDToOut.attributes.uid }}
### Annotation: {{ bd.fvRsBDToOut.attributes.annotation }}
### Child Action: {{ bd.fvRsBDToOut.attributes.childAction }}
### DN: {{ bd.fvRsBDToOut.attributes.dn }}
### Externally Managed By: {{ bd.fvRsBDToOut.attributes.extMngdBy }}
### Force Resolve: {{ bd.fvRsBDToOut.attributes.forceResolve }}
### Local Owner: {{ bd.fvRsBDToOut.attributes.lcOwn }}
### Last Modified: {{ bd.fvRsBDToOut.attributes.modTs }}
### Monitoring Policy DN: {{ bd.fvRsBDToOut.attributes.monPolDn }}
### rType: {{ bd.fvRsBDToOut.attributes.rType }}
### State: {{ bd.fvRsBDToOut.attributes.state }}
### State Quality: {{ bd.fvRsBDToOut.attributes.stateQual }}
### Status: {{ bd.fvRsBDToOut.attributes.status }}
### t
#### Cl: {{ bd.fvRsBDToOut.attributes.tCl }}
#### Context DN: {{ bd.fvRsBDToOut.attributes.tContextDn }}
#### DN: {{ bd.fvRsBDToOut.attributes.tDn }}
#### RN: {{ bd.fvRsBDToOut.attributes.tRn }}
#### Type: {{ bd.fvRsBDToOut.attributes.tType }}
### tn L3 Ext Out Name: {{ bd.fvRsBDToOut.attributes.tnL3extOutName }}
{%-     endfor %}
{%- elif "fvRsBd" in api %}
# EPG Bridge Domain Links
{%-     for bd in data_to_template['imdata'] %}
## UID: {{ bd.fvRsBd.attributes.uid }}
### Annotation: {{ bd.fvRsBd.attributes.annotation }}
### Child Action: {{ bd.fvRsBd.attributes.childAction }}
### DN: {{ bd.fvRsBd.attributes.dn }}
### Externally Managed By: {{ bd.fvRsBd.attributes.extMngdBy }}
### Force Resolve: {{ bd.fvRsBd.attributes.forceResolve }}
### Local Owner: {{ bd.fvRsBd.attributes.lcOwn }}
### Last Modified: {{ bd.fvRsBd.attributes.modTs }}
### Monitoring Policy DN: {{ bd.fvRsBd.attributes.monPolDn }}
### rType: {{ bd.fvRsBd.attributes.rType }}
### State: {{ bd.fvRsBd.attributes.state }}
### State Quality: {{ bd.fvRsBd.attributes.stateQual }}
### Status: {{ bd.fvRsBd.attributes.status }}
### t
#### Cl: {{ bd.fvRsBd.attributes.tCl }}
#### Context DN: {{ bd.fvRsBd.attributes.tContextDn }}
#### DN: {{ bd.fvRsBd.attributes.tDn }}
#### RN: {{ bd.fvRsBd.attributes.tRn }}
#### Type: {{ bd.fvRsBd.attributes.tType }}
### Fv BD Name: {{ bd.fvRsBd.attributes.tnFvBDName }}
{%-     endfor %}
{%- elif "fvRsCEpToPathEp" in api %}
# Endpoints To Paths
{%-     for endpoint in data_to_template['imdata'] %}
## DN: {{ endpoint.fvRsCEpToPathEp.attributes.dn }}
### Child Action: {{ endpoint.fvRsCEpToPathEp.attributes.childAction }}
### Force Resolve: {{ endpoint.fvRsCEpToPathEp.attributes.forceResolve }}
### lcC: {{ endpoint.fvRsCEpToPathEp.attributes.lcC }}
### Local Owner: {{ endpoint.fvRsCEpToPathEp.attributes.lcOwn }}
### Last Modified: {{ endpoint.fvRsCEpToPathEp.attributes.modTs }}
### rType: {{ endpoint.fvRsCEpToPathEp.attributes.rType }}
### State: {{ endpoint.fvRsCEpToPathEp.attributes.state }}
### State Quality: {{ endpoint.fvRsCEpToPathEp.attributes.stateQual }}
### Status: {{ endpoint.fvRsCEpToPathEp.attributes.status }}
### t
#### Cl: {{ endpoint.fvRsCEpToPathEp.attributes.tCl }}
#### DN: {{ endpoint.fvRsCEpToPathEp.attributes.tDn }}
#### Type: {{ endpoint.fvRsCEpToPathEp.attributes.tType }}
{%-     endfor %}
{%- elif "fvRsCons" in api %}
{%-     if "If" in api %}
# Contract Consumer Interfaces
{%-         for interface in data_to_template['imdata'] %}
## UID: {{ interface.fvRsConsIf.attributes.uid }}
### Annotation: {{ interface.fvRsConsIf.attributes.annotation }}
### Child Action: {{ interface.fvRsConsIf.attributes.childAction }}
### Deployment Info: {{ interface.fvRsConsIf.attributes.deplInfo }}
### DN: {{ interface.fvRsConsIf.attributes.dn }}
### Externally Managed By: {{ interface.fvRsConsIf.attributes.extMngdBy }}
### Force Resolve: {{ interface.fvRsConsIf.attributes.forceResolve }}
### Local Owner: {{ interface.fvRsConsIf.attributes.lcOwn }}
### Last Modified: {{ interface.fvRsConsIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.fvRsConsIf.attributes.monPolDn }}
### Priority: {{ interface.fvRsConsIf.attributes.prio }}
### rType: {{ interface.fvRsConsIf.attributes.rType }}
### State: {{ interface.fvRsConsIf.attributes.state }}
### State Quality: {{ interface.fvRsConsIf.attributes.stateQual }}
### Status: {{ interface.fvRsConsIf.attributes.status }}
### t
#### Cl: {{ interface.fvRsConsIf.attributes.tCl }}
#### Context DN: {{ interface.fvRsConsIf.attributes.tContextDn }}
#### DN: {{ interface.fvRsConsIf.attributes.tDn }}
#### RN: {{ interface.fvRsConsIf.attributes.tRn }}
#### Type: {{ interface.fvRsConsIf.attributes.tType }}
### tnVz CP Interface Name: {{ interface.fvRsConsIf.attributes.tnVzCPIfName }}
### Update Collection: {{ interface.fvRsConsIf.attributes.updateCollection }}
{%-         endfor %}
{%-     else %}
# Contract Consumers
{%-         for consumer in data_to_template['imdata'] %}
## UID: {{ consumer.fvRsCons.attributes.uid }}
### Annotation: {{ consumer.fvRsCons.attributes.annotation }}
### Child Action: {{ consumer.fvRsCons.attributes.childAction }}
### Contract Update: {{ consumer.fvRsCons.attributes.ctrctUpd }}
### Deployment Info: {{ consumer.fvRsCons.attributes.deplInfo }}
### DN: {{ consumer.fvRsCons.attributes.dn }}
### Externally Managed By: {{ consumer.fvRsCons.attributes.extMngdBy }}
### Force Resolve: {{ consumer.fvRsCons.attributes.forceResolve }}
### Intent: {{ consumer.fvRsCons.attributes.intent }}
### Local Owner: {{ consumer.fvRsCons.attributes.lcOwn }}
### Last Modified: {{ consumer.fvRsCons.attributes.modTs }}
### Monitoring Policy DN: {{ consumer.fvRsCons.attributes.monPolDn }}
### Priority: {{ consumer.fvRsCons.attributes.prio }}
### rType: {{ consumer.fvRsCons.attributes.rType }}
### State: {{ consumer.fvRsCons.attributes.state }}
### State Quality: {{ consumer.fvRsCons.attributes.stateQual }}
### Status: {{ consumer.fvRsCons.attributes.status }}
### t
#### Cl: {{ consumer.fvRsCons.attributes.tCl }}
#### Context DN: {{ consumer.fvRsCons.attributes.tContextDn }}
#### DN: {{ consumer.fvRsCons.attributes.tDn }}
#### RN: {{ consumer.fvRsCons.attributes.tRn }}
#### Type: {{ consumer.fvRsCons.attributes.tType }}
### tnVz Br CP Name: {{ consumer.fvRsCons.attributes.tnVzBrCPName }}
### Trigger State: {{ consumer.fvRsCons.attributes.triggerSt }}
### Update Collection: {{ consumer.fvRsCons.attributes.updateCollection }}
{%-         endfor %}
{%-     endif %}
{%- elif "fvRsCtx" in api %}
# Context Source Relationships
{%-     for context in data_to_template['imdata'] %}
## UID: {{ context.fvRsCtx.attributes.uid }}
### Annotation: {{ context.fvRsCtx.attributes.annotation }}
### Child Action: {{ context.fvRsCtx.attributes.childAction }}
### DN: {{ context.fvRsCtx.attributes.dn }}
### Externally Managed By: {{ context.fvRsCtx.attributes.extMngdBy }}
### Force Resolve: {{ context.fvRsCtx.attributes.forceResolve }}
### Local Owner: {{ context.fvRsCtx.attributes.lcOwn }}
### Last Modified: {{ context.fvRsCtx.attributes.modTs }}
### Monitoring Policy DN: {{ context.fvRsCtx.attributes.monPolDn }}
### rType: {{ context.fvRsCtx.attributes.rType }}
### State: {{ context.fvRsCtx.attributes.state }}
### State Quality: {{ context.fvRsCtx.attributes.stateQual }}
### Status: {{ context.fvRsCtx.attributes.status }}
### t
#### Cl: {{ context.fvRsCtx.attributes.tCl }}
#### Context DN: {{ context.fvRsCtx.attributes.tContextDn }}
#### DN: {{ context.fvRsCtx.attributes.tDn }}
#### RN: {{ context.fvRsCtx.attributes.tRn }}
#### Type: {{ context.fvRsCtx.attributes.tType }}
### tnFv Context Name: {{ context.fvRsCtx.attributes.tnFvCtxName }}
{%-     endfor %}
{%- elif "fvRsDomAtt" in api %}
# Domain Attachments
{%-     for attachment in data_to_template['imdata'] %}
## UID: {{ attachment.fvRsDomAtt.attributes.uid }}
### Annotation: {{ attachment.fvRsDomAtt.attributes.annotation }}
### Binding Type: {{ attachment.fvRsDomAtt.attributes.bindingType }}
### Child Action: {{ attachment.fvRsDomAtt.attributes.childAction }}
### Class Preference: {{ attachment.fvRsDomAtt.attributes.classPref }}
### Config Issues: {{ attachment.fvRsDomAtt.attributes.configIssues }}
### Delimeter: {{ attachment.fvRsDomAtt.attributes.delimiter }}
### DN: {{ attachment.fvRsDomAtt.attributes.dn }}
### Encapsulation
#### Encapsulation: {{ attachment.fvRsDomAtt.attributes.encap }}
#### Mode: {{ attachment.fvRsDomAtt.attributes.encapMode }}
#### Primary: {{ attachment.fvRsDomAtt.attributes.primaryEncap }}
#### Primary Inner: {{ attachment.fvRsDomAtt.attributes.primaryEncapInner }}
#### Secondary Inner: {{ attachment.fvRsDomAtt.attributes.secondaryEncapInner }}
### EPG
#### Custom EPG Name: {{ attachment.fvRsDomAtt.attributes.customEpgName }}
#### COS: {{ attachment.fvRsDomAtt.attributes.epgCos }}
#### COS Preferred: {{ attachment.fvRsDomAtt.attributes.epgCosPref }}
### Externally Managed By: {{ attachment.fvRsDomAtt.attributes.extMngdBy }}
### Force Resolve: {{ attachment.fvRsDomAtt.attributes.forceResolve }}
### Instruction Immediacy: {{ attachment.fvRsDomAtt.attributes.instrImedcy }}
### LAG Policy Name: {{ attachment.fvRsDomAtt.attributes.lagPolicyName }}
### Local Owner: {{ attachment.fvRsDomAtt.attributes.lcOwn }}
### Last Modified: {{ attachment.fvRsDomAtt.attributes.modTs }}
### Mode: {{ attachment.fvRsDomAtt.attributes.mode }}
### Monitoring Policy DN: {{ attachment.fvRsDomAtt.attributes.monPolDn }}
### Netflow
#### Direction: {{ attachment.fvRsDomAtt.attributes.netflowDir }}
#### Preferred: {{ attachment.fvRsDomAtt.attributes.netflowPref }}
### Number of Ports: {{ attachment.fvRsDomAtt.attributes.numPorts }}
### Port Allocation: {{ attachment.fvRsDomAtt.attributes.portAllocation }}
### rType: {{ attachment.fvRsDomAtt.attributes.rType }}
### Res Immediacy: {{ attachment.fvRsDomAtt.attributes.resImedcy }}
### State: {{ attachment.fvRsDomAtt.attributes.state }}
### State Quality: {{ attachment.fvRsDomAtt.attributes.stateQual }}
### Status: {{ attachment.fvRsDomAtt.attributes.status }}
### Switching Mode: {{ attachment.fvRsDomAtt.attributes.switchingMode }}
### t
#### Cl: {{ attachment.fvRsDomAtt.attributes.tCl }}
#### DN: {{ attachment.fvRsDomAtt.attributes.tDn }}
#### Type: {{ attachment.fvRsDomAtt.attributes.tType }}
### Trigger State: {{ attachment.fvRsDomAtt.attributes.triggerSt }}
### TX ID: {{ attachment.fvRsDomAtt.attributes.txId }}
### Untagged: {{ attachment.fvRsDomAtt.attributes.untagged }}
### VNET Only: {{ attachment.fvRsDomAtt.attributes.vnetOnly }}
{%-     endfor %}
{%- elif "fvRsPathAtt" in api %}
# Path Attachments
{%-     for attachment in data_to_template['imdata'] %}
## UID: {{ attachment.fvRsPathAtt.attributes.uid }}
### Annotation: {{ attachment.fvRsPathAtt.attributes.annotation }}
### Child Action: {{ attachment.fvRsPathAtt.attributes.childAction }}
### Description: {{ attachment.fvRsPathAtt.attributes.descr }}
### DN: {{ attachment.fvRsPathAtt.attributes.dn }}
### Encapsulation: {{ attachment.fvRsPathAtt.attributes.encap }}
### Externally Managed By: {{ attachment.fvRsPathAtt.attributes.extMngdBy }}
### Force Resolve: {{ attachment.fvRsPathAtt.attributes.forceResolve }}
### Instruction Immediacy: {{ attachment.fvRsPathAtt.attributes.instrImedcy }}
### lcC: {{ attachment.fvRsPathAtt.attributes.lcC }}
### Local Owner: {{ attachment.fvRsPathAtt.attributes.lcOwn }}
### Last Modified: {{ attachment.fvRsPathAtt.attributes.modTs }}
### Mode: {{ attachment.fvRsPathAtt.attributes.mode }}
### Monitoring Policy DN: {{ attachment.fvRsPathAtt.attributes.monPolDn }}
### Primary Encapsulation: {{ attachment.fvRsPathAtt.attributes.primaryEncap }}
### rType: {{ attachment.fvRsPathAtt.attributes.rType }}
### State: {{ attachment.fvRsPathAtt.attributes.state }}
### State Quality: {{ attachment.fvRsPathAtt.attributes.stateQual }}
### Status: {{ attachment.fvRsPathAtt.attributes.status }}
### t
#### Cl: {{ attachment.fvRsPathAtt.attributes.tCl }}
#### DN: {{ attachment.fvRsPathAtt.attributes.tDn }}
#### Type: {{ attachment.fvRsPathAtt.attributes.tType }}
{%-     endfor %}
{%- elif "fvRsProv" in api %}
# Contract Providers
{%-     for provider in data_to_template['imdata'] %}
## UID: {{ provider.fvRsProv.attributes.uid }}
### Annotation: {{ provider.fvRsProv.attributes.annotation }}
### Child Action: {{ provider.fvRsProv.attributes.childAction }}
### Contract Update: {{ provider.fvRsProv.attributes.ctrctUpd }}
### DN: {{ provider.fvRsProv.attributes.dn }}
### Externally Managed By: {{ provider.fvRsProv.attributes.extMngdBy }}
### Force Resolve: {{ provider.fvRsProv.attributes.forceResolve }}
### Intent: {{ provider.fvRsProv.attributes.intent }}
### Local Owner: {{ provider.fvRsProv.attributes.lcOwn }}
### Match Type: {{ provider.fvRsProv.attributes.matchT }}
### Last Modified: {{ provider.fvRsProv.attributes.modTs }}
### Monitoring Policy DN: {{ provider.fvRsProv.attributes.monPolDn }}
### Priority: {{ provider.fvRsProv.attributes.prio }}
### rType: {{ provider.fvRsProv.attributes.rType }}
### State: {{ provider.fvRsProv.attributes.state }}
### State Quality: {{ provider.fvRsProv.attributes.stateQual }}
### Status: {{ provider.fvRsProv.attributes.status }}
### t
#### Cl: {{ provider.fvRsProv.attributes.tCl }}
#### Context DN: {{ provider.fvRsProv.attributes.tContextDn }}
#### DN: {{ provider.fvRsProv.attributes.tDn }}
#### RN: {{ provider.fvRsProv.attributes.tRn }}
#### Type: {{ provider.fvRsProv.attributes.tType }}
### tnVz Br CP Name: {{ provider.fvRsProv.attributes.tnVzBrCPName }}
### Trigger State: {{ provider.fvRsProv.attributes.triggerSt }}
### Update Collection: {{ provider.fvRsProv.attributes.updateCollection }}
{%-     endfor %}
{%- elif "fvRtBd" in api %}
# Bridge Domain Target Relationships
{%-     for bd in data_to_template['imdata'] %}
## DN: {{ bd.fvRtBd.attributes.dn }}
### Child Action: {{ bd.fvRtBd.attributes.childAction }}
### Local Owner: {{ bd.fvRtBd.attributes.lcOwn }}
### Last Modified: {{ bd.fvRtBd.attributes.modTs }}
### Status: {{ bd.fvRtBd.attributes.status }}
### tCl: {{ bd.fvRtBd.attributes.tCl }}
### tDN: {{ bd.fvRtBd.attributes.tDn }}
{%-     endfor %}
{%- elif "fvRtCtx" in api %}
# Contexts Target Relationships
{%-     for context in data_to_template['imdata'] %}
## DN: {{ context.fvRtCtx.attributes.dn }}
### Child Action: {{ context.fvRtCtx.attributes.childAction }}
### Local Owner: {{ context.fvRtCtx.attributes.lcOwn }}
### Last Modified: {{ context.fvRtCtx.attributes.modTs }}
### Status: {{ context.fvRtCtx.attributes.status }}
### tCl: {{ context.fvRtCtx.attributes.tCl }}
### tDN: {{ context.fvRtCtx.attributes.tDn }}
{%-     endfor %}
{%- elif "fvnsEncapBlk" in api %}
# VLAN Encapsulation Blocks
{%-     for vlan in data_to_template['imdata'] %}
## Name: {{ vlan.fvnsEncapBlk.attributes.name }}
### Name Alias: {{ vlan.fvnsEncapBlk.attributes.nameAlias }}
### Allocation Mode: {{ vlan.fvnsEncapBlk.attributes.allocMode }}
### Annotation: {{ vlan.fvnsEncapBlk.attributes.annotation }}
### Child Action: {{ vlan.fvnsEncapBlk.attributes.childAction }}
### Description: {{ vlan.fvnsEncapBlk.attributes.descr }}
### DN: {{ vlan.fvnsEncapBlk.attributes.dn }}
### Externally Managed By: {{ vlan.fvnsEncapBlk.attributes.extMngdBy }}
### Scope
#### From: {{ vlan.fvnsEncapBlk.attributes.from }}
#### To: {{ vlan.fvnsEncapBlk.attributes.to }}
### Local Owner: {{ vlan.fvnsEncapBlk.attributes.lcOwn }}
### Last Modified: {{ vlan.fvnsEncapBlk.attributes.modTs }}
### Monitoring Policy DN: {{ vlan.fvnsEncapBlk.attributes.monPolDn }}
### Role: {{ vlan.fvnsEncapBlk.attributes.role }}
### Status: {{ vlan.fvnsEncapBlk.attributes.status }}
### UID: {{ vlan.fvnsEncapBlk.attributes.uid }}
{%-     endfor %}
{%- elif "fvnsVlanInstP" in api %}
# VLAN Namespace Policies
{%-     for policy in data_to_template['imdata'] %}
## Name: {{ policy.fvnsVlanInstP.attributes.name }}
### Name Alias: {{ policy.fvnsVlanInstP.attributes.nameAlias }}
### Allocation Mode: {{ policy.fvnsVlanInstP.attributes.allocMode }}
### Annotation: {{ policy.fvnsVlanInstP.attributes.annotation }}
### Child Action: {{ policy.fvnsVlanInstP.attributes.childAction }}
### Config Issues: {{ policy.fvnsVlanInstP.attributes.configIssues }}
### Description: {{ policy.fvnsVlanInstP.attributes.descr }}
### DN: {{ policy.fvnsVlanInstP.attributes.dn }}
### Externally Managed By: {{ policy.fvnsVlanInstP.attributes.extMngdBy }}
### Local Owner: {{ policy.fvnsVlanInstP.attributes.lcOwn }}
### Last Modified: {{ policy.fvnsVlanInstP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.fvnsVlanInstP.attributes.monPolDn }}
### Owner
#### Key: {{ policy.fvnsVlanInstP.attributes.ownerKey }}
#### Tag: {{ policy.fvnsVlanInstP.attributes.ownerTag }}
### Status: {{ policy.fvnsVlanInstP.attributes.status }}
### UID: {{ policy.fvnsVlanInstP.attributes.uid }}
{%-     endfor %}
{%- elif "infraAccBndlGrp" in api %}
# Access Bundle Groups
{%-     for group in data_to_template['imdata'] %}
## Name: {{ group.infraAccBndlGrp.attributes.name }}
### Name Alias: {{ group.infraAccBndlGrp.attributes.nameAlias }}
### Annotation: {{ group.infraAccBndlGrp.attributes.annotation }}
### Child Action: {{ group.infraAccBndlGrp.attributes.childAction }}
### Description: {{ group.infraAccBndlGrp.attributes.descr }}
### DN: {{ group.infraAccBndlGrp.attributes.dn }}
### Externally Managed By: {{ group.infraAccBndlGrp.attributes.extMngdBy }}
### LAG Type: {{ group.infraAccBndlGrp.attributes.lagT }}
### Local Owner: {{ group.infraAccBndlGrp.attributes.lcOwn }}
### Last Modified: {{ group.infraAccBndlGrp.attributes.modTs }}
### Monitoring Policy DN: {{ group.infraAccBndlGrp.attributes.monPolDn }}
### Owner
#### Key: {{ group.infraAccBndlGrp.attributes.ownerKey }}
#### Tag: {{ group.infraAccBndlGrp.attributes.ownerTag }}
### Status: {{ group.infraAccBndlGrp.attributes.status }}
### UID: {{ group.infraAccBndlGrp.attributes.uid }}
{%-     endfor %}
{%- elif "infraAccPortGrp" in api %}
# Access Port Groups
{%-     for group in data_to_template['imdata'] %}
## Name: {{ group.infraAccPortGrp.attributes.name }}
### Name Alias: {{ group.infraAccPortGrp.attributes.nameAlias }}
### Annotation: {{ group.infraAccPortGrp.attributes.annotation }}
### Child Action: {{ group.infraAccPortGrp.attributes.childAction }}
### Description: {{ group.infraAccPortGrp.attributes.descr }}
### DN: {{ group.infraAccPortGrp.attributes.dn }}
### Externally Managed By: {{ group.infraAccPortGrp.attributes.extMngdBy }}
### Local Owner: {{ group.infraAccPortGrp.attributes.lcOwn }}
### Last Modified: {{ group.infraAccPortGrp.attributes.modTs }}
### Monitoring Policy DN: {{ group.infraAccPortGrp.attributes.monPolDn }}
### Owner
#### Key: {{ group.infraAccPortGrp.attributes.ownerKey }}
#### Tag: {{ group.infraAccPortGrp.attributes.ownerTag }}
### Status: {{ group.infraAccPortGrp.attributes.status }}
### UID: {{ group.infraAccPortGrp.attributes.uid }}
{%-     endfor %}
{%- elif "infraAccPortP" in api %}
# Access Port Groups
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.infraAccPortP.attributes.name }}
### Name Alias: {{ profile.infraAccPortP.attributes.nameAlias }}
### Annotation: {{ profile.infraAccPortP.attributes.annotation }}
### Child Action: {{ profile.infraAccPortP.attributes.childAction }}
### Description: {{ profile.infraAccPortP.attributes.descr }}
### DN: {{ profile.infraAccPortP.attributes.dn }}
### Externally Managed By: {{ profile.infraAccPortP.attributes.extMngdBy }}
### Local Owner: {{ profile.infraAccPortP.attributes.lcOwn }}
### Last Modified: {{ profile.infraAccPortP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.infraAccPortP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.infraAccPortP.attributes.ownerKey }}
#### Tag: {{ profile.infraAccPortP.attributes.ownerTag }}
### Status: {{ profile.infraAccPortP.attributes.status }}
### UID: {{ profile.infraAccPortP.attributes.uid }}
{%-     endfor %}
{%- elif "infraCont" in api %}
<h1>Controllers</h1>
<table id = "datatable">
<thead>
  <tr>
    <th>Name</th>
    <th>Name Alias</th>
    <th>Child Action</th>
    <th>DN</th>
    <th>DRR Mode</th>
    <th>DSCV Mode</th>
    <th>Fabric Domain Name</th>
    <th>Local Owner</th>
    <th>Last Modified</th>
    <th>Monitoring Policy DN</th>
    <th>Size</th>
    <th>Status</th>
    <th>Start Timestamp</th>
    <th>UCT Difference</th>
  </tr>
</thead>
<tbody>
{%-     for controller in data_to_template['imdata'] %}
  <tr>
    <td>{{ controller.infraCont.attributes.name }}</td>
    <td>{{ controller.infraCont.attributes.nameAlias }}</td>
    <td>{{ controller.infraCont.attributes.childAction }}</td>
    <td>{{ controller.infraCont.attributes.dn }}</td>
    <td>{{ controller.infraCont.attributes.drrMd }}</td>
    <td>{{ controller.infraCont.attributes.dscvMd }}</td>
    <td>{{ controller.infraCont.attributes.fbDmNm }}</td>
    <td>{{ controller.infraCont.attributes.lcOwn }}</td>
    <td>{{ controller.infraCont.attributes.modTs }}</td>
    <td>{{ controller.infraCont.attributes.monPolDn }}</td>
    <td>{{ controller.infraCont.attributes.size }}</td>
    <td>{{ controller.infraCont.attributes.status }}</td>
    <td>{{ controller.infraCont.attributes.strtTs }}</td>
    <td>{{ controller.infraCont.attributes.uctDiff }}</td>
  </tr>
{%-     endfor %}
{%- elif "infraCont" in api %}
# Controllers
{%-     for controller in data_to_template['imdata'] %}
## Name: {{ controller.infraCont.attributes.name }}
### Name Alias: {{ controller.infraCont.attributes.nameAlias }}
### Child Action: {{ controller.infraCont.attributes.childAction }}
### DN: {{ controller.infraCont.attributes.dn }}
### Mode
#### DRR: {{ controller.infraCont.attributes.drrMd }}
#### DSCV: {{ controller.infraCont.attributes.dscvMd }}
### Fabric Name: {{ controller.infraCont.attributes.fbDmNm }}
### Local Owner: {{ controller.infraCont.attributes.lcOwn }}
### Timestamp
#### Last Modified: {{ controller.infraCont.attributes.modTs }}
#### Start: {{ controller.infraCont.attributes.strtTs }}
### Monitoring Policy DN: {{ controller.infraCont.attributes.monPolDn }}
### Size: {{ controller.infraCont.attributes.size }}
### Status: {{ controller.infraCont.attributes.status }}
### UCT Difference: {{ controller.infraCont.attributes.uctDiff }}
{%-     endfor %}
{%- elif "infraFexP" in api %}
# FEX Policies
{%-     for policy in data_to_template['imdata'] %}
## Name: {{ policy.infraFexP.attributes.name }}
### Name Alias: {{ policy.infraFexP.attributes.nameAlias }}
### Annotation: {{ policy.infraFexP.attributes.annotation }}
### Child Action: {{ policy.infraFexP.attributes.childAction }}
### Description: {{ policy.infraFexP.attributes.descr }}
### DN: {{ policy.infraFexP.attributes.dn }}
### Externally Managed By: {{ policy.infraFexP.attributes.extMngdBy }}
### Local Owner: {{ policy.infraFexP.attributes.lcOwn }}
### Last Modified: {{ policy.infraFexP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraFexP.attributes.monPolDn }}
### Owner
#### Key: {{ policy.infraFexP.attributes.ownerKey }}
#### Tag: {{ policy.infraFexP.attributes.ownerTag }}
### Status: {{ policy.infraFexP.attributes.status }}
### UID: {{ policy.infraFexP.attributes.uid }}
{%-     endfor %}
{%- elif "infraFuncP" in api %}
# Function Policies
{%-     for function in data_to_template['imdata'] %}
## Name: {{ function.infraFuncP.attributes.name }}
### Name Alias: {{ function.infraFuncP.attributes.nameAlias }}
### Annotation: {{ function.infraFuncP.attributes.annotation }}
### Child Action: {{ function.infraFuncP.attributes.childAction }}
### Description: {{ function.infraFuncP.attributes.descr }}
### DN: {{ function.infraFuncP.attributes.dn }}
### Externally Managed By: {{ function.infraFuncP.attributes.extMngdBy }}
### Local Owner: {{ function.infraFuncP.attributes.lcOwn }}
### Last Modified: {{ function.infraFuncP.attributes.modTs }}
### Monitoring Policy DN: {{ function.infraFuncP.attributes.monPolDn }}
### Owner
#### Key: {{ function.infraFuncP.attributes.ownerKey }}
#### Tag: {{ function.infraFuncP.attributes.ownerTag }}
### Status: {{ function.infraFuncP.attributes.status }}
### UID: {{ function.infraFuncP.attributes.uid }}
{%-     endfor %}
{%- elif "infraFuncP" in api %}
# Host Port Selectors
{%-     for port in data_to_template['imdata'] %}
## Name: {{ port.infraHPortS.attributes.name }}
### Name Alias: {{ port.infraHPortS.attributes.nameAlias }}
### Annotation: {{ port.infraHPortS.attributes.annotation }}
### Child Action: {{ port.infraHPortS.attributes.childAction }}
### Description: {{ port.infraHPortS.attributes.descr }}
### DN: {{ port.infraHPortS.attributes.dn }}
### Externally Managed By: {{ port.infraHPortS.attributes.extMngdBy }}
### Local Owner: {{ port.infraHPortS.attributes.lcOwn }}
### Last Modified: {{ port.infraHPortS.attributes.modTs }}
### Monitoring Policy DN: {{ port.infraHPortS.attributes.monPolDn }}
### Owner
#### Key: {{ port.infraHPortS.attributes.ownerKey }}
#### Tag: {{ port.infraHPortS.attributes.ownerTag }}
### Status: {{ port.infraHPortS.attributes.status }}
### Type: {{ port.infraHPortS.attributes.type }}
### UID: {{ port.infraHPortS.attributes.uid }}
{%-     endfor %}
{%- elif "infraPortBlk" in api %}
# Port Blocks
{%-     for port_block in data_to_template['imdata'] %}
## Name: {{ port_block.infraPortBlk.attributes.name }}
### Name Alias: {{ port_block.infraPortBlk.attributes.nameAlias }}
### Annotation: {{ port_block.infraPortBlk.attributes.annotation }}
### Child Action: {{ port_block.infraPortBlk.attributes.childAction }}
### Description: {{ port_block.infraPortBlk.attributes.descr }}
### DN: {{ port_block.infraPortBlk.attributes.dn }}
### Externally Managed By: {{ port_block.infraPortBlk.attributes.extMngdBy }}
### Card Range
#### From: {{ port_block.infraPortBlk.attributes.fromCard }}
#### To: {{ port_block.infraPortBlk.attributes.toCard }}
### Port Range
#### From: {{ port_block.infraPortBlk.attributes.fromPort }}
#### To: {{ port_block.infraPortBlk.attributes.toPort }}
### Local Owner: {{ port_block.infraPortBlk.attributes.lcOwn }}
### Last Modifed: {{ port_block.infraPortBlk.attributes.modTs }}
### Monitoring Policy DN: {{ port_block.infraPortBlk.attributes.monPolDn }}
### Status: {{ port_block.infraPortBlk.attributes.status }}
### UID: {{ port_block.infraPortBlk.attributes.uid }}
{%-     endfor %}
{%- elif "infraRsAccBaseGrp" in api %}
# Access Policy Group Source Relationships
{%-     for policy in data_to_template['imdata'] %}
## UID: {{ policy.infraRsAccBaseGrp.attributes.uid }}
### Annotation: {{ policy.infraRsAccBaseGrp.attributes.annotation }}
### Child Action: {{ policy.infraRsAccBaseGrp.attributes.childAction }}
### DN: {{ policy.infraRsAccBaseGrp.attributes.dn }}
### Externally Managed By: {{ policy.infraRsAccBaseGrp.attributes.extMngdBy }}
### FEX ID: {{ policy.infraRsAccBaseGrp.attributes.fexId }}
### Force Resolve: {{ policy.infraRsAccBaseGrp.attributes.forceResolve }}
### Local Owner: {{ policy.infraRsAccBaseGrp.attributes.lcOwn }}
### Last Modifed: {{ policy.infraRsAccBaseGrp.attributes.modTs }}
### Monitoring Policy DN: {{ policy.infraRsAccBaseGrp.attributes.monPolDn }}
### rType: {{ policy.infraRsAccBaseGrp.attributes.rType }}
### State: {{ policy.infraRsAccBaseGrp.attributes.state }}
### State Quality: {{ policy.infraRsAccBaseGrp.attributes.stateQual }}
### Status: {{ policy.infraRsAccBaseGrp.attributes.status }}
### t
#### Cl: {{ policy.infraRsAccBaseGrp.attributes.tCl }}
#### DN: {{ policy.infraRsAccBaseGrp.attributes.tDn }}
#### Type: {{ policy.infraRsAccBaseGrp.attributes.tType }}
{%-     endfor %}
{%- elif "infraRsAttEntP" in api %}
# Attachable Entity Profiles Source Relationships
{%-     for profile in data_to_template['imdata'] %}
## UID: {{ profile.infraRsAttEntP.attributes.uid }}
### Annotation: {{ profile.infraRsAttEntP.attributes.annotation }}
### Child Action: {{ profile.infraRsAttEntP.attributes.childAction }}
### DN: {{ profile.infraRsAttEntP.attributes.dn }}
### Externally Managed By: {{ profile.infraRsAttEntP.attributes.extMngdBy }}
### Force Resolve: {{ profile.infraRsAttEntP.attributes.forceResolve }}
### Is Using Connection Selector: {{ profile.infraRsAttEntP.attributes.isUsingConnSel }}
### Local Owner: {{ profile.infraRsAttEntP.attributes.lcOwn }}
### Last Modifed: {{ profile.infraRsAttEntP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.infraRsAttEntP.attributes.monPolDn }}
### rType: {{ profile.infraRsAttEntP.attributes.rType }}
### State: {{ profile.infraRsAttEntP.attributes.state }}
### State Quality: {{ profile.infraRsAttEntP.attributes.stateQual }}
### Status: {{ profile.infraRsAttEntP.attributes.status }}
### t
#### Cl: {{ profile.infraRsAttEntP.attributes.tCl }}
#### DN: {{ profile.infraRsAttEntP.attributes.tDn }}
#### Type: {{ profile.infraRsAttEntP.attributes.tType }}
{%-     endfor %}
{%- elif "infraRsDomP" in api %}
# Domain Profiles Source Relationships
{%-     for profile in data_to_template['imdata'] %}
## UID: {{ profile.infraRsDomP.attributes.uid }}
### Annotation: {{ profile.infraRsDomP.attributes.annotation }}
### Child Action: {{ profile.infraRsDomP.attributes.childAction }}
### DN: {{ profile.infraRsDomP.attributes.dn }}
### Externally Managed By: {{ profile.infraRsDomP.attributes.extMngdBy }}
### Force Resolve: {{ profile.infraRsDomP.attributes.forceResolve }}
### Local Owner: {{ profile.infraRsDomP.attributes.lcOwn }}
### Last Modifed: {{ profile.infraRsDomP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.infraRsDomP.attributes.monPolDn }}
### rType: {{ profile.infraRsDomP.attributes.rType }}
### State: {{ profile.infraRsDomP.attributes.state }}
### State Quality: {{ profile.infraRsDomP.attributes.stateQual }}
### Status: {{ profile.infraRsDomP.attributes.status }}
### t
#### Cl: {{ profile.infraRsDomP.attributes.tCl }}
#### DN: {{ profile.infraRsDomP.attributes.tDn }}
#### Type: {{ profile.infraRsDomP.attributes.tType }}
{%-     endfor %}
{%- elif "infraRsSpAccGrp" in api %}
# Spine Access Policy Groups
{%-     for group in data_to_template['imdata'] %}
## UID: {{ group.infraRsSpAccGrp.attributes.uid }}
### Annotation: {{ group.infraRsSpAccGrp.attributes.annotation }}
### Child Action: {{ group.infraRsSpAccGrp.attributes.childAction }}
### DN: {{ group.infraRsSpAccGrp.attributes.dn }}
### Externally Managed By: {{ group.infraRsSpAccGrp.attributes.extMngdBy }}
### Force Resolve: {{ group.infraRsSpAccGrp.attributes.forceResolve }}
### Local Owner: {{ group.infraRsSpAccGrp.attributes.lcOwn }}
### Last Modifed: {{ group.infraRsSpAccGrp.attributes.modTs }}
### Monitoring Policy DN: {{ group.infraRsSpAccGrp.attributes.monPolDn }}
### rType: {{ group.infraRsSpAccGrp.attributes.rType }}
### State: {{ group.infraRsSpAccGrp.attributes.state }}
### State Quality: {{ group.infraRsSpAccGrp.attributes.stateQual }}
### Status: {{ group.infraRsSpAccGrp.attributes.status }}
### t
#### Cl: {{ group.infraRsSpAccGrp.attributes.tCl }}
#### DN: {{ group.infraRsSpAccGrp.attributes.tDn }}
#### Type: {{ group.infraRsSpAccGrp.attributes.tType }}
{%-     endfor %}
{%- elif "infraRsVlanNs" in api %}
# VLAN Namespace Source Relationships
{%-     for namespace in data_to_template['imdata'] %}
## UID: {{ namespace.infraRsVlanNs.attributes.uid }}
### Annotation: {{ namespace.infraRsVlanNs.attributes.annotation }}
### Child Action: {{ namespace.infraRsVlanNs.attributes.childAction }}
### DN: {{ namespace.infraRsVlanNs.attributes.dn }}
### Externally Managed By: {{ namespace.infraRsVlanNs.attributes.extMngdBy }}
### Force Resolve: {{ namespace.infraRsVlanNs.attributes.forceResolve }}
### Local Owner: {{ namespace.infraRsVlanNs.attributes.lcOwn }}
### Last Modifed: {{ namespace.infraRsVlanNs.attributes.modTs }}
### Monitoring Policy DN: {{ namespace.infraRsVlanNs.attributes.monPolDn }}
### rType: {{ namespace.infraRsVlanNs.attributes.rType }}
### State: {{ namespace.infraRsVlanNs.attributes.state }}
### State Quality: {{ namespace.infraRsVlanNs.attributes.stateQual }}
### Status: {{ namespace.infraRsVlanNs.attributes.status }}
### t
#### Cl: {{ namespace.infraRsVlanNs.attributes.tCl }}
#### DN: {{ namespace.infraRsVlanNs.attributes.tDn }}
#### Type: {{ namespace.infraRsVlanNs.attributes.tType }}
{%-     endfor %}
{%- elif "infraSHPortS" in api %}
# Spine Host Port Selector
{%-     for selector in data_to_template['imdata'] %}
## Name: {{ selector.infraSHPortS.attributes.name }}
### Name Alias: {{ selector.infraSHPortS.attributes.nameAlias }}
### Annotation: {{ selector.infraSHPortS.attributes.annotation }}
### Child Action: {{ selector.infraSHPortS.attributes.childAction }}
### Description: {{ selector.infraSHPortS.attributes.descr }}
### DN: {{ selector.infraSHPortS.attributes.dn }}
### Externally Managed By: {{ selector.infraSHPortS.attributes.extMngdBy }}
### Local Owner: {{ selector.infraSHPortS.attributes.lcOwn }}
### Last Modified: {{ selector.infraSHPortS.attributes.modTs }}
### Monitoring Policy DN: {{ selector.infraSHPortS.attributes.monPolDn }}
### Owner
#### Key: {{ selector.infraSHPortS.attributes.ownerKey }}
#### Tag: {{ selector.infraSHPortS.attributes.ownerTag }}
### Status: {{ selector.infraSHPortS.attributes.status }}
### Type: {{ selector.infraSHPortS.attributes.type }}
### UID: {{ selector.infraSHPortS.attributes.uid }}
{%-     endfor %}
{%- elif "infraSpAccPortP" in api %}
# Spine Access Port Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.infraSpAccPortP.attributes.name }}
### Name Alias: {{ profile.infraSpAccPortP.attributes.nameAlias }}
### Annotation: {{ profile.infraSpAccPortP.attributes.annotation }}
### Child Action: {{ profile.infraSpAccPortP.attributes.childAction }}
### Description: {{ profile.infraSpAccPortP.attributes.descr }}
### DN: {{ profile.infraSpAccPortP.attributes.dn }}
### Externally Managed By: {{ profile.infraSpAccPortP.attributes.extMngdBy }}
### Local Owner: {{ profile.infraSpAccPortP.attributes.lcOwn }}
### Last Modified: {{ profile.infraSpAccPortP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.infraSpAccPortP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.infraSpAccPortP.attributes.ownerKey }}
#### Tag: {{ profile.infraSpAccPortP.attributes.ownerTag }}
### Status: {{ profile.infraSpAccPortP.attributes.status }}
### UID: {{ profile.infraSpAccPortP.attributes.uid }}
{%-     endfor %}
{%- elif "infraWiNode" in api %}
# Wired Nodes
{%-     for node in data_to_template['imdata'] %}
## Name: {{ node.infraWiNode.attributes.name }}
### Name Alias: {{ node.infraWiNode.attributes.nameAlias }}
### Address: {{ node.infraWiNode.attributes.addr }}
### Admin State: {{ node.infraWiNode.attributes.adminSt }}
### Annotation: {{ node.infraWiNode.attributes.annotation }}
### APIC Mode: {{ node.infraWiNode.attributes.apicMode }}
### Chassis: {{ node.infraWiNode.attributes.chassis }}
### Child Action: {{ node.infraWiNode.attributes.childAction }}
### Controller Sbst State: {{ node.infraWiNode.attributes.cntrlSbstState }}
### DN: {{ node.infraWiNode.attributes.dn }}
### Externally Managed By: {{ node.infraWiNode.attributes.extMngdBy }}
### Failover Status: {{ node.infraWiNode.attributes.failoverStatus }}
### Health: {{ node.infraWiNode.attributes.health }}
### ID: {{ node.infraWiNode.attributes.id }}
### Local Owner: {{ node.infraWiNode.attributes.lcOwn }}
### Motherboard Serial Number: {{ node.infraWiNode.attributes.mbSn }}
### Last Modified: {{ node.infraWiNode.attributes.modTs }}
### Monitoring Policy DN: {{ node.infraWiNode.attributes.monPolDn }}
### Mutn Timestamp: {{ node.infraWiNode.attributes.mutnTs }}
### Node Name: {{ node.infraWiNode.attributes.nodeName }}
### Oper State: {{ node.infraWiNode.attributes.operSt }}
### Pod ID: {{ node.infraWiNode.attributes.podId }}
### Routable IP Address: {{ node.infraWiNode.attributes.routableIpAddr }}
### Status: {{ node.infraWiNode.attributes.status }}
### Target Motherboard Serial Number: {{ node.infraWiNode.attributes.targetMbSn }}
### UID: {{ node.infraWiNode.attributes.uid }}
{%-     endfor %}
{%- elif "ipNexthopP" in api %}
# Static Route Next Hop Policies
{%-     for policy in data_to_template['imdata'] %}
## Name: {{ policy.ipNexthopP.attributes.name }}
### Name Alias: {{ policy.ipNexthopP.attributes.nameAlias }}
### Annotation: {{ policy.ipNexthopP.attributes.annotation }}
### Child Action: {{ policy.ipNexthopP.attributes.childAction }}
### Description: {{ policy.ipNexthopP.attributes.descr }}
### DN: {{ policy.ipNexthopP.attributes.dn }}
### Externally Managed By: {{ policy.ipNexthopP.attributes.extMngdBy }}
### Local Owner: {{ policy.ipNexthopP.attributes.lcOwn }}
### Last Modified: {{ policy.ipNexthopP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.ipNexthopP.attributes.monPolDn }}
### Next Hop Address: {{ policy.ipNexthopP.attributes.nhAddr }}
### Prefix: {{ policy.ipNexthopP.attributes.pref }}
### Status: {{ policy.ipNexthopP.attributes.status }}
### Type: {{ policy.ipNexthopP.attributes.type }}
### UID: {{ policy.ipNexthopP.attributes.uid }}
{%-     endfor %}
{%- elif "ipRouteP" in api %}
# Route Policies
{%-     for policy in data_to_template['imdata'] %}
## Name: {{ policy.ipRouteP.attributes.name }}
### Name Alias: {{ policy.ipRouteP.attributes.nameAlias }}
### Aggregate: {{ policy.ipRouteP.attributes.aggregate }}
### Annotation: {{ policy.ipRouteP.attributes.annotation }}
### Child Action: {{ policy.ipRouteP.attributes.childAction }}
### Description: {{ policy.ipRouteP.attributes.descr }}
### DN: {{ policy.ipRouteP.attributes.dn }}
### Externally Managed By: {{ policy.ipRouteP.attributes.extMngdBy }}
### Prefix Length Range
#### From: {{ policy.ipRouteP.attributes.fromPfxLen }}
#### To: {{ policy.ipRouteP.attributes.toPfxLen }}
### IP: {{ policy.ipRouteP.attributes.ip }}
### Local Owner: {{ policy.ipRouteP.attributes.lcOwn }}
### Last Modified: {{ policy.ipRouteP.attributes.modTs }}
### Monitoring Policy DN: {{ policy.ipRouteP.attributes.monPolDn }}
### Prefix: {{ policy.ipRouteP.attributes.pref }}
### Route Control: {{ policy.ipRouteP.attributes.rtCtrl }}
### Status: {{ policy.ipRouteP.attributes.status }}
### Type: {{ policy.ipRouteP.attributes.type }}
### UID: {{ policy.ipRouteP.attributes.uid }}
{%-     endfor %}
{%- elif "ipv4Addr" in api %}
# IPv4 Addresses
{%-     for address in data_to_template['imdata'] %}
## Address: {{ address.ipv4Addr.attributes.addr }}
### Child Action: {{ address.ipv4Addr.attributes.childAction }}
### Control: {{ address.ipv4Addr.attributes.ctrl }}
### DN: {{ address.ipv4Addr.attributes.dn }}
### IPv4 Config
#### Failed
##### Bmp: {{ address.ipv4Addr.attributes.ipv4CfgFailedBmp }}
##### Timestamp: {{ address.ipv4Addr.attributes.ipv4CfgFailedTs }}
#### State: {{ address.ipv4Addr.attributes.ipv4CfgState }}
### Local Owner: {{ address.ipv4Addr.attributes.lcOwn }}
### Last Modified: {{ address.ipv4Addr.attributes.modTs }}
### Monitoring Policy DN: {{ address.ipv4Addr.attributes.monPolDn }}
### Oper
#### State: {{ address.ipv4Addr.attributes.operSt }}
#### State Quality: {{ address.ipv4Addr.attributes.operStQual }}
### Prefix: {{ address.ipv4Addr.attributes.pref }}
### Status: {{ address.ipv4Addr.attributes.status }}
### Tag: {{ address.ipv4Addr.attributes.tag }}
### Type: {{ address.ipv4Addr.attributes.type }}
### vPC Peer: {{ address.ipv4Addr.attributes.vpcPeer }}
{%-     endfor %}
{%- elif "ipv4Dom" in api %}
# IPv4 Domains
{%-     for domain in data_to_template['imdata'] %}
## Name: {{ domain.ipv4Dom.attributes.name }}
### Child Action: {{ domain.ipv4Dom.attributes.childAction }}
### DN: {{ domain.ipv4Dom.attributes.dn }}
### Encapsulation: {{ domain.ipv4Dom.attributes.encap }}
### Local Owner: {{ domain.ipv4Dom.attributes.lcOwn }}
### Last Modified: {{ domain.ipv4Dom.attributes.modTs }}
### Monitoring Policy DN: {{ domain.ipv4Dom.attributes.monPolDn }}
### Router ID: {{ domain.ipv4Dom.attributes.rtrId }}
### Status: {{ domain.ipv4Dom.attributes.status }}
{%-     endfor %}
{%- elif "ipv4Entity" in api %}
# IPv4 Entities
{%-     for entity in data_to_template['imdata'] %}
## Name: {{ entity.ipv4Entity.attributes.name }}
### Admin State: {{ entity.ipv4Entity.attributes.adminSt }}
### Child Action: {{ entity.ipv4Entity.attributes.childAction }}
### DN: {{ entity.ipv4Entity.attributes.dn }}
### Local Owner: {{ entity.ipv4Entity.attributes.lcOwn }}
### Last Modified: {{ entity.ipv4Entity.attributes.modTs }}
### Monitoring Policy DN: {{ entity.ipv4Entity.attributes.monPolDn }}
### Oper
#### Error: {{ entity.ipv4Entity.attributes.operErr }}
#### State: {{ entity.ipv4Entity.attributes.operSt }}
### Status: {{ entity.ipv4Entity.attributes.status }}
{%-     endfor %}
{%- elif "ipv4If" in api %}
# IPv4 Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.ipv4If.attributes.name }}
### Admin State: {{ interface.ipv4If.attributes.adminSt }}
### Child Action: {{ interface.ipv4If.attributes.childAction }}
### Control: {{ interface.ipv4If.attributes.ctrl }}
### Description: {{ interface.ipv4If.attributes.descr }}
### DN: {{ interface.ipv4If.attributes.dn }}
### Donor Interface: {{ interface.ipv4If.attributes.donorIf }}
### ID: {{ interface.ipv4If.attributes.id }}
### Local Owner: {{ interface.ipv4If.attributes.lcOwn }}
### Last Modified: {{ interface.ipv4If.attributes.modTs }}
### Mode: {{ interface.ipv4If.attributes.mode }}
### Mode External: {{ interface.ipv4If.attributes.modeExtn }}
### Monitoring Policy DN: {{ interface.ipv4If.attributes.monPolDn }}
### Status: {{ interface.ipv4If.attributes.status }}
{%-     endfor %}
{%- elif "ipv4Inst" in api %}
# IPv4 Instances
{%-     for instance in data_to_template['imdata'] %}
## Name: {{ instance.ipv4Inst.attributes.name }}
### Admin State: {{ instance.ipv4Inst.attributes.adminSt }}
### Child Action: {{ instance.ipv4Inst.attributes.childAction }}
### Control: {{ instance.ipv4Inst.attributes.ctrl }}
### DN: {{ instance.ipv4Inst.attributes.dn }}
### Local Owner: {{ instance.ipv4Inst.attributes.lcOwn }}
### Last Modified: {{ instance.ipv4Inst.attributes.modTs }}
### Monitoring Policy DN: {{ instance.ipv4Inst.attributes.monPolDn }}
### Oper Error: {{ instance.ipv4Inst.attributes.operErr }}
### Status: {{ instance.ipv4Inst.attributes.status }}
{%-     endfor %}
{%- elif "ipv4Nexthop" in api %}
# IPv4 Next Hop
{%-     for nexthop in data_to_template['imdata'] %}
## Name: {{ nexthop.ipv4Nexthop.attributes.name }}
### Name Alias: {{ nexthop.ipv4Nexthop.attributes.nameAlias }}
### Logical DN: {{ nexthop.ipv4Nexthop.attributes.LogicalDn }}
### Cached Route Control: {{ nexthop.ipv4Nexthop.attributes.cachedRtCtrl }}
### Child Action: {{ nexthop.ipv4Nexthop.attributes.childAction }}
### Context ID: {{ nexthop.ipv4Nexthop.attributes.contextId }}
### Control: {{ nexthop.ipv4Nexthop.attributes.ctrl }}
### Description: {{ nexthop.ipv4Nexthop.attributes.descr }}
### DN: {{ nexthop.ipv4Nexthop.attributes.dn }}
### Flags: {{ nexthop.ipv4Nexthop.attributes.flags }}
### IPv4 Config
#### Failed Bmp: {{ nexthop.ipv4Nexthop.attributes.ipv4CfgFailedBmp }}
#### Failed Timestamp: {{ nexthop.ipv4Nexthop.attributes.ipv4CfgFailedTs }}
#### State: {{ nexthop.ipv4Nexthop.attributes.ipv4CfgState }}
### Local Owner: {{ nexthop.ipv4Nexthop.attributes.lcOwn }}
### Last Modified: {{ nexthop.ipv4Nexthop.attributes.modTs }}
### Monitoring Policy DN: {{ nexthop.ipv4Nexthop.attributes.monPolDn }}
### Next Hop
#### Address: {{ nexthop.ipv4Nexthop.attributes.nhAddr }}
#### Interface: {{ nexthop.ipv4Nexthop.attributes.nhIf }}
#### VRF: {{ nexthop.ipv4Nexthop.attributes.nhVrf }}
### Oper State: {{ nexthop.ipv4Nexthop.attributes.operSt }}
### Oper State Quality: {{ nexthop.ipv4Nexthop.attributes.operStQual }}
### Prefix: {{ nexthop.ipv4Nexthop.attributes.pref }}
### RW Encapsulation: {{ nexthop.ipv4Nexthop.attributes.rwEncap }}
### Status: {{ nexthop.ipv4Nexthop.attributes.status }}
### Track ID: {{ nexthop.ipv4Nexthop.attributes.trackId }}
{%-     endfor %}
{%- elif "ipv4Route" in api %}
# IPv4 Routes
{%-     for route in data_to_template['imdata'] %}
## Name: {{ route.ipv4Route.attributes.name }}
### Name Alias: {{ route.ipv4Route.attributes.nameAlias }}
### Child Action: {{ route.ipv4Route.attributes.childAction }}
### Control: {{ route.ipv4Route.attributes.ctrl }}
### Description: {{ route.ipv4Route.attributes.descr }}
### DN: {{ route.ipv4Route.attributes.dn }}
### Flush Count: {{ route.ipv4Route.attributes.flushCount }}
### Local Owner: {{ route.ipv4Route.attributes.lcOwn }}
### Last Modified: {{ route.ipv4Route.attributes.modTs }}
### Monitoring Policy DN: {{ route.ipv4Route.attributes.monPolDn }}
### PC Tag: {{ route.ipv4Route.attributes.pcTag }}
### Preference: {{ route.ipv4Route.attributes.pref }}
### Prefix: {{ route.ipv4Route.attributes.prefix }}
### Shared Cons Count: {{ route.ipv4Route.attributes.sharedConsCount }}
### Status: {{ route.ipv4Route.attributes.status }}
### Tag: {{ route.ipv4Route.attributes.tag }}
### Track ID: {{ route.ipv4Route.attributes.trackId }}
{%-     endfor %}
{%- elif "isisAdjEp" in api %}
# ISIS Adjacency Endpoints
{%-     for endpoint in data_to_template['imdata'] %}
## Name: {{ endpoint.isisAdjEp.attributes.name }}
### BFD Oper State: {{ endpoint.isisAdjEp.attributes.bfdOperSt }}
### Child Action: {{ endpoint.isisAdjEp.attributes.childAction }}
### Ckt Type: {{ endpoint.isisAdjEp.attributes.cktType }}
### DN: {{ endpoint.isisAdjEp.attributes.dn }}
### Hold Expired Timestamp: {{ endpoint.isisAdjEp.attributes.holdExpTs }}
### LAN ID: {{ endpoint.isisAdjEp.attributes.lanId }}
### Last Transaction: {{ endpoint.isisAdjEp.attributes.lastTrans }}
### Last Modified: {{ endpoint.isisAdjEp.attributes.modTs }}
### Monitoring Policy DN: {{ endpoint.isisAdjEp.attributes.monPolDn }}
### Nuymber of Adjacency Transactions: {{ endpoint.isisAdjEp.attributes.numAdjTrans }}
### Oper State: {{ endpoint.isisAdjEp.attributes.operSt }}
### Peer
#### Chk ID: {{ endpoint.isisAdjEp.attributes.peerCktId }}
#### Chk Priority: {{ endpoint.isisAdjEp.attributes.peerCktPrio }}
#### Gr Flags: {{ endpoint.isisAdjEp.attributes.peerGrFlags }}
### Status: {{ endpoint.isisAdjEp.attributes.status }}
### System ID: {{ endpoint.isisAdjEp.attributes.sysId }}
### Type: {{ endpoint.isisAdjEp.attributes.type }}
{%-     endfor %}
{%- elif "isisDTEp" in api %}
# ISIS Discovered Tunnel Endpoints
{%-     for endpoint in data_to_template['imdata'] %}
## Name: {{ endpoint.isisDTEp.attributes.name }}
### Child Action: {{ endpoint.isisDTEp.attributes.childAction }}
### DN: {{ endpoint.isisDTEp.attributes.dn }}
### Encapsulation Type: {{ endpoint.isisDTEp.attributes.encapt }}
### ID: {{ endpoint.isisDTEp.attributes.id }}
### Last Modified: {{ endpoint.isisDTEp.attributes.modTs }}
### Role: {{ endpoint.isisDTEp.attributes.role }}
### Status: {{ endpoint.isisDTEp.attributes.status }}
### Type: {{ endpoint.isisDTEp.attributes.type }}
{%-     endfor %}
{%- elif "isisDom" in api %}
{%-     if "Lvl" in api %}
# ISIS Domain Levels
{%-         for level in data_to_template['imdata'] %}
## Name: {{ level.isisDomLvl.attributes.name }}
### Child Action: {{ level.isisDomLvl.attributes.childAction }}
### Control: {{ level.isisDomLvl.attributes.ctrl }}
### Distance: {{ level.isisDomLvl.attributes.dist }}
### DN: {{ level.isisDomLvl.attributes.dn }}
### Fast
#### Cnsp: {{ level.isisDomLvl.attributes.fastCsnp }}
#### LISP: {{ level.isisDomLvl.attributes.fastLsp }}
### Local Owner: {{ level.isisDomLvl.attributes.lcOwn }}
### Last Modified: {{ level.isisDomLvl.attributes.modTs }}
### Monitoring Policy DN: {{ level.isisDomLvl.attributes.monPolDn }}
### Number of Routes Summarized: {{ level.isisDomLvl.attributes.numRtSummarized }}
### SPF
#### Resynced: {{ level.isisDomLvl.attributes.spfResynced }}
#### Scheduled: {{ level.isisDomLvl.attributes.spfScheduled }}
### Status: {{ level.isisDomLvl.attributes.status }}
### Type: {{ level.isisDomLvl.attributes.type }}
{%-         endfor %}
{%-     else %}
# ISIS Domains
{%-         for domain in data_to_template['imdata'] %}
## Name: {{ domain.isisDom.attributes.name }}
### Aggregate Fabric Adjacency Oper State: {{ domain.isisDom.attributes.aggFabAdjOperSt }}
### Area ID: {{ domain.isisDom.attributes.areaId }}
### Bandwidth Reference: {{ domain.isisDom.attributes.bwRef }}
### Child Action: {{ domain.isisDom.attributes.childAction }}
### Context ID: {{ domain.isisDom.attributes.contextId }}
### Control: {{ domain.isisDom.attributes.ctrl }}
### DN: {{ domain.isisDom.attributes.dn }}
### Fast
### Csnps: {{ domain.isisDom.attributes.fastCsnps }}
### Lsps: {{ domain.isisDom.attributes.fastLsps }}
### Local Owner: {{ domain.isisDom.attributes.lcOwn }}
### LISP
#### Purged: {{ domain.isisDom.attributes.lspPurged }}
#### Refreshed: {{ domain.isisDom.attributes.lspRefreshed }}
#### Sourced: {{ domain.isisDom.attributes.lspSourced }}
### MAX ECMP: {{ domain.isisDom.attributes.maxEcmp }}
### Metric Style: {{ domain.isisDom.attributes.metricStyle }}
### Last Modified: {{ domain.isisDom.attributes.modTs }}
### Mode: {{ domain.isisDom.attributes.mode }}
### Monitoring Policy DN: {{ domain.isisDom.attributes.monPolDn }}
### MTS Error: {{ domain.isisDom.attributes.mtsError }}
### MTU: {{ domain.isisDom.attributes.mtu }}
### nSel: {{ domain.isisDom.attributes.nSel }}
### Oper State: {{ domain.isisDom.attributes.operSt }}
### Redistribution Metric: {{ domain.isisDom.attributes.redistribMetric }}
### Sequence Wrap Error: {{ domain.isisDom.attributes.seqWrapError }}
### SPF Calculated: {{ domain.isisDom.attributes.spfCalculated }}
### Status: {{ domain.isisDom.attributes.status }}
### System
#### ID: {{ domain.isisDom.attributes.sysId }}
#### GIPO {{ domain.isisDom.attributes.systemGipo }}
#### GIPO Oper State: {{ domain.isisDom.attributes.systemGipoOperSt }}
### Urib Error: {{ domain.isisDom.attributes.uribError }}
{%-         endfor %}
{%-     endif %}
{%- elif "isisEntity" in api %}
# ISIS Entities
{%-     for entity in data_to_template['imdata'] %}
## Name: {{ entity.isisEntity.attributes.name }}
### Admin State: {{ entity.isisEntity.attributes.adminSt }}
### Child Action: {{ entity.isisEntity.attributes.childAction }}
### DN: {{ entity.isisEntity.attributes.dn }}
### Local Owner: {{ entity.isisEntity.attributes.lcOwn }}
### Last Modified: {{ entity.isisEntity.attributes.modTs }}
### Monitoring Policy DN: {{ entity.isisEntity.attributes.monPolDn }}
### Oper
#### Error: {{ entity.isisEntity.attributes.operErr }}
#### State: {{ entity.isisEntity.attributes.operSt }}
### Status: {{ entity.isisEntity.attributes.status }}
{%-         endfor %}
{%- elif "isisIf" in api %}
{%-     if "Lvl" in api %}
# ISIS Interfaces Level
{%-         for level in data_to_template['imdata'] %}
## Name: {{ level.isisIfLvl.attributes.name }}
### Child Action: {{ level.isisIfLvl.attributes.childAction }}
### Csnp
#### Interval: {{ level.isisIfLvl.attributes.csnpIntvl }}
#### Next Timestamp: {{ level.isisIfLvl.attributes.nextCsnpTs }}
### DN: {{ level.isisIfLvl.attributes.dn }}
### Hello
#### Interval: {{ level.isisIfLvl.attributes.helloIntvl }}
#### Mult: {{ level.isisIfLvl.attributes.helloMult }}
### Local Owner: {{ level.isisIfLvl.attributes.lcOwn }}
### Last Modified: {{ level.isisIfLvl.attributes.modTs }}
### Monitoring Policy DN: {{ level.isisIfLvl.attributes.monPolDn }}
### Priority: {{ level.isisIfLvl.attributes.priority }}
### Protocol Error: {{ level.isisIfLvl.attributes.protoError }}
### Status: {{ level.isisIfLvl.attributes.status }}
### Type: {{ level.isisIfLvl.attributes.type }}
{%-         endfor %}
{%-     else %}
# ISIS Interfaces
{%-         for interface in data_to_template['imdata'] %}
## Name: {{ interface.isisIf.attributes.name }}
### Admin State: {{ interface.isisIf.attributes.adminSt }}
### Child Action: {{ interface.isisIf.attributes.childAction }}
### Chk
#### Type: {{ interface.isisIf.attributes.cktT }}
#### ID
##### Local: {{ interface.isisIf.attributes.localCktId }}
##### Extended Local: {{ interface.isisIf.attributes.extdLocalCktId }}
##### P2P: {{ interface.isisIf.attributes.p2pCktId }}
### Control: {{ interface.isisIf.attributes.ctrl }}
### Description: {{ interface.isisIf.attributes.descr }}
### DN: {{ interface.isisIf.attributes.dn }}
### ID: {{ interface.isisIf.attributes.id }}
### IIB
#### Index: {{ interface.isisIf.attributes.iibIdx }}
#### State: {{ interface.isisIf.attributes.iibState }}
#### Up Control: {{ interface.isisIf.attributes.iibUpCtrl }}
### Init Error: {{ interface.isisIf.attributes.initError }}
### Local Owner: {{ interface.isisIf.attributes.lcOwn }}
### LISP Refresh Interval: {{ interface.isisIf.attributes.lspRefreshIntvl }}
### Metric: {{ interface.isisIf.attributes.metric }}
### Last Modified: {{ interface.isisIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.isisIf.attributes.monPolDn }}
### Next IIH Timestamp: {{ interface.isisIf.attributes.nextIIHTs }}
### Status: {{ interface.isisIf.attributes.status }}
{%-         endfor %}
{%-     endif %}
{%- elif "isisInst" in api %}
# ISIS Instances
{%-     for instance in data_to_template['imdata'] %}
## Name: {{ instance.isisInst.attributes.name }}
### Admin State: {{ instance.isisInst.attributes.adminSt }}
### Child Action: {{ instance.isisInst.attributes.childAction }}
### Control: {{ instance.isisInst.attributes.ctrl }}
### DN: {{ instance.isisInst.attributes.dn }}
### Local Owner: {{ instance.isisInst.attributes.lcOwn }}
### Memory Alert: {{ instance.isisInst.attributes.memAlert }}
### Last Modified: {{ instance.isisInst.attributes.modTs }}
### Monitoring Policy DN: {{ instance.isisInst.attributes.monPolDn }}
### Errors
#### Duplicate System ID: {{ instance.isisInst.attributes.dupSysIdErr }}
#### MTS: {{ instance.isisInst.attributes.mtsErr }}
#### Protocol: {{ instance.isisInst.attributes.protoErr }}
#### PSS: {{ instance.isisInst.attributes.pssErr }}
### Oper
#### Error: {{ instance.isisInst.attributes.operErr }}
#### State: {{ instance.isisInst.attributes.operSt }}
### Process
#### Queue: {{ instance.isisInst.attributes.processQueue }}
#### Sap: {{ instance.isisInst.attributes.processSap }}
#### Tag: {{ instance.isisInst.attributes.processTag }}
### Status: {{ instance.isisInst.attributes.status }}
{%-          endfor %}
{%- elif "isisNexthop" in api %}
# ISIS Next Hop
{%-     for nexthop in data_to_template['imdata'] %}
## Name: {{ nexthop.isisNexthop.attributes.name }}
### Address: {{ nexthop.isisNexthop.attributes.addr }}
### Child Action: {{ nexthop.isisNexthop.attributes.childAction }}
### DN: {{ nexthop.isisNexthop.attributes.dn }}
### Interface: {{ nexthop.isisNexthop.attributes.if }}
### Last Modified: {{ nexthop.isisNexthop.attributes.modTs }}
### Next Hop Interface: {{ nexthop.isisNexthop.attributes.nhIf }}
### Status: {{ nexthop.isisNexthop.attributes.status }}
{%-          endfor %}
{%- elif "isisRoute" in api %}
# ISIS Routes
{%-     for route in data_to_template['imdata'] %}
## Name: {{ route.isisRoute.attributes.name }}
### Child Action: {{ route.isisRoute.attributes.childAction }}
### DN: {{ route.isisRoute.attributes.dn }}
### Metric: {{ route.isisRoute.attributes.metric }}
### Last Modified: {{ route.isisRoute.attributes.modTs }}
### Monitoring Policy DN: {{ route.isisRoute.attributes.monPolDn }}
### Prefix: {{ route.isisRoute.attributes.pfx }}
### Preference: {{ route.isisRoute.attributes.pref }}
### Status: {{ route.isisRoute.attributes.status }}
{%-          endfor %}
{%- elif "l2BD" in api %}
# L2 Bridge Domains
{%-     for bd in data_to_template['imdata'] %}
## Name: {{ bd.l2BD.attributes.name }}
### Access Encapsulation: {{ bd.l2BD.attributes.accEncap }}
### Address: {{ bd.l2BD.attributes.addr }}
### Admin State: {{ bd.l2BD.attributes.adminSt }}
### Bridge Domain Def DN: {{ bd.l2BD.attributes.bdDefDn }}
### Bridge Mode: {{ bd.l2BD.attributes.bridgeMode }}
### Child Action: {{ bd.l2BD.attributes.childAction }}
### Created: {{ bd.l2BD.attributes.createTs }}
### Control: {{ bd.l2BD.attributes.ctrl }}
### DN: {{ bd.l2BD.attributes.dn }}
### Endpoint
#### Move Detect Mode: {{ bd.l2BD.attributes.epMoveDetectMode }}
#### Oper State: {{ bd.l2BD.attributes.epOperSt }}
#### Oper State Quality: {{ bd.l2BD.attributes.epOperStQual }}
#### Up Sequence Number: {{ bd.l2BD.attributes.epUpSeqNum }}
### Fabric Encapsulation: {{ bd.l2BD.attributes.fabEncap }}
### Forward
#### Control: {{ bd.l2BD.attributes.fwdCtrl }}
#### Mode: {{ bd.l2BD.attributes.fwdMode }}
### Hardware
#### ID: {{ bd.l2BD.attributes.hwId }}
#### Resource ID: {{ bd.l2BD.attributes.hwResourceId }}
#### Shadow ID: {{ bd.l2BD.attributes.hwShadowId }}
### ID: {{ bd.l2BD.attributes.id }}
### Local Owner: {{ bd.l2BD.attributes.lcOwn }}
### Multicast
#### Allow: {{ bd.l2BD.attributes.mcastAllow }}
#### Oper State: {{ bd.l2BD.attributes.mcastOperSt }}
#### IPv6 Allow: {{ bd.l2BD.attributes.ipv6McastAllow }}
### Last Modified: {{ bd.l2BD.attributes.modTs }}
### Mode: {{ bd.l2BD.attributes.mode }}
### Monitoring Policy DN: {{ bd.l2BD.attributes.monPolDn }}
### Multi Destination Packet Action: {{ bd.l2BD.attributes.multiDstPktAct }}
### Oper State: {{ bd.l2BD.attributes.operSt }}
### PC Tag: {{ bd.l2BD.attributes.pcTag }}
### Q in Q L2 Protocol Tunnel Mask: {{ bd.l2BD.attributes.qiqL2ProtTunMask }}
### QOS Priority: {{ bd.l2BD.attributes.qosPrio }}
### Status: {{ bd.l2BD.attributes.status }}
### Type: {{ bd.l2BD.attributes.type }}
### Unknown Action
#### MAC Unicast: {{ bd.l2BD.attributes.unkMacUcastAct }}
#### Multicast: {{ bd.l2BD.attributes.unkMcastAct }}
#### IPv6 Multicast: {{ bd.l2BD.attributes.v6unkMcastAct }}
### VLAN Manager
#### Config
##### Failed Bmp: {{ bd.l2BD.attributes.vlanmgrCfgFailedBmp }}
##### Failed Timestamp: {{ bd.l2BD.attributes.vlanmgrCfgFailedTs }}
##### State: {{ bd.l2BD.attributes.vlanmgrCfgState }}
#### Custom Fault Bmp: {{ bd.l2BD.attributes.vlanmgrCustFaultBmp }}
{%-          endfor %}
{%- elif "l2ExtIf" in api %}
# L2 External Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.l2ExtIf.attributes.name }}
### Child Action: {{ interface.l2ExtIf.attributes.childAction }}
### Description: {{ interface.l2ExtIf.attributes.descr }}
### DN: {{ interface.l2ExtIf.attributes.dn }}
### External Chassis ID: {{ interface.l2ExtIf.attributes.extChasId }}
### ID: {{ interface.l2ExtIf.attributes.id }}
### Local Owner: {{ interface.l2ExtIf.attributes.lcOwn }}
### Last Modified: {{ interface.l2ExtIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.l2ExtIf.attributes.monPolDn }}
### SAT Manager Config
#### Failed Bmp: {{ interface.l2ExtIf.attributes.satmgrCfgFailedBmp }}
#### Failed Timestamp: {{ interface.l2ExtIf.attributes.satmgrCfgFailedTs }}
#### State: {{ interface.l2ExtIf.attributes.satmgrCfgState }}
### Status: {{ interface.l2ExtIf.attributes.status }}
{%-          endfor %}
{%- elif "l2RsEthIf" in api %}
# L2 Interface Source Relationships
{%-     for interface in data_to_template['imdata'] %}
## DN: {{ interface.l2RsEthIf.attributes.dn }}
### Child Action: {{ interface.l2RsEthIf.attributes.childAction }}
### Force Resolve: {{ interface.l2RsEthIf.attributes.forceResolve }}
### Local Owner: {{ interface.l2RsEthIf.attributes.lcOwn }}
### Last Modified: {{ interface.l2RsEthIf.attributes.modTs }}
### Parent Source Key: {{ interface.l2RsEthIf.attributes.parentSKey }}
### rType: {{ interface.l2RsEthIf.attributes.rType }}
### State: {{ interface.l2RsEthIf.attributes.state }}
### State Quality: {{ interface.l2RsEthIf.attributes.stateQual }}
### Status: {{ interface.l2RsEthIf.attributes.status }}
### t
#### Cl: {{ interface.l2RsEthIf.attributes.tCl }}
#### DN: {{ interface.l2RsEthIf.attributes.tDn }}
#### Source Key: {{ interface.l2RsEthIf.attributes.tSKey }}
#### Type: {{ interface.l2RsEthIf.attributes.tType }}
{%-          endfor %}
{%- elif "l2extInstP" in api %}
# L2 External Instance Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.l2extInstP.attributes.name }}
### Name Alias: {{ profile.l2extInstP.attributes.nameAlias }}
### Annotation: {{ profile.l2extInstP.attributes.annotation }}
### Child Action: {{ profile.l2extInstP.attributes.childAction }}
### Config
#### Issues: {{ profile.l2extInstP.attributes.configIssues }}
#### State: {{ profile.l2extInstP.attributes.configSt }}
### Description: {{ profile.l2extInstP.attributes.descr }}
### DN: {{ profile.l2extInstP.attributes.dn }}
### Exception Tag: {{ profile.l2extInstP.attributes.exceptionTag }}
### Externally Managed By: {{ profile.l2extInstP.attributes.extMngdBy }}
### Flood On Encapsulation: {{ profile.l2extInstP.attributes.floodOnEncap }}
### Is Shared Service Multisite EPG: {{ profile.l2extInstP.attributes.isSharedSrvMsiteEPg }}
### Local Owner: {{ profile.l2extInstP.attributes.lcOwn }}
### Match Type: {{ profile.l2extInstP.attributes.matchT }}
### Last Modified: {{ profile.l2extInstP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.l2extInstP.attributes.monPolDn }}
### PC
#### Enforced Preference: {{ profile.l2extInstP.attributes.pcEnfPref }}
#### Tag: {{ profile.l2extInstP.attributes.pcTag }}
### Preferred Group Member: {{ profile.l2extInstP.attributes.prefGrMemb }}
### Priority: {{ profile.l2extInstP.attributes.prio }}
### Scope: {{ profile.l2extInstP.attributes.scope }}
### Status: {{ profile.l2extInstP.attributes.status }}
### Target DSCP: {{ profile.l2extInstP.attributes.targetDscp }}
### Trigger State: {{ profile.l2extInstP.attributes.triggerSt }}
### TX ID: {{ profile.l2extInstP.attributes.txId }}
### UID: {{ profile.l2extInstP.attributes.uid }}
{%-          endfor %}
{%- elif "l2extLIfP" in api %}
# L2 External Logical Interface Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.l2extLIfP.attributes.name }}
### Name Alias: {{ profile.l2extLIfP.attributes.nameAlias }}
### Annotation: {{ profile.l2extLIfP.attributes.annotation }}
### Child Action: {{ profile.l2extLIfP.attributes.childAction }}
### Description: {{ profile.l2extLIfP.attributes.descr }}
### DN: {{ profile.l2extLIfP.attributes.dn }}
### Externally Managed By: {{ profile.l2extLIfP.attributes.extMngdBy }}
### Local Owner: {{ profile.l2extLIfP.attributes.lcOwn }}
### Last Modified: {{ profile.l2extLIfP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.l2extLIfP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.l2extLIfP.attributes.ownerKey }}
#### Tag: {{ profile.l2extLIfP.attributes.ownerTag }}
### Status: {{ profile.l2extLIfP.attributes.status }}
### Tag: {{ profile.l2extLIfP.attributes.tag }}
### UID: {{ profile.l2extLIfP.attributes.uid }}
{%-          endfor %}
{%- elif "l2extLNodeP" in api %}
# L2 External Logical Interface Profiles
{%-     for node in data_to_template['imdata'] %}
## Name: {{ node.l2extLNodeP.attributes.name }}
### Name Alias: {{ node.l2extLNodeP.attributes.nameAlias }}
### Annotation: {{ node.l2extLNodeP.attributes.annotation }}
### Child Action: {{ node.l2extLNodeP.attributes.childAction }}
### Description: {{ node.l2extLNodeP.attributes.descr }}
### DN: {{ node.l2extLNodeP.attributes.dn }}
### Externally Managed By: {{ node.l2extLNodeP.attributes.extMngdBy }}
### Local Owner: {{ node.l2extLNodeP.attributes.lcOwn }}
### Last Modified: {{ node.l2extLNodeP.attributes.modTs }}
### Monitoring Policy DN: {{ node.l2extLNodeP.attributes.monPolDn }}
### Owner
#### Key: {{ node.l2extLNodeP.attributes.ownerKey }}
#### Tag: {{ node.l2extLNodeP.attributes.ownerTag }}
### Status: {{ node.l2extLNodeP.attributes.status }}
### Tag: {{ node.l2extLNodeP.attributes.tag }}
### UID: {{ node.l2extLNodeP.attributes.uid }}
{%-          endfor %}
{%- elif "l2extRsEBd" in api %}
# L2 EPG Bridge Domain Source Relationships
{%-     for epg in data_to_template['imdata'] %}
## UID: {{ epg.l2extRsEBd.attributes.uid }}
### Annotation: {{ epg.l2extRsEBd.attributes.annotation }}
### Child Action: {{ epg.l2extRsEBd.attributes.childAction }}
### DN: {{ epg.l2extRsEBd.attributes.dn }}
### Encapsulation: {{ epg.l2extRsEBd.attributes.encap }}
### Externally Managed By: {{ epg.l2extRsEBd.attributes.extMngdBy }}
### Force Resolve: {{ epg.l2extRsEBd.attributes.forceResolve }}
### Local Owner: {{ epg.l2extRsEBd.attributes.lcOwn }}
### Last Modified: {{ epg.l2extRsEBd.attributes.modTs }}
### Monitoring Policy DN: {{ epg.l2extRsEBd.attributes.monPolDn }}
### rType: {{ epg.l2extRsEBd.attributes.rType }}
### State: {{ epg.l2extRsEBd.attributes.state }}
### State Quality: {{ epg.l2extRsEBd.attributes.stateQual }}
### Status: {{ epg.l2extRsEBd.attributes.status }}
### t
#### Cl: {{ epg.l2extRsEBd.attributes.tCl }}
#### Context DN: {{ epg.l2extRsEBd.attributes.tContextDn }}
#### DN: {{ epg.l2extRsEBd.attributes.tDn }}
#### RN: {{ epg.l2extRsEBd.attributes.tRn }}
#### Type: {{ epg.l2extRsEBd.attributes.tType }}
### tn Fv Bridge Domain Name: {{ epg.l2extRsEBd.attributes.tnFvBDName }}
{%-          endfor %}
{%- elif "l2extRsPathL2OutAtt" in api %}
# L2Out Paths
{%-     for path in data_to_template['imdata'] %}
## UID: {{ path.l2extRsPathL2OutAtt.attributes.uid }}
### Annotation: {{ path.l2extRsPathL2OutAtt.attributes.annotation }}
### Child Action: {{ path.l2extRsPathL2OutAtt.attributes.childAction }}
### Description: {{ path.l2extRsPathL2OutAtt.attributes.descr }}
### DN: {{ path.l2extRsPathL2OutAtt.attributes.dn }}
### Externally Managed By: {{ path.l2extRsPathL2OutAtt.attributes.extMngdBy }}
### Force Resolve: {{ path.l2extRsPathL2OutAtt.attributes.forceResolve }}
### Local Owner: {{ path.l2extRsPathL2OutAtt.attributes.lcOwn }}
### Last Modified: {{ path.l2extRsPathL2OutAtt.attributes.modTs }}
### rType: {{ path.l2extRsPathL2OutAtt.attributes.rType }}
### State: {{ path.l2extRsPathL2OutAtt.attributes.state }}
### State Quality: {{ path.l2extRsPathL2OutAtt.attributes.stateQual }}
### Status: {{ path.l2extRsPathL2OutAtt.attributes.status }}
### t
#### Cl: {{ path.l2extRsPathL2OutAtt.attributes.tCl }}
#### DN: {{ path.l2extRsPathL2OutAtt.attributes.tDn }}
#### Type: {{ path.l2extRsPathL2OutAtt.attributes.tType }}
### Target DSCP: {{ path.l2extRsPathL2OutAtt.attributes.targetDscp }}
{%-          endfor %}
{%- elif "l3Ctx" in api %}
# L3 Contexts
{%-     for context in data_to_template['imdata'] %}
## Name: {{ context.l3Ctx.attributes.name }}
### Admin State: {{ context.l3Ctx.attributes.adminState }}
### Bridge Domain Enforced Enable: {{ context.l3Ctx.attributes.bdEnforcedEnable }}
### BGP
#### RD: {{ context.l3Ctx.attributes.bgpRd }}
#### RD Display: {{ context.l3Ctx.attributes.bgpRdDisp }}
### Child Action: {{ context.l3Ctx.attributes.childAction }}
### Created: {{ context.l3Ctx.attributes.createTs }}
### Context P Key: {{ context.l3Ctx.attributes.ctxPKey }}
### DN: {{ context.l3Ctx.attributes.dn }}
### Encapsulation: {{ context.l3Ctx.attributes.encap }}
### GSDB Context: {{ context.l3Ctx.attributes.gsdbCtx }}
### Hardware Resource ID: {{ context.l3Ctx.attributes.hwResourceId }}
### ID: {{ context.l3Ctx.attributes.id }}
### IP Learning Disabled: {{ context.l3Ctx.attributes.ipLearnDisable }}
### L3 VM Config
#### Failed Bmp: {{ context.l3Ctx.attributes.l3vmCfgFailedBmp }}
#### Failed Timestamp: {{ context.l3Ctx.attributes.l3vmCfgFailedTs }}
#### State: {{ context.l3Ctx.attributes.l3vmCfgState }}
### Last Changed: {{ context.l3Ctx.attributes.lastChgdTs }}
### Local Owner: {{ context.l3Ctx.attributes.lcOwn }}
### Management PC Tag: {{ context.l3Ctx.attributes.mgmtPcTag }}
### Last Modified: {{ context.l3Ctx.attributes.modTs }}
### Monitoring Policy DN: {{ context.l3Ctx.attributes.monPolDn }}
### NG AVS: {{ context.l3Ctx.attributes.ngAvs }}
### Oper State
#### Old Quality: {{ context.l3Ctx.attributes.oldOperStQual }}
#### Quality: {{ context.l3Ctx.attributes.operStQual }}
#### State: {{ context.l3Ctx.attributes.operState }}
### OUI: {{ context.l3Ctx.attributes.oui }}
### PC Enforced
#### Direction: {{ context.l3Ctx.attributes.pcEnfDir }}
#### Preference: {{ context.l3Ctx.attributes.pcEnfPref }}
### PC Tag: {{ context.l3Ctx.attributes.pcTag }}
### Pending: {{ context.l3Ctx.attributes.pending }}
### Port Control Bmp: {{ context.l3Ctx.attributes.prtclBmp }}
### Resource ID: {{ context.l3Ctx.attributes.resourceId }}
### Scope: {{ context.l3Ctx.attributes.scope }}
### Status: {{ context.l3Ctx.attributes.status }}
### Type: {{ context.l3Ctx.attributes.type }}
### IPv4 TIB
#### ID: {{ context.l3Ctx.attributes.v4TibId }}
#### Name: {{ context.l3Ctx.attributes.v4TibName }}
#### Old Oper State Quality: {{ context.l3Ctx.attributes.v4TibOldOperStQual }}
#### Oper State Quality: {{ context.l3Ctx.attributes.v4TibOperStQual }}
#### Oper State: {{ context.l3Ctx.attributes.v4TibOperState }}
#### Pending: {{ context.l3Ctx.attributes.v4TibPending }}
#### Valid: {{ context.l3Ctx.attributes.v4TibValid }}
### IPv6 TIB
#### ID: {{ context.l3Ctx.attributes.v6TibId }}
#### Name: {{ context.l3Ctx.attributes.v6TibName }}
#### Old Oper State Quality: {{ context.l3Ctx.attributes.v6TibOldOperStQual }}
#### Oper State Quality: {{ context.l3Ctx.attributes.v6TibOperStQual }}
#### Oper State: {{ context.l3Ctx.attributes.v6TibOperState }}
#### Pending: {{ context.l3Ctx.attributes.v6TibPending }}
#### Valid: {{ context.l3Ctx.attributes.v6TibValid }}
### VPN ID: {{ context.l3Ctx.attributes.vpnId }}
{%-          endfor %}
{%- elif "l3EncRtdIf" in api %}
# L3 Subinterfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.l3EncRtdIf.attributes.name }}
### Admin State: {{ interface.l3EncRtdIf.attributes.adminSt }}
### Bandwidth: {{ interface.l3EncRtdIf.attributes.bw }}
### Child Action: {{ interface.l3EncRtdIf.attributes.childAction }}
### Delay: {{ interface.l3EncRtdIf.attributes.delay }}
### Description: {{ interface.l3EncRtdIf.attributes.descr }}
### DN: {{ interface.l3EncRtdIf.attributes.dn }}
### Encapsulation: {{ interface.l3EncRtdIf.attributes.encap }}
### Ethernet PM Config
#### Failed Bmp: {{ interface.l3EncRtdIf.attributes.ethpmCfgFailedBmp }}
#### Failed Timestamp: {{ interface.l3EncRtdIf.attributes.ethpmCfgFailedTs }}
#### Config State: {{ interface.l3EncRtdIf.attributes.ethpmCfgState }}
### ID: {{ interface.l3EncRtdIf.attributes.id }}
### Interface Conn DN: {{ interface.l3EncRtdIf.attributes.ifConnDn }}
### Local Owner: {{ interface.l3EncRtdIf.attributes.lcOwn }}
### Link Log Enabled: {{ interface.l3EncRtdIf.attributes.linkLogEn }}
### Last Modified: {{ interface.l3EncRtdIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.l3EncRtdIf.attributes.monPolDn }}
### MTU
#### MTU: {{ interface.l3EncRtdIf.attributes.mtu }}
#### Inherit: {{ interface.l3EncRtdIf.attributes.mtuInherit }}
### QOS Priority: {{ interface.l3EncRtdIf.attributes.qosPrio }}
### Router MAC: {{ interface.l3EncRtdIf.attributes.routerMac }}
### Routed Outside Def DN: {{ interface.l3EncRtdIf.attributes.rtdOutDefDn }}
### Status: {{ interface.l3EncRtdIf.attributes.status }}
{%-          endfor %}
{%- elif "l3Inst" in api %}
# L3 Instances
{%-     for instance in data_to_template['imdata'] %}
## Name: {{ instance.l3Inst.attributes.name }}
### Admin State: {{ instance.l3Inst.attributes.adminState }}
### BGP
#### RD: {{ instance.l3Inst.attributes.bgpRd }}
#### RD Display: {{ instance.l3Inst.attributes.bgpRdDisp }}
### Child Action: {{ instance.l3Inst.attributes.childAction }}
### Created: {{ instance.l3Inst.attributes.createTs }}
### Context P Key: {{ instance.l3Inst.attributes.ctxPKey }}
### DN: {{ instance.l3Inst.attributes.dn }}
### Encapsulation: {{ instance.l3Inst.attributes.encap }}
### GSDB Context: {{ instance.l3Inst.attributes.gsdbCtx }}
### ID: {{ instance.l3Inst.attributes.id }}
### L3 VM Config
#### Failed Bmp: {{ instance.l3Inst.attributes.l3vmCfgFailedBmp }}
#### Failed Timestamp: {{ instance.l3Inst.attributes.l3vmCfgFailedTs }}
#### State: {{ instance.l3Inst.attributes.l3vmCfgState }}
### Last Changed: {{ instance.l3Inst.attributes.lastChgdTs }}
### Local Owner: {{ instance.l3Inst.attributes.lcOwn }}
### Last Modified: {{ instance.l3Inst.attributes.modTs }}
### Monitoring Policy DN: {{ instance.l3Inst.attributes.monPolDn }}
### Oper State
#### Old Quality: {{ instance.l3Inst.attributes.oldOperStQual }}
#### Quality: {{ instance.l3Inst.attributes.operStQual }}
#### State: {{ instance.l3Inst.attributes.operState }}
### OUI: {{ instance.l3Inst.attributes.oui }}
### Pending: {{ instance.l3Inst.attributes.pending }}
### Protocol Bmp: {{ instance.l3Inst.attributes.prtclBmp }}
### Resource ID: {{ instance.l3Inst.attributes.resourceId }}
### Scope: {{ instance.l3Inst.attributes.scope }}
### Status: {{ instance.l3Inst.attributes.status }}
### IPv4 TIB
#### ID: {{ instance.l3Inst.attributes.v4TibId }}
#### Name: {{ instance.l3Inst.attributes.v4TibName }}
#### Old Oper State Quality: {{ instance.l3Inst.attributes.v4TibOldOperStQual }}
#### Oper State Quality: {{ instance.l3Inst.attributes.v4TibOperStQual }}
#### Oper State: {{ instance.l3Inst.attributes.v4TibOperState }}
#### Pending: {{ instance.l3Inst.attributes.v4TibPending }}
#### Valid: {{ instance.l3Inst.attributes.v4TibValid }}
### IPv6 TIB
#### ID: {{ instance.l3Inst.attributes.v6TibId }}
#### Name: {{ instance.l3Inst.attributes.v6TibName }}
#### Old Oper State Quality: {{ instance.l3Inst.attributes.v6TibOldOperStQual }}
#### Oper State Quality: {{ instance.l3Inst.attributes.v6TibOperStQual }}
#### Oper State: {{ instance.l3Inst.attributes.v6TibOperState }}
#### Pending: {{ instance.l3Inst.attributes.v6TibPending }}
#### Valid: {{ instance.l3Inst.attributes.v6TibValid }}
### VPN ID: {{ instance.l3Inst.attributes.vpnId }}
{%-          endfor %}
{%- elif "l3LbRtdIf" in api %}
# L3 Routed Loopback Interfaces
{%-     for loopback in data_to_template['imdata'] %}
## Name: {{ loopback.l3LbRtdIf.attributes.name }}
### Admin State: {{ loopback.l3LbRtdIf.attributes.adminSt }}
### Child Action: {{ loopback.l3LbRtdIf.attributes.childAction }}
### Description: {{ loopback.l3LbRtdIf.attributes.descr }}
### DN: {{ loopback.l3LbRtdIf.attributes.dn }}
### ID: {{ loopback.l3LbRtdIf.attributes.id }}
### Local Owner: {{ loopback.l3LbRtdIf.attributes.lcOwn }}
### Link Log: {{ loopback.l3LbRtdIf.attributes.linkLog }}
### Last Modified: {{ loopback.l3LbRtdIf.attributes.modTs }}
### Monitoring Policy DN: {{ loopback.l3LbRtdIf.attributes.monPolDn }}
### QOS Priority: {{ loopback.l3LbRtdIf.attributes.qosPrio }}
### Routed Out Def DN: {{ loopback.l3LbRtdIf.attributes.rtdOutDefDn }}
### Status: {{ loopback.l3LbRtdIf.attributes.status }}
### Type: {{ loopback.l3LbRtdIf.attributes.type }}
{%-          endfor %}
{%- elif "l3RsEncPhysRtdConf" in api %}
# L3 Physical Interface Source Relationships
{%-     for interface in data_to_template['imdata'] %}
## DN: {{ interface.l3RsEncPhysRtdConf.attributes.dn }}
### Child Action: {{ interface.l3RsEncPhysRtdConf.attributes.childAction }}
### Force Resolve: {{ interface.l3RsEncPhysRtdConf.attributes.forceResolve }}
### Local Owner: {{ interface.l3RsEncPhysRtdConf.attributes.lcOwn }}
### Last Modified: {{ interface.l3RsEncPhysRtdConf.attributes.modTs }}
### Parent S Key: {{ interface.l3RsEncPhysRtdConf.attributes.parentSKey }}
### rType: {{ interface.l3RsEncPhysRtdConf.attributes.rType }}
### State: {{ interface.l3RsEncPhysRtdConf.attributes.state }}
### State Quality: {{ interface.l3RsEncPhysRtdConf.attributes.stateQual }}
### Status: {{ interface.l3RsEncPhysRtdConf.attributes.status }}
### t
#### Cl: {{ interface.l3RsEncPhysRtdConf.attributes.tCl }}
#### DN: {{ interface.l3RsEncPhysRtdConf.attributes.tDn }}
#### S Key: {{ interface.l3RsEncPhysRtdConf.attributes.tSKey }}
#### Type: {{ interface.l3RsEncPhysRtdConf.attributes.tType }}
{%-          endfor %}
{%- elif "l3RtdIf" in api %}
# L3 Routed Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.l3RtdIf.attributes.name }}
### Admin State: {{ interface.l3RtdIf.attributes.adminSt }}
### Child Action: {{ interface.l3RtdIf.attributes.childAction }}
### Description: {{ interface.l3RtdIf.attributes.descr }}
### DN: {{ interface.l3RtdIf.attributes.dn }}
### ID: {{ interface.l3RtdIf.attributes.id }}
### Local Owner: {{ interface.l3RtdIf.attributes.lcOwn }}
### Last Modified: {{ interface.l3RtdIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.l3RtdIf.attributes.monPolDn }}
### QOS Priority: {{ interface.l3RtdIf.attributes.qosPrio }}
### Routed Out Def DN: {{ interface.l3RtdIf.attributes.rtdOutDefDn }}
### Status: {{ interface.l3RtdIf.attributes.status }}
{%-          endfor %}
{%- elif "l3extInstP" in api %}
# L3Out Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.l3extInstP.attributes.name }}
### Name Alias: {{ profile.l3extInstP.attributes.nameAlias }}
### Annotation: {{ profile.l3extInstP.attributes.annotation }}
### Child Action: {{ profile.l3extInstP.attributes.childAction }}
### Config
#### Issue: {{ profile.l3extInstP.attributes.configIssues }}
#### State: {{ profile.l3extInstP.attributes.configSt }}
### Description: {{ profile.l3extInstP.attributes.descr }}
### DN: {{ profile.l3extInstP.attributes.dn }}
### Exception Tag: {{ profile.l3extInstP.attributes.exceptionTag }}
### Externally Managed By: {{ profile.l3extInstP.attributes.extMngdBy }}
### Flood On Encapsulation: {{ profile.l3extInstP.attributes.floodOnEncap }}
### Is Shared Service Multisite EPG: {{ profile.l3extInstP.attributes.isSharedSrvMsiteEPg }}
### Local Owner: {{ profile.l3extInstP.attributes.lcOwn }}
### Match Type: {{ profile.l3extInstP.attributes.matchT }}
### Multicast: {{ profile.l3extInstP.attributes.mcast }}
### Last Modified: {{ profile.l3extInstP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.l3extInstP.attributes.monPolDn }}
### PC Tag: {{ profile.l3extInstP.attributes.pcTag }}
### Preferred Group Memeber: {{ profile.l3extInstP.attributes.prefGrMemb }}
### Priority: {{ profile.l3extInstP.attributes.prio }}
### Scope: {{ profile.l3extInstP.attributes.scope }}
### Status: {{ profile.l3extInstP.attributes.status }}
### Target DSCP: {{ profile.l3extInstP.attributes.targetDscp }}
### Trigger State: {{ profile.l3extInstP.attributes.triggerSt }}
### TX ID: {{ profile.l3extInstP.attributes.txId }}
### UID: {{ profile.l3extInstP.attributes.uid }}
{%-          endfor %}
{%- elif "l3extIp" in api %}
# L3Out IP Addresses
{%-     for ip in data_to_template['imdata'] %}
## Name: {{ ip.l3extIp.attributes.name }}
### Name Alias: {{ ip.l3extIp.attributes.nameAlias }}
### Address: {{ ip.l3extIp.attributes.addr }}
### Annotation: {{ ip.l3extIp.attributes.annotation }}
### Child Action: {{ ip.l3extIp.attributes.childAction }}
### Description: {{ ip.l3extIp.attributes.descr }}
### DN: {{ ip.l3extIp.attributes.dn }}
### Externally Managed By: {{ ip.l3extIp.attributes.extMngdBy }}
### IPv6 DAD: {{ ip.l3extIp.attributes.ipv6Dad }}
### Local Owner: {{ ip.l3extIp.attributes.lcOwn }}
### Last Modified: {{ ip.l3extIp.attributes.modTs }}
### Monitoring Policy DN: {{ ip.l3extIp.attributes.monPolDn }}
### Status: {{ ip.l3extIp.attributes.status }}
### UID: {{ ip.l3extIp.attributes.uid }}
{%-          endfor %}
{%- elif "l3extLIfP" in api %}
# L3 Logical Interface Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.l3extLIfP.attributes.name }}
### Name Alias: {{ profile.l3extLIfP.attributes.nameAlias }}
### Address: {{ profile.l3extLIfP.attributes.addr }}
### Annotation: {{ profile.l3extLIfP.attributes.annotation }}
### Child Action: {{ profile.l3extLIfP.attributes.childAction }}
### Description: {{ profile.l3extLIfP.attributes.descr }}
### DN: {{ profile.l3extLIfP.attributes.dn }}
### Encapsulation: {{ profile.l3extLIfP.attributes.encap }}
### Externally Managed By: {{ profile.l3extLIfP.attributes.extMngdBy }}
### Local Owner: {{ profile.l3extLIfP.attributes.lcOwn }}
### Last Modified: {{ profile.l3extLIfP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.l3extLIfP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.l3extLIfP.attributes.ownerKey }}
#### Tag: {{ profile.l3extLIfP.attributes.ownerTag }}
### Priority: {{ profile.l3extLIfP.attributes.prio }}
### Status: {{ profile.l3extLIfP.attributes.status }}
### Tag: {{ profile.l3extLIfP.attributes.tag }}
### Target DSCP: {{ profile.l3extLIfP.attributes.targetDscp }}
### UID: {{ profile.l3extLIfP.attributes.uid }}
{%-          endfor %}
{%- elif "l3extLNodeP" in api %}
# L3 Logical Node Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.l3extLNodeP.attributes.name }}
### Name Alias: {{ profile.l3extLNodeP.attributes.nameAlias }}
### Annotation: {{ profile.l3extLNodeP.attributes.annotation }}
### Child Action: {{ profile.l3extLNodeP.attributes.childAction }}
### Config Issues: {{ profile.l3extLNodeP.attributes.configIssues }}
### Description: {{ profile.l3extLNodeP.attributes.descr }}
### DN: {{ profile.l3extLNodeP.attributes.dn }}
### Externally Managed By: {{ profile.l3extLNodeP.attributes.extMngdBy }}
### Local Owner: {{ profile.l3extLNodeP.attributes.lcOwn }}
### Last Modified: {{ profile.l3extLNodeP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.l3extLNodeP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.l3extLNodeP.attributes.ownerKey }}
#### Tag: {{ profile.l3extLNodeP.attributes.ownerTag }}
### Status: {{ profile.l3extLNodeP.attributes.status }}
### Tag: {{ profile.l3extLNodeP.attributes.tag }}
### Target DSCP: {{ profile.l3extLNodeP.attributes.targetDscp }}
### UID: {{ profile.l3extLNodeP.attributes.uid }}
{%-          endfor %}
{%- elif "l3extMember" in api %}
# L3Out Members
{%-     for member in data_to_template['imdata'] %}
## Name: {{ member.l3extMember.attributes.name }}
### Name Alias: {{ member.l3extMember.attributes.nameAlias }}
### Address: {{ member.l3extMember.attributes.addr }}
### Annotation: {{ member.l3extMember.attributes.annotation }}
### Child Action: {{ member.l3extMember.attributes.childAction }}
### Description: {{ member.l3extMember.attributes.descr }}
### DN: {{ member.l3extMember.attributes.dn }}
### Externally Managed By: {{ member.l3extMember.attributes.extMngdBy }}
### IPv6 DAD: {{ member.l3extMember.attributes.ipv6Dad }}
### Local Owner: {{ member.l3extMember.attributes.lcOwn }}
### Logical Link Address: {{ member.l3extMember.attributes.llAddr }}
### Last Modified: {{ member.l3extMember.attributes.modTs }}
### Monitoring Policy DN: {{ member.l3extMember.attributes.monPolDn }}
### Side: {{ member.l3extMember.attributes.side }}
### Status: {{ member.l3extMember.attributes.status }}
### UID: {{ member.l3extMember.attributes.uid }}
{%-          endfor %}
{%- elif "l3extRsEctx" in api %}
# L3 Context Source Relationships
{%-     for context in data_to_template['imdata'] %}
## UID: {{ context.l3extRsEctx.attributes.uid }}
### Annotation: {{ context.l3extRsEctx.attributes.annotation }}
### Child Action: {{ context.l3extRsEctx.attributes.childAction }}
### DN: {{ context.l3extRsEctx.attributes.dn }}
### Externally Managed By: {{ context.l3extRsEctx.attributes.extMngdBy }}
### Force Resolve: {{ context.l3extRsEctx.attributes.forceResolve }}
### Local Owner: {{ context.l3extRsEctx.attributes.lcOwn }}
### Last Modified: {{ context.l3extRsEctx.attributes.modTs }}
### Monitoring Policy DN: {{ context.l3extRsEctx.attributes.monPolDn }}
### rType: {{ context.l3extRsEctx.attributes.rType }}
### State: {{ context.l3extRsEctx.attributes.state }}
### State Quality: {{ context.l3extRsEctx.attributes.stateQual }}
### Status: {{ context.l3extRsEctx.attributes.status }}
### t
#### Cl: {{ context.l3extRsEctx.attributes.tCl }}
#### Context DN: {{ context.l3extRsEctx.attributes.tContextDn }}
#### DN: {{ context.l3extRsEctx.attributes.tDn }}
#### RN: {{ context.l3extRsEctx.attributes.tRn }}
#### Type: {{ context.l3extRsEctx.attributes.tType }}
### tn Fv Context Name: {{ context.l3extRsEctx.attributes.tnFvCtxName }}
{%-          endfor %}
{%- elif "l3extRsL3DomAtt" in api %}
# L3 Domain Source Relationships
{%-     for domain in data_to_template['imdata'] %}
## UID: {{ domain.l3extRsL3DomAtt.attributes.uid }}
### Annotation: {{ domain.l3extRsL3DomAtt.attributes.annotation }}
### Child Action: {{ domain.l3extRsL3DomAtt.attributes.childAction }}
### DN: {{ domain.l3extRsL3DomAtt.attributes.dn }}
### Externally Managed By: {{ domain.l3extRsL3DomAtt.attributes.extMngdBy }}
### Force Resolve: {{ domain.l3extRsL3DomAtt.attributes.forceResolve }}
### Local Owner: {{ domain.l3extRsL3DomAtt.attributes.lcOwn }}
### Last Modified: {{ domain.l3extRsL3DomAtt.attributes.modTs }}
### Monitoring Policy DN: {{ domain.l3extRsL3DomAtt.attributes.monPolDn }}
### rType: {{ domain.l3extRsL3DomAtt.attributes.rType }}
### State: {{ domain.l3extRsL3DomAtt.attributes.state }}
### State Quality: {{ domain.l3extRsL3DomAtt.attributes.stateQual }}
### Status: {{ domain.l3extRsL3DomAtt.attributes.status }}
### t
#### Cl: {{ domain.l3extRsL3DomAtt.attributes.tCl }}
#### DN: {{ domain.l3extRsL3DomAtt.attributes.tDn }}
#### Type: {{ domain.l3extRsL3DomAtt.attributes.tType }}
{%-          endfor %}
{%- elif "l3extRsNodeL3OutAtt" in api %}
# L3Out Node Source Relationships
{%-     for node in data_to_template['imdata'] %}
## UID: {{ node.l3extRsNodeL3OutAtt.attributes.uid }}
### Annotation: {{ node.l3extRsNodeL3OutAtt.attributes.annotation }}
### Child Action: {{ node.l3extRsNodeL3OutAtt.attributes.childAction }}
### Config Issues: {{ node.l3extRsNodeL3OutAtt.attributes.configIssues }}
### DN: {{ node.l3extRsNodeL3OutAtt.attributes.dn }}
### Externally Managed By: {{ node.l3extRsNodeL3OutAtt.attributes.extMngdBy }}
### Force Resolve: {{ node.l3extRsNodeL3OutAtt.attributes.forceResolve }}
### Local Owner: {{ node.l3extRsNodeL3OutAtt.attributes.lcOwn }}
### Last Modified: {{ node.l3extRsNodeL3OutAtt.attributes.modTs }}
### Monitoring Policy DN: {{ node.l3extRsNodeL3OutAtt.attributes.monPolDn }}
### rType: {{ node.l3extRsNodeL3OutAtt.attributes.rType }}
### Router
#### ID: {{ node.l3extRsNodeL3OutAtt.attributes.rtrId }}
#### ID Loopback: {{ node.l3extRsNodeL3OutAtt.attributes.rtrIdLoopBack }}
### State: {{ node.l3extRsNodeL3OutAtt.attributes.state }}
### State Quality: {{ node.l3extRsNodeL3OutAtt.attributes.stateQual }}
### Status: {{ node.l3extRsNodeL3OutAtt.attributes.status }}
### t
#### Cl: {{ node.l3extRsNodeL3OutAtt.attributes.tCl }}
#### DN: {{ node.l3extRsNodeL3OutAtt.attributes.tDn }}
#### Type: {{ node.l3extRsNodeL3OutAtt.attributes.tType }}
{%-          endfor %}
{%- elif "l3extRsPathL3OutAtt" in api %}
# L3Out Path Source Relationships
{%-     for path in data_to_template['imdata'] %}
## UID: {{ path.l3extRsPathL3OutAtt.attributes.uid }}
### Address: {{ path.l3extRsPathL3OutAtt.attributes.addr }}
### Annotation: {{ path.l3extRsPathL3OutAtt.attributes.annotation }}
### Auto State: {{ path.l3extRsPathL3OutAtt.attributes.autostate }}
### Child Action: {{ path.l3extRsPathL3OutAtt.attributes.childAction }}
### Config Issues: {{ path.l3extRsPathL3OutAtt.attributes.configIssues }}
### Description: {{ path.l3extRsPathL3OutAtt.attributes.descr }}
### DN: {{ path.l3extRsPathL3OutAtt.attributes.dn }}
### Encapsulation
#### Encapsulation {{ path.l3extRsPathL3OutAtt.attributes.encap }}
#### Scope: {{ path.l3extRsPathL3OutAtt.attributes.encapScope }}
### Externally Managed By: {{ path.l3extRsPathL3OutAtt.attributes.extMngdBy }}
### Force Resolve: {{ path.l3extRsPathL3OutAtt.attributes.forceResolve }}
### Interface Instance Type: {{ path.l3extRsPathL3OutAtt.attributes.ifInstT }}
### IPv6 DAD: {{ path.l3extRsPathL3OutAtt.attributes.ipv6Dad }}
### Local Owner: {{ path.l3extRsPathL3OutAtt.attributes.lcOwn }}
### Link Local Address: {{ path.l3extRsPathL3OutAtt.attributes.llAddr }}
### MAC: {{ path.l3extRsPathL3OutAtt.attributes.mac }}
### Last Modified: {{ path.l3extRsPathL3OutAtt.attributes.modTs }}
### Mode: {{ path.l3extRsPathL3OutAtt.attributes.mode }}
### Monitoring Policy DN: {{ path.l3extRsPathL3OutAtt.attributes.monPolDn }}
### MTU: {{ path.l3extRsPathL3OutAtt.attributes.mtu }}
### rType: {{ path.l3extRsPathL3OutAtt.attributes.rType }}
### State: {{ path.l3extRsPathL3OutAtt.attributes.state }}
### State Quality: {{ path.l3extRsPathL3OutAtt.attributes.stateQual }}
### Status: {{ path.l3extRsPathL3OutAtt.attributes.status }}
### t
#### Cl: {{ path.l3extRsPathL3OutAtt.attributes.tCl }}
#### DN: {{ path.l3extRsPathL3OutAtt.attributes.tDn }}
#### Type: {{ path.l3extRsPathL3OutAtt.attributes.tType }}
### Target DSCP: {{ path.l3extRsPathL3OutAtt.attributes.targetDscp }}
{%-          endfor %}
{%- elif "l3extSubnet" in api %}
# L3 Subnets
{%-     for subnet in data_to_template['imdata'] %}
## Name: {{ subnet.l3extSubnet.attributes.name }}
### Name Alias: {{ subnet.l3extSubnet.attributes.nameAlias }}
### Aggregate: {{ subnet.l3extSubnet.attributes.aggregate }}
### Annotation: {{ subnet.l3extSubnet.attributes.annotation }}
### Child Action: {{ subnet.l3extSubnet.attributes.childAction }}
### Description: {{ subnet.l3extSubnet.attributes.descr }}
### DN: {{ subnet.l3extSubnet.attributes.dn }}
### Externally Managed By: {{ subnet.l3extSubnet.attributes.extMngdBy }}
### IP: {{ subnet.l3extSubnet.attributes.ip }}
### Local Owner: {{ subnet.l3extSubnet.attributes.lcOwn }}
### Last Modified: {{ subnet.l3extSubnet.attributes.modTs }}
### Monitoring Policy DN: {{ subnet.l3extSubnet.attributes.monPolDn }}
### Scope: {{ subnet.l3extSubnet.attributes.scope }}
### Status: {{ subnet.l3extSubnet.attributes.status }}
### UID: {{ subnet.l3extSubnet.attributes.uid }}
{%-          endfor %}
{%- elif "lacpEntity" in api %}
# LACP Entities
{%-     for entity in data_to_template['imdata'] %}
## Name: {{ entity.lacpEntity.attributes.name }}
### Admin State: {{ entity.lacpEntity.attributes.adminSt }}
### Child Action: {{ entity.lacpEntity.attributes.childAction }}
### DN: {{ entity.lacpEntity.attributes.dn }}
### Local Owner: {{ entity.lacpEntity.attributes.lcOwn }}
### Last Modified: {{ entity.lacpEntity.attributes.modTs }}
### Oper
#### Error: {{ entity.lacpEntity.attributes.operErr }}
#### State: {{ entity.lacpEntity.attributes.openSt }}
### Status: {{ entity.lacpEntity.attributes.status }}
{%-          endfor %}
{%- elif "lacpIf" in api %}
# LACP Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.lacpIf.attributes.name }}
### Activity Flags: {{ interface.lacpIf.attributes.activityFlags }}
### Admin State: {{ interface.lacpIf.attributes.adminSt }}
### Child Action: {{ interface.lacpIf.attributes.childAction }}
### Description: {{ interface.lacpIf.attributes.descr }}
### DN: {{ interface.lacpIf.attributes.dn }}
### ID: {{ interface.lacpIf.attributes.id }}
### Key: {{ interface.lacpIf.attributes.key }}
### Last Active: {{ interface.lacpIf.attributes.lastActive }}
### Local Owner: {{ interface.lacpIf.attributes.lcOwn }}
### Last Modified: {{ interface.lacpIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.lacpIf.attributes.monPolDn }}
### Priority
#### Oper: {{ interface.lacpIf.attributes.operPrio }}
#### Priority: {{ interface.lacpIf.attributes.prio }}
### Port: {{ interface.lacpIf.attributes.port }}
### Status: {{ interface.lacpIf.attributes.status }}
### TX Rate: {{ interface.lacpIf.attributes.txRate }}
{%-          endfor %}
{%- elif "lacpInst" in api %}
# LACP Instances
{%-     for instance in data_to_template['imdata'] %}
## Name: {{ instance.lacpInst.attributes.name }}
### Admin
#### Priority: {{ instance.lacpInst.attributes.adminPrio }}
#### State: {{ instance.lacpInst.attributes.adminSt }}
### Child Action: {{ instance.lacpInst.attributes.childAction }}
### Control: {{ instance.lacpInst.attributes.ctrl }}
### DN: {{ instance.lacpInst.attributes.dn }}
### Local Owner: {{ instance.lacpInst.attributes.lcOwn }}
### Last Modified: {{ instance.lacpInst.attributes.modTs }}
### Monitoring Policy DN: {{ instance.lacpInst.attributes.monPolDn }}
### Oper
#### Error: {{ instance.lacpInst.attributes.operErr }}
#### Priority: {{ instance.lacpInst.attributes.operPrio }}
### Status:{{ instance.lacpInst.attributes.status }}
### System MAC: {{ instance.lacpInst.attributes.sysMac }}
{%-          endfor %}
{%- elif "leqptLooseNode" in api %}
# External Unmanaged Nodes
{%-     for node in data_to_template['imdata'] %}
## Name: {{ node.leqptLooseNode.attributes.name }}
### Name Alias: {{ node.leqptLooseNode.attributes.nameAlias }}
### Child Action: {{ node.leqptLooseNode.attributes.childAction }}
### DN: {{ node.leqptLooseNode.attributes.dn }}
### Edm Node DN: {{ node.leqptLooseNode.attributes.edmNodeDn }}
### ID: {{ node.leqptLooseNode.attributes.id }}
### Local Owner: {{ node.leqptLooseNode.attributes.lcOwn }}
### Managed Loose Node: {{ node.leqptLooseNode.attributes.managedLooseNode }}
### Last Modified: {{ node.leqptLooseNode.attributes.modTs }}
### Monitoring Policy DN: {{ node.leqptLooseNode.attributes.monPolDn }}
### Status: {{ node.leqptLooseNode.attributes.status }}
### System
#### Name: {{ node.leqptLooseNode.attributes.sysName }}
#### Description: {{ node.leqptLooseNode.attributes.sysDesc | replace("\n"," ") }}
{%-          endfor %}
{%- elif "leqptRsLsNodeToIf" in api %}
# External Unmanaged Nodes Interfaces
{%-     for interface in data_to_template['imdata'] %}
## DN: {{ interface.leqptRsLsNodeToIf.attributes.dn }}
### Child Action: {{ interface.leqptRsLsNodeToIf.attributes.childAction }}
### Force Resolve: {{ interface.leqptRsLsNodeToIf.attributes.forceResolve }}
### Local Owner: {{ interface.leqptRsLsNodeToIf.attributes.lcOwn }}
### Last Modified: {{ interface.leqptRsLsNodeToIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.leqptRsLsNodeToIf.attributes.monPolDn }}
### rType: {{ interface.leqptRsLsNodeToIf.attributes.rType }}
### State: {{ interface.leqptRsLsNodeToIf.attributes.state }}
### State Quality: {{ interface.leqptRsLsNodeToIf.attributes.stateQual }}
### Status: {{ interface.leqptRsLsNodeToIf.attributes.status }}
### t
#### Cl: {{ interface.leqptRsLsNodeToIf.attributes.tCl }}
#### DN: {{ interface.leqptRsLsNodeToIf.attributes.tDn }}
#### SKey: {{ interface.leqptRsLsNodeToIf.attributes.tSKey }}
#### Type: {{ interface.leqptRsLsNodeToIf.attributes.tType }}
{%-          endfor %}
{%- elif "lldpAdjEp" in api %}
# LLDP Adjacency Endpoints
{%-     for endpoint in data_to_template['imdata'] %}
## Name: {{ endpoint.lldpAdjEp.attributes.name }}
### Capabilites: {{ endpoint.lldpAdjEp.attributes.capability }}
### Chassis
#### ID Type: {{ endpoint.lldpAdjEp.attributes.chassisIdT }}
#### ID Version: {{ endpoint.lldpAdjEp.attributes.chassisIdV }}
### Child Action: {{ endpoint.lldpAdjEp.attributes.childAction }}
### DN: {{ endpoint.lldpAdjEp.attributes.dn }}
### Encapsulation: {{ endpoint.lldpAdjEp.attributes.enCap }}
### ID: {{ endpoint.lldpAdjEp.attributes.id }}
### Management
#### ID: {{ endpoint.lldpAdjEp.attributes.mgmtId }}
#### IP: {{ endpoint.lldpAdjEp.attributes.mgmtIp }}
#### Port MAC: {{ endpoint.lldpAdjEp.attributes.mgmtPortMac }}
### Last Modified: {{ endpoint.lldpAdjEp.attributes.modTs }}
### Monitoring Policy DN: {{ endpoint.lldpAdjEp.attributes.monPolDn }}
### Port
#### Description: {{ endpoint.lldpAdjEp.attributes.portDesc }}
#### ID Type: {{ endpoint.lldpAdjEp.attributes.portIdT }}
#### ID Version: {{ endpoint.lldpAdjEp.attributes.portIdV }}
#### VLAN: {{ endpoint.lldpAdjEp.attributes.portVlan }}
### State Quality: {{ endpoint.lldpAdjEp.attributes.stQual }}
### Status: {{ endpoint.lldpAdjEp.attributes.status }}
### System
#### Name: {{ endpoint.lldpAdjEp.attributes.sysName }}
#### Description: {{ endpoint.lldpAdjEp.attributes.sysDesc | replace("\n"," ") }}
### TTL: {{ endpoint.lldpAdjEp.attributes.ttl }}
{%-          endfor %}
{%- elif "lldpEntity" in api %}
# LLDP Entities
{%-     for entity in data_to_template['imdata'] %}
## Name: {{ entity.lldpEntity.attributes.name }}
### Admin State: {{ entity.lldpEntity.attributes.adminSt }}
### Child Action: {{ entity.lldpEntity.attributes.childAction }}
### DN: {{ entity.lldpEntity.attributes.dn }}
### Local Owner: {{ entity.lldpEntity.attributes.lcOwn }}
### Last Modified: {{ entity.lldpEntity.attributes.modTs }}
### Monitoring Policy DN: {{ entity.lldpEntity.attributes.monPolDn }}
### Oper
#### Error: {{ entity.lldpEntity.attributes.operErr }}
#### State: {{ entity.lldpEntity.attributes.operSt }}
### Status: {{ entity.lldpEntity.attributes.status }}
{%-          endfor %}
{%- elif "lldpIf" in api %}
# LLDP Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.lldpIf.attributes.name }}
### Admin
#### RX State: {{ interface.lldpIf.attributes.adminRxSt }}
#### State: {{ interface.lldpIf.attributes.adminSt }}
#### TX State: {{ interface.lldpIf.attributes.adminTxSt }}
### Child Action: {{ interface.lldpIf.attributes.childAction }}
### Description: {{ interface.lldpIf.attributes.descr }}
### DN: {{ interface.lldpIf.attributes.dn }}
### ID: {{ interface.lldpIf.attributes.id }}
### Local Owner: {{ interface.lldpIf.attributes.lcOwn }}
### MAC: {{ interface.lldpIf.attributes.mac }}
### Last Modified: {{ interface.lldpIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.lldpIf.attributes.monPolDn }}
### Oper
#### RX State: {{ interface.lldpIf.attributes.operRxSt }}
#### TX State: {{ interface.lldpIf.attributes.operTxSt }}
### Port
#### Description: {{ interface.lldpIf.attributes.portDesc }}
#### Mode: {{ interface.lldpIf.attributes.portMode }}
#### VLAN: {{ interface.lldpIf.attributes.portVlan }}
### Status: {{ interface.lldpIf.attributes.status }}
### System Description: {{ interface.lldpIf.attributes.sysDesc }}
### Wiring Issues: {{ interface.lldpIf.attributes.wiringIssues }}
{%-          endfor %}
{%- elif "lldpInst" in api %}
# LLDP Instances
{%-     for instance in data_to_template['imdata'] %}
## Name: {{ instance.lldpInst.attributes.name }}
### Admin State: {{ instance.lldpInst.attributes.adminSt }}
### Child Action: {{ instance.lldpInst.attributes.childAction }}
### Control: {{ instance.lldpInst.attributes.ctrl }}
### DN: {{ instance.lldpInst.attributes.dn }}
### Hold Time: {{ instance.lldpInst.attributes.holdTime }}
### Infra VLAN: {{ instance.lldpInst.attributes.infraVlan }}
### Init Delay Time: {{ instance.lldpInst.attributes.initDelayTime }}
### Local Owner: {{ instance.lldpInst.attributes.lcOwn }}
### Last Modified: {{ instance.lldpInst.attributes.modTs }}
### Monitoring Policy DN: {{ instance.lldpInst.attributes.monPolDn }}
### Oper Error: {{ instance.lldpInst.attributes.operErr }}
### Opt Tlv Sel: {{ instance.lldpInst.attributes.optTlvSel }}
### Status: {{ instance.lldpInst.attributes.status }}
### System Description: {{ instance.lldpInst.attributes.sysDesc }}
### TX Frequency: {{ instance.lldpInst.attributes.txFreq }}
{%-          endfor %}
{%- elif "mgmtMgmtIf" in api %}
# Management Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.mgmtMgmtIf.attributes.name }}
### Admin State: {{ interface.mgmtMgmtIf.attributes.adminSt }}
### Auto Negotiate: {{ interface.mgmtMgmtIf.attributes.autoNeg }}
### Child Action: {{ interface.mgmtMgmtIf.attributes.childAction }}
### Description: {{ interface.mgmtMgmtIf.attributes.descr }}
### DN: {{ interface.mgmtMgmtIf.attributes.dn }}
### FCOT Channel Number: {{ interface.mgmtMgmtIf.attributes.fcotChannelNumber }}
### ID: {{ interface.mgmtMgmtIf.attributes.id }}
### Local Owner: {{ interface.mgmtMgmtIf.attributes.lcOwn }}
### Last Modified: {{ interface.mgmtMgmtIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.mgmtMgmtIf.attributes.monPolDn }}
### MTU: {{ interface.mgmtMgmtIf.attributes.mtu }}
### SNMP Trap State: {{ interface.mgmtMgmtIf.attributes.snmpTrapSt }}
### Speed: {{ interface.mgmtMgmtIf.attributes.speed }}
### Status: {{ interface.mgmtMgmtIf.attributes.status }}
### Switching State: {{ interface.mgmtMgmtIf.attributes.switchingSt }}
{%-          endfor %}
{%- elif "ospfAdjEp" in api %}
# OSPF Adjacency Endpoints
{%-     for endpoint in data_to_template['imdata'] %}
## Name: {{ endpoint.ospfAdjEp.attributes.name }}
### Area: {{ endpoint.ospfAdjEp.attributes.area }}
### BDR: {{ endpoint.ospfAdjEp.attributes.bdr }}
### BFD State: {{ endpoint.ospfAdjEp.attributes.bfdSt }}
### Child Action: {{ endpoint.ospfAdjEp.attributes.childAction }}
### DBD Options: {{ endpoint.ospfAdjEp.attributes.dbdOptions }}
### DN: {{ endpoint.ospfAdjEp.attributes.dn }}
### DR: {{ endpoint.ospfAdjEp.attributes.dr }}
### Flags: {{ endpoint.ospfAdjEp.attributes.flags }}
### Hello Options: {{ endpoint.ospfAdjEp.attributes.helloOptions }}
### ID: {{ endpoint.ospfAdjEp.attributes.id }}
### Interface ID: {{ endpoint.ospfAdjEp.attributes.ifId }}
### Last Modified: {{ endpoint.ospfAdjEp.attributes.modTs }}
### Monitoring Policy DN: {{ endpoint.ospfAdjEp.attributes.monPolDn }}
### Oper State: {{ endpoint.ospfAdjEp.attributes.operSt }}
### Peer
#### IP: {{ endpoint.ospfAdjEp.attributes.peerIp }}
#### Name: {{ endpoint.ospfAdjEp.attributes.peerName }}
### Priority: {{ endpoint.ospfAdjEp.attributes.prio }}
### Status: {{ endpoint.ospfAdjEp.attributes.status }}
{%-          endfor %}
{%- elif "ospfArea" in api %}
# OSPF Areas
{%-     for area in data_to_template['imdata'] %}
## Name: {{ area.ospfArea.attributes.name }}
### Count
#### ASBR: {{ area.ospfArea.attributes.asbrCnt }}
#### BR: {{ area.ospfArea.attributes.brCnt }}
### Child Action: {{ area.ospfArea.attributes.childAction }}
### Cost: {{ area.ospfArea.attributes.cost }}
### Control: {{ area.ospfArea.attributes.ctrl }}
### DN: {{ area.ospfArea.attributes.dn }}
### ID: {{ area.ospfArea.attributes.id }}
### Local Owner: {{ area.ospfArea.attributes.lcOwn }}
### LSA Checksum Summary: {{ area.ospfArea.attributes.lsaCksumSum }}
### Last Modified: {{ area.ospfArea.attributes.modTs }}
### NSSA Trans
#### Role: {{ area.ospfArea.attributes.nssaTransRole }}
#### State: {{ area.ospfArea.attributes.nssaTransSt }}
#### Stable Interval: {{ area.ospfArea.attributes.nssaTransStabIntvl }}
### Status: {{ area.ospfArea.attributes.status }}
### Type: {{ area.ospfArea.attributes.type }}
{%-          endfor %}
{%- elif "ospfDb" in api %}
# OSPF Database
{%-     for database in data_to_template['imdata'] %}
## Name: {{ database.ospfDb.attributes.name }}
### Child Action: {{ database.ospfDb.attributes.childAction }}
### DN: {{ database.ospfDb.attributes.dn }}
### Last Modified: {{ database.ospfDb.attributes.modTs }}
### Status: {{ database.ospfDb.attributes.status }}
### Type: {{ database.ospfDb.attributes.type }}
{%-          endfor %}
{%- elif "ospfDom" in api %}
# OSPF Domains
{%-     for domain in data_to_template['imdata'] %}
## Name: {{ domain.ospfDom.attributes.name }}
### Bandwidth Reference: {{ domain.ospfDom.attributes.bwRef }}
### Child Action: {{ domain.ospfDom.attributes.childAction }}
### Control: {{ domain.ospfDom.attributes.ctrl }}
### Distance: {{ domain.ospfDom.attributes.dist }}
### DN: {{ domain.ospfDom.attributes.dn }}
### ECMP Oper State: {{ domain.ospfDom.attributes.ecmpOperSt }}
### Failed State Quality: {{ domain.ospfDom.attributes.failStQual }}
### Flags: {{ domain.ospfDom.attributes.flags }}
### Local Owner: {{ domain.ospfDom.attributes.lcOwn }}
### Max ECMP: {{ domain.ospfDom.attributes.maxEcmp }}
### Last Modified: {{ domain.ospfDom.attributes.modTs }}
### Monitoring Policy DN: {{ domain.ospfDom.attributes.monPolDn }}
### Oper State: {{ domain.ospfDom.attributes.operSt }}
### Router ID: {{ domain.ospfDom.attributes.rtrId }}
### Seld Advertised Router Tag: {{ domain.ospfDom.attributes.selfAdvRtTag }}
### Status: {{ domain.ospfDom.attributes.status }}
{%-          endfor %}
{%- elif "ospfEntity" in api %}
# OSPF Entities
{%-     for entity in data_to_template['imdata'] %}
## Name: {{ entity.ospfEntity.attributes.name }}
### Admin State: {{ entity.ospfEntity.attributes.adminSt }}
### Child Action: {{ entity.ospfEntity.attributes.childAction }}
### DN: {{ entity.ospfEntity.attributes.dn }}
### Local Owner: {{ entity.ospfEntity.attributes.lcOwn }}
### Last Modified: {{ entity.ospfEntity.attributes.modTs }}
### Monitoring Policy DN: {{ entity.ospfEntity.attributes.monPolDn }}
### Oper
#### Error: {{ entity.ospfEntity.attributes.operErr }}
#### State: {{ entity.ospfEntity.attributes.operSt }}
### Status: {{ entity.ospfEntity.attributes.status }}
{%-          endfor %}
{%- elif "ospfExtP" in api %}
# OSPF External Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.ospfExtP.attributes.name }}
### Name Alias: {{ profile.ospfExtP.attributes.nameAlias }}
### Annotation: {{ profile.ospfExtP.attributes.annotation }}
### Area
#### Cost: {{ profile.ospfExtP.attributes.areaCost }}
#### Control: {{ profile.ospfExtP.attributes.areaCtrl }}
#### ID: {{ profile.ospfExtP.attributes.areaId }}
#### Type: {{ profile.ospfExtP.attributes.areaType }}
### Child Action: {{ profile.ospfExtP.attributes.childAction }}
### Description: {{ profile.ospfExtP.attributes.descr }}
### DN: {{ profile.ospfExtP.attributes.dn }}
### Externally Managed By: {{ profile.ospfExtP.attributes.extMngdBy }}
### Local Owner: {{ profile.ospfExtP.attributes.lcOwn }}
### Last Modified: {{ profile.ospfExtP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.ospfExtP.attributes.monPolDn }}
### Multipod Internal: {{ profile.ospfExtP.attributes.multipodInternal }}
### Status: {{ profile.ospfExtP.attributes.status }}
### UID: {{ profile.ospfExtP.attributes.uid }}
{%-          endfor %}
{%- elif "ospfIf" in api %}
# OSPF Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.ospfIf.attributes.name }}
### Address: {{ interface.ospfIf.attributes.addr }}
### Admin State: {{ interface.ospfIf.attributes.adminSt }}
### Area: {{ interface.ospfIf.attributes.area }}
### BDR
#### BDR: {{ interface.ospfIf.attributes.bdr }}
#### ID: {{ interface.ospfIf.attributes.bdrId }}
### Child Action: {{ interface.ospfIf.attributes.childAction }}
### Cost: {{ interface.ospfIf.attributes.cost }}
### Control: {{ interface.ospfIf.attributes.ctrl }}
### Dead Interval: {{ interface.ospfIf.attributes.deadIntvl }}
### Description: {{ interface.ospfIf.attributes.descr }}
### DN: {{ interface.ospfIf.attributes.dn }}
### DR
#### DR: {{ interface.ospfIf.attributes.dr }}
#### ID: {{ interface.ospfIf.attributes.drId }}
### Failed State Quality: {{ interface.ospfIf.attributes.failStQual }}
### Flags: {{ interface.ospfIf.attributes.flags }}
### Hello Interval: {{ interface.ospfIf.attributes.helloIntvl }}
### ID: {{ interface.ospfIf.attributes.id }}
### Local Owner: {{ interface.ospfIf.attributes.lcOwn }}
### LSA Checksum Summary: {{ interface.ospfIf.attributes.lsaCksumSum }}
### Last Modified: {{ interface.ospfIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.ospfIf.attributes.monPolDn }}
### NW Type: {{ interface.ospfIf.attributes.nwT }}
### Oper
#### Cost: {{ interface.ospfIf.attributes.operCost }}
#### State: {{ interface.ospfIf.attributes.operSt }}
### P2P Oper State: {{ interface.ospfIf.attributes.p2pOperSt }}
### Prefix Suppress: {{ interface.ospfIf.attributes.pfxSuppress }}
### Priority: {{ interface.ospfIf.attributes.prio }}
### Retransmit Interval: {{ interface.ospfIf.attributes.rexmitIntvl }}
### Status: {{ interface.ospfIf.attributes.status }}
### Type: {{ interface.ospfIf.attributes.type }}
### Transmit Delay: {{ interface.ospfIf.attributes.xmitDelay }}
{%-          endfor %}
{%- elif "ospfInst" in api %}
# OSPF Instances
{%-     for instance in data_to_template['imdata'] %}
## Name: {{ instance.ospfInst.attributes.name }}
### Admin State: {{ instance.ospfInst.attributes.adminSt }}
### Child Action: {{ instance.ospfInst.attributes.childAction }}
### Control: {{ instance.ospfInst.attributes.ctrl }}
### DN: {{ instance.ospfInst.attributes.dn }}
### Local Owner: {{ instance.ospfInst.attributes.lcOwn }}
### Memory Alert: {{ instance.ospfInst.attributes.memAlert }}
### Last Modified: {{ instance.ospfInst.attributes.modTs }}
### Monitoring Policy DN: {{ instance.ospfInst.attributes.monPolDn }}
### Oper Error: {{ instance.ospfInst.attributes.operErr }}
### Status: {{ instance.ospfInst.attributes.status}}
{%-          endfor %}
{%- elif "ospfRoute" in api %}
# OSPF Routes
{%-     for route in data_to_template['imdata'] %}
## Name: {{ route.ospfRoute.attributes.name }}
### Area: {{ route.ospfRoute.attributes.area }}
### Child Action: {{ route.ospfRoute.attributes.childAction }}
### Distance: {{ route.ospfRoute.attributes.dist }}
### DN: {{ route.ospfRoute.attributes.dn }}
### Flags: {{ route.ospfRoute.attributes.flags }}
### Last Modified: {{ route.ospfRoute.attributes.modTs }}
### Path Type: {{ route.ospfRoute.attributes.pathT }}
### Prefix: {{ route.ospfRoute.attributes.pfx }}
### Status: {{ route.ospfRoute.attributes.status }}
### Tag: {{ route.ospfRoute.attributes.tag }}
### Cost
#### Unicast: {{ route.ospfRoute.attributes.ucastCost }}
#### Multicast: {{ route.ospfRoute.attributes.mcastCost }}
{%-          endfor %}
{%- elif "ospfUcNexthop" in api %}
# OSPF Unicast Next Hop
{%-     for nexthop in data_to_template['imdata'] %}
## Name: {{ nexthop.ospfUcNexthop.attributes.name }}
### Address: {{ nexthop.ospfUcNexthop.attributes.addr }}
### Child Action: {{ nexthop.ospfUcNexthop.attributes.childAction }}
### DN: {{ nexthop.ospfUcNexthop.attributes.dn }}
### Flags: {{ nexthop.ospfUcNexthop.attributes.flags }}
### Interface: {{ nexthop.ospfUcNexthop.attributes.if }}
### Last Modified: {{ nexthop.ospfUcNexthop.attributes.modTs }}
### Status: {{ nexthop.ospfUcNexthop.attributes.status }}
{%-          endfor %}
{%- elif "pcAggrIf" in api %}
# Port Channel Aggregate Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.pcAggrIf.attributes.name }}
### Active Ports: {{ interface.pcAggrIf.attributes.activePorts }}
### Admin State: {{ interface.pcAggrIf.attributes.adminSt }}
### Auto Negotiate: {{ interface.pcAggrIf.attributes.autoNeg }}
### Bandwidth
#### Actual: {{ interface.pcAggrIf.attributes.bw }}
#### Inherited: {{ interface.pcAggrIf.attributes.inhBw }}
### Child Action: {{ interface.pcAggrIf.attributes.childAction }}
### Created: {{ interface.pcAggrIf.attributes.createTime }}
### Control: {{ interface.pcAggrIf.attributes.ctrl }}
### Delay: {{ interface.pcAggrIf.attributes.delay }}
### Description: {{ interface.pcAggrIf.attributes.descr }}
### DN: {{ interface.pcAggrIf.attributes.dn }}
### Dot1q EtherType: {{ interface.pcAggrIf.attributes.dot1qEtherType }}
### Ethpm Config
#### Failed Bmp: {{ interface.pcAggrIf.attributes.ethpmCfgFailedBmp }}
#### Failed Timestamp: {{ interface.pcAggrIf.attributes.ethpmCfgFailedTs }}
#### State: {{ interface.pcAggrIf.attributes.ethpmCfgState }}
### FCOT Channel Number: {{ interface.pcAggrIf.attributes.fcotChannelNumber }}
### FOP: {{ interface.pcAggrIf.attributes.fop }}
### Hash Dist: {{ interface.pcAggrIf.attributes.hashDist }}
### ID: {{ interface.pcAggrIf.attributes.id }}
### IOD: {{ interface.pcAggrIf.attributes.iod }}
### Is Platform Supported: {{ interface.pcAggrIf.attributes.isPlatformSupported }}
### Is Relfective Relay Config Supported: {{ interface.pcAggrIf.attributes.isReflectiveRelayCfgSupported }}
### Last Bundle
#### Member: {{ interface.pcAggrIf.attributes.lastBundleMbr }}
#### Timestamp: {{ interface.pcAggrIf.attributes.lastBundleTime }}
### Last State
#### State: {{ interface.pcAggrIf.attributes.lastSt }}
#### Cause {{ interface.pcAggrIf.attributes.lastStCause }}
#### Timestamp: {{ interface.pcAggrIf.attributes.lastTime }}
### Last Unbundle
#### Member: {{ interface.pcAggrIf.attributes.lastUnbundleMbr }}
#### Timestamp: {{ interface.pcAggrIf.attributes.lastUnbundleTime }}
### Layer: {{ interface.pcAggrIf.attributes.layer }}
### Local Owner: {{ interface.pcAggrIf.attributes.lcOwn }}
### Logical Interface: {{ interface.pcAggrIf.attributes.lif }}
### Link
#### Debounce: {{ interface.pcAggrIf.attributes.linkDebounce }}
#### Log: {{ interface.pcAggrIf.attributes.linkLog }}
### Load Defer Start Time: {{ interface.pcAggrIf.attributes.loadDeferStartTime }}
### LTL: {{ interface.pcAggrIf.attributes.ltl }}
### Max
#### Active: {{ interface.pcAggrIf.attributes.maxActive }}
#### Links: {{ interface.pcAggrIf.attributes.maxLinks }}
### MDIX: {{ interface.pcAggrIf.attributes.mdix }}
### Medium: {{ interface.pcAggrIf.attributes.medium }}
### Minimum Links: {{ interface.pcAggrIf.attributes.minLinks }}
### Last Modified: {{ interface.pcAggrIf.attributes.modTs }}
### Mode: {{ interface.pcAggrIf.attributes.mode }}
### Monitoring Policy DN: {{ interface.pcAggrIf.attributes.monPolDn }}
### MTU: {{ interface.pcAggrIf.attributes.mtu }}
### Oper Channel Mode: {{ interface.pcAggrIf.attributes.operChannelMode }}
### OS Summary: {{ interface.pcAggrIf.attributes.osSum }}
### Path S Description: {{ interface.pcAggrIf.attributes.pathSDescr }}
### Port Channel
#### ID: {{ interface.pcAggrIf.attributes.pcId }}
#### Mode: {{ interface.pcAggrIf.attributes.pcMode }}
#### Member Config
#### Failed Bmp: {{ interface.pcAggrIf.attributes.pcmCfgFailedBmp }}
#### Failed Timestamp: {{ interface.pcAggrIf.attributes.pcmCfgFailedTs }}
#### State: {{ interface.pcAggrIf.attributes.pcmCfgState }}
### Port Type: {{ interface.pcAggrIf.attributes.portT }}
### Priority Flow Control: {{ interface.pcAggrIf.attributes.prioFlowCtrl }}
### Reflective Relay Enabled: {{ interface.pcAggrIf.attributes.reflectiveRelayEn }}
### Router MAC: {{ interface.pcAggrIf.attributes.routerMac }}
### Row State: {{ interface.pcAggrIf.attributes.rowSt }}
### SNMP Trap State: {{ interface.pcAggrIf.attributes.snmpTrapSt }}
### Span Mode: {{ interface.pcAggrIf.attributes.spanMode }}
### Speed: {{ interface.pcAggrIf.attributes.speed }}
### Status: {{ interface.pcAggrIf.attributes.status }}
### Susp Min Links: {{ interface.pcAggrIf.attributes.suspMinlinks }}
### Switching State: {{ interface.pcAggrIf.attributes.switchingSt }}
### Trunk Log: {{ interface.pcAggrIf.attributes.trunkLog }}
### Usage: {{ interface.pcAggrIf.attributes.usage }}
{%-          endfor %}
{%- elif "pcRsMbrIfs" in api %}
# Port Channel Member Interfaces
{%-     for member in data_to_template['imdata'] %}
## t S Key: {{ member.pcRsMbrIfs.attributes.tSKey }}
### Child Action: {{ member.pcRsMbrIfs.attributes.childAction }}
### DN: {{ member.pcRsMbrIfs.attributes.dn }}
### Force Resolve: {{ member.pcRsMbrIfs.attributes.forceResolve }}
### Local Owner: {{ member.pcRsMbrIfs.attributes.lcOwn }}
### Last Modified: {{ member.pcRsMbrIfs.attributes.modTs }}
### Monitoring Policy DN: {{ member.pcRsMbrIfs.attributes.monPolDn }}
### Parent S Key: {{ member.pcRsMbrIfs.attributes.parentSKey }}
### Port Channel Member Config
#### Failed Bmp: {{ member.pcRsMbrIfs.attributes.pcmCfgFailedBmp }}
#### Failed Timestamp: {{ member.pcRsMbrIfs.attributes.pcmCfgFailedTs }}
#### State: {{ member.pcRsMbrIfs.attributes.pcmCfgState }}
### rType: {{ member.pcRsMbrIfs.attributes.rType }}
### State: {{ member.pcRsMbrIfs.attributes.state }}
### State Quality: {{ member.pcRsMbrIfs.attributes.stateQual }}
### Status: {{ member.pcRsMbrIfs.attributes.status }}
### t
#### Cl: {{ member.pcRsMbrIfs.attributes.tCl }}
#### DN: {{ member.pcRsMbrIfs.attributes.tDn }}
#### Type: {{ member.pcRsMbrIfs.attributes.tType }}
{%-          endfor %}
{%- elif "sviIf" in api %}
# SVIs
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.sviIf.attributes.name }}
### Admin State: {{ interface.sviIf.attributes.adminSt }}
### Auto State: {{ interface.sviIf.attributes.autostate }}
### Bandwidth: {{ interface.sviIf.attributes.bw }}
### Car Del: {{ interface.sviIf.attributes.carDel }}
### Child Action: {{ interface.sviIf.attributes.childAction }}
### Delay: {{ interface.sviIf.attributes.delay }}
### Description: {{ interface.sviIf.attributes.descr }}
### DN: {{ interface.sviIf.attributes.dn }}
### ID: {{ interface.sviIf.attributes.id }}
### Inband Management: {{ interface.sviIf.attributes.inbMgmt }}
### IOD: {{ interface.sviIf.attributes.iod }}
### Local Owner: {{ interface.sviIf.attributes.lcOwn }}
### Load Interval
#### 1: {{ interface.sviIf.attributes.loadIntvl1 }}
#### 2: {{ interface.sviIf.attributes.loadIntvl2 }}
#### 3: {{ interface.sviIf.attributes.loadIntvl3 }}
### MAC: {{ interface.sviIf.attributes.mac }}
### Medium: {{ interface.sviIf.attributes.medium }}
### Last Modified: {{ interface.sviIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.sviIf.attributes.monPolDn }}
### MTU
#### MTU: {{ interface.sviIf.attributes.mtu }}
#### Inherit: {{ interface.sviIf.attributes.mtuInherit }}
### Oper
#### State: {{ interface.sviIf.attributes.operSt }}
#### State Quality: {{ interface.sviIf.attributes.operStQual }}
### OS Summary: {{ interface.sviIf.attributes.osSum }}
### QoS Priority: {{ interface.sviIf.attributes.qosPrio }}
### Routed Out Def DN: {{ interface.sviIf.attributes.rtdOutDefDn }}
### Status: {{ interface.sviIf.attributes.status }}
### VLAN
#### ID: {{ interface.sviIf.attributes.vlanId }}
#### Type: {{ interface.sviIf.attributes.vlanT }}
### vMAC: {{ interface.sviIf.attributes.vmac }}
{%-          endfor %}
{%- elif "tunnelIf" in api %}
# Tunnel Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.tunnelIf.attributes.name }}
### ACL TCAM State Quality: {{ interface.tunnelIf.attributes.aclTcamStQual }}
### Admin State: {{ interface.tunnelIf.attributes.adminSt }}
### Configured MTU: {{ interface.tunnelIf.attributes.cfgdMtu }}
### Child Action: {{ interface.tunnelIf.attributes.childAction }}
### Del in Progress: {{ interface.tunnelIf.attributes.delInProg }}
### Description: {{ interface.tunnelIf.attributes.descr }}
### Destination: {{ interface.tunnelIf.attributes.dest }}
### DN: {{ interface.tunnelIf.attributes.dn }}
### ID: {{ interface.tunnelIf.attributes.id }}
### ID Requestor DN: {{ interface.tunnelIf.attributes.idRequestorDn }}
### IOD: {{ interface.tunnelIf.attributes.iod }}
### Keep Alive
#### Interval: {{ interface.tunnelIf.attributes.keepAlvIntvl }}
#### Retries: {{ interface.tunnelIf.attributes.keepAlvRetries }}
### LCC: {{ interface.tunnelIf.attributes.lcC }}
### Local Owner: {{ interface.tunnelIf.attributes.lcOwn }}
### MAC: {{ interface.tunnelIf.attributes.mac }}
### Last Modified: {{ interface.tunnelIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.tunnelIf.attributes.monPolDn }}
### Oper
#### State: {{ interface.tunnelIf.attributes.operSt }}
#### State Quality: {{ interface.tunnelIf.attributes.operStQual }}
### Source: {{ interface.tunnelIf.attributes.src }}
### Status: {{ interface.tunnelIf.attributes.status }}
### t
#### Layer: {{ interface.tunnelIf.attributes.tLayer }}
#### Type: {{ interface.tunnelIf.attributes.tType }}
### TM Config
#### Failed Bmp: {{ interface.tunnelIf.attributes.tmCfgFailedBmp }}
#### Failed Timestamp: {{ interface.tunnelIf.attributes.tmCfgFailedTs }}
#### State: {{ interface.tunnelIf.attributes.tmCfgState }}
### Type: {{ interface.tunnelIf.attributes.type }}
### Underlay VRF Name: {{ interface.tunnelIf.attributes.underlayVrfName }}
### v6 Source: {{ interface.tunnelIf.attributes.v6Src }}
### VRF Name: {{ interface.tunnelIf.attributes.vrfName }}
{%-          endfor %}
{%- elif "uribv4Dom" in api %}
# Unicast Route Domains
{%-     for route in data_to_template['imdata'] %}
## Name: {{ route.uribv4Dom.attributes.name }}
### Child Action: {{ route.uribv4Dom.attributes.childAction }}
### DN: {{ route.uribv4Dom.attributes.dn }}
### Last Modified: {{ route.uribv4Dom.attributes.modTs }}
### Oper State: {{ route.uribv4Dom.attributes.operSt }}
### Status: {{ route.uribv4Dom.attributes.status }}
{%-          endfor %}
{%- elif "uribv4Entity" in api %}
# Unicast Route Entities
{%-     for entity in data_to_template['imdata'] %}
## Name: {{ entity.uribv4Entity.attributes.name }}
### Admin State: {{ entity.uribv4Entity.attributes.adminSt }}
### Child Action: {{ entity.uribv4Entity.attributes.childAction }}
### DN: {{ entity.uribv4Entity.attributes.dn }}
### Last Modified: {{ entity.uribv4Entity.attributes.modTs }}
### Monitoring Policy DN: {{ entity.uribv4Entity.attributes.monPolDn }}
### Oper
#### Error: {{ entity.uribv4Entity.attributes.operErr }}
#### State: {{ entity.uribv4Entity.attributes.operSt }}
### Status: {{ entity.uribv4Entity.attributes.status }}
{%-          endfor %}
{%- elif "uribv4Nexthop" in api %}
# Unicast Route Next Hop
{%-     for nexthop in data_to_template['imdata'] %}
## Name: {{ nexthop.uribv4Nexthop.attributes.name }}
### Next Hop
#### Metric: {{ nexthop.uribv4Nexthop.attributes.Nhmetric }}
#### Tag: {{ nexthop.uribv4Nexthop.attributes.Nhtag }}
### Active: {{ nexthop.uribv4Nexthop.attributes.active }}
### Address: {{ nexthop.uribv4Nexthop.attributes.addr }}
### Child Action: {{ nexthop.uribv4Nexthop.attributes.childAction }}
### Created: {{ nexthop.uribv4Nexthop.attributes.createTs }}
### DN: {{ nexthop.uribv4Nexthop.attributes.dn }}
### Interface: {{ nexthop.uribv4Nexthop.attributes.if }}
### Metric: {{ nexthop.uribv4Nexthop.attributes.metric }}
### Last Modified: {{ nexthop.uribv4Nexthop.attributes.modTs }}
### Owner: {{ nexthop.uribv4Nexthop.attributes.owner }}
### Preference: {{ nexthop.uribv4Nexthop.attributes.pref }}
### Route Type: {{ nexthop.uribv4Nexthop.attributes.routeType }}
### rw VNID: {{ nexthop.uribv4Nexthop.attributes.rwVnid }}
### Status: {{ nexthop.uribv4Nexthop.attributes.status }}
### Tag: {{ nexthop.uribv4Nexthop.attributes.tag }}
### Type: {{ nexthop.uribv4Nexthop.attributes.type }}
### VRF: {{ nexthop.uribv4Nexthop.attributes.vrf }}
{%-          endfor %}
{%- elif "uribv4Route" in api %}
# Unicast Routes
{%-     for route in data_to_template['imdata'] %}
## Name: {{ route.uribv4Route.attributes.name }}
### Child Action: {{ route.uribv4Route.attributes.childAction }}
### DN: {{ route.uribv4Route.attributes.dn }}
### Last Modified: {{ route.uribv4Route.attributes.modTs }}
### Prefix
#### Prefix: {{ route.uribv4Route.attributes.prefix }}
#### Length: {{ route.uribv4Route.attributes.prefixLength }}
### Status: {{ route.uribv4Route.attributes.status }}
{%-          endfor %}
{%- elif "vlanCktEp" in api %}
# VLAN Endpoint Group Encapsulation
{%-     for vlan in data_to_template['imdata'] %}
## Name: {{ vlan.vlanCktEp.attributes.name }}
### Admin State: {{ vlan.vlanCktEp.attributes.adminSt }}
### Allow USeg Unsupported: {{ vlan.vlanCktEp.attributes.allowUsegUnsupported }}
### Child Action: {{ vlan.vlanCktEp.attributes.childAction }}
### Class Preferred Oper State:{{ vlan.vlanCktEp.attributes.classPrefOperSt }}
### Created: {{ vlan.vlanCktEp.attributes.createTs }}
### Control: {{ vlan.vlanCktEp.attributes.ctrl }}
### DN: {{ vlan.vlanCktEp.attributes.dn }}
### Encapsulation: {{ vlan.vlanCktEp.attributes.encap }}
### Enforced Preference: {{ vlan.vlanCktEp.attributes.enfPref }}
### Endpoint Up Sequence Number: {{ vlan.vlanCktEp.attributes.epUpSeqNum }}
### EPG DN: {{ vlan.vlanCktEp.attributes.epgDn }}
### Excessive TCN Flush Control: {{ vlan.vlanCktEp.attributes.excessiveTcnFlushCnt }}
### Fabric Encapsulation: {{ vlan.vlanCktEp.attributes.fabEncap }}
### Flood In Encapsulation Unsupported: {{ vlan.vlanCktEp.attributes.floodInEncapUnsupported }}
### Forward Control: {{ vlan.vlanCktEp.attributes.fwdCtrl }}
### Hardware ID: {{ vlan.vlanCktEp.attributes.hwId }}
### ID: {{ vlan.vlanCktEp.attributes.id }}
### Local Owner: {{ vlan.vlanCktEp.attributes.lcOwn }}
### Last Modified: {{ vlan.vlanCktEp.attributes.modTs }}
### Mode: {{ vlan.vlanCktEp.attributes.mode }}
### Monitoring Policy DN: {{ vlan.vlanCktEp.attributes.monPolDn }}
### Oper
#### State: {{ vlan.vlanCktEp.attributes.operSt }}
#### State Quality: {{ vlan.vlanCktEp.attributes.operStQual }}
#### State: {{ vlan.vlanCktEp.attributes.operState }}
### Port Channel Tag: {{ vlan.vlanCktEp.attributes.pcTag }}
### Proxy ARP Unsupported: {{ vlan.vlanCktEp.attributes.proxyArpUnsupported }}
### QoS
#### Priority: {{ vlan.vlanCktEp.attributes.qosPrio }}
#### M Config
##### Failed Bmp: {{ vlan.vlanCktEp.attributes.qosmCfgFailedBmp }}
##### Failed Timestamp: {{ vlan.vlanCktEp.attributes.qosmCfgFailedTs }}
##### State: {{ vlan.vlanCktEp.attributes.qosmCfgState }}
### Status: {{ vlan.vlanCktEp.attributes.status }}
### Type: {{ vlan.vlanCktEp.attributes.type }}
### VLAN Manager Config
#### Failed Bmp: {{ vlan.vlanCktEp.attributes.vlanmgrCfgFailedBmp }}
#### Failed Timestamp: {{ vlan.vlanCktEp.attributes.vlanmgrCfgFailedTs }}
#### State: {{ vlan.vlanCktEp.attributes.vlanmgrCfgState }}
### Custom Fault Bmp: {{ vlan.vlanCktEp.attributes.vlanmgrCustFaultBmp }}
{%-          endfor %}
{%- elif "vmmCtrlrP" in api %}
# VMM Controller Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.vmmCtrlrP.attributes.name }}
### Name Alias: {{ profile.vmmCtrlrP.attributes.nameAlias }}
### Annotation: {{ profile.vmmCtrlrP.attributes.annotation }}
### Child Action: {{ profile.vmmCtrlrP.attributes.childAction }}
### Config Issues: {{ profile.vmmCtrlrP.attributes.configIssues }}
### DN: {{ profile.vmmCtrlrP.attributes.dn }}
### Domain Name: {{ profile.vmmCtrlrP.attributes.domName }}
### DVS Version: {{ profile.vmmCtrlrP.attributes.dvsVersion }}
### Externally Managed By: {{ profile.vmmCtrlrP.attributes.extMngdBy }}
### Host or IP: {{ profile.vmmCtrlrP.attributes.hostOrIp }}
### Inventory Trigger State: {{ profile.vmmCtrlrP.attributes.inventoryTrigSt }}
### Local Owner: {{ profile.vmmCtrlrP.attributes.lcOwn }}
### Last Modified: {{ profile.vmmCtrlrP.attributes.modTs }}
### Mode: {{ profile.vmmCtrlrP.attributes.mode }}
### Monitoring Policy DN: {{ profile.vmmCtrlrP.attributes.monPolDn }}
### Microsoft Config
#### Error Message: {{ profile.vmmCtrlrP.attributes.msftConfigErrMsg }}
#### Issues: {{ profile.vmmCtrlrP.attributes.msftConfigIssues }}
### N1KV Stats Mode: {{ profile.vmmCtrlrP.attributes.n1kvStatsMode }}
### Port: {{ profile.vmmCtrlrP.attributes.port }}
### Root Container Name: {{ profile.vmmCtrlrP.attributes.rootContName }}
### Scope: {{ profile.vmmCtrlrP.attributes.scope }}
### Sequence Number: {{ profile.vmmCtrlrP.attributes.seqNum }}
### Stats Mode: {{ profile.vmmCtrlrP.attributes.statsMode }}
### Status: {{ profile.vmmCtrlrP.attributes.status }}
### UID: {{ profile.vmmCtrlrP.attributes.uid }}
### VXLAN Deployment Preference: {{ profile.vmmCtrlrP.attributes.vxlanDeplPref }}
{%-          endfor %}
{%- elif "vmmDomP" in api %}
# VMM Domain Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.vmmDomP.attributes.name }}
### Name Alias: {{ profile.vmmDomP.attributes.nameAlias }}
### Access Mode: {{ profile.vmmDomP.attributes.accessMode }}
### Annotation: {{ profile.vmmDomP.attributes.annotation }}
### ARP Learning: {{ profile.vmmDomP.attributes.arpLearning }}
### AVE Timeout: {{ profile.vmmDomP.attributes.aveTimeOut }}
### Child Action: {{ profile.vmmDomP.attributes.childAction }}
### Config
#### Infra Pg: {{ profile.vmmDomP.attributes.configInfraPg }}
#### Issues: {{ profile.vmmDomP.attributes.configIssues }}
### Control Knob: {{ profile.vmmDomP.attributes.ctrlKnob }}
### Delimeter: {{ profile.vmmDomP.attributes.delimiter }}
### DN: {{ profile.vmmDomP.attributes.dn }}
### Enable
#### AVE: {{ profile.vmmDomP.attributes.enableAVE }}
#### Tag: {{ profile.vmmDomP.attributes.enableTag }}
#### VM Folder: {{ profile.vmmDomP.attributes.enableVmFolder }}
### Encapsulation Mode: {{ profile.vmmDomP.attributes.encapMode }}
### Enforced Preference: {{ profile.vmmDomP.attributes.enfPref }}
### Endpoint
#### Inventory Type: {{ profile.vmmDomP.attributes.epInventoryType }}
#### Retention Time: {{ profile.vmmDomP.attributes.epRetTime }}
### Externally Managed By: {{ profile.vmmDomP.attributes.extMngdBy }}
### Hypervisor Availability Monitor: {{ profile.vmmDomP.attributes.hvAvailMonitor }}
### LAG Policy Name: {{ profile.vmmDomP.attributes.lagPolicyName }}
### Local Owner: {{ profile.vmmDomP.attributes.lcOwn }}
### Multicast Address: {{ profile.vmmDomP.attributes.mcastAddr }}
### Last Modified: {{ profile.vmmDomP.attributes.modTs }}
### Mode: {{ profile.vmmDomP.attributes.mode }}
### Monitoring Policy DN: {{ profile.vmmDomP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.vmmDomP.attributes.ownerKey }}
#### Tag: {{ profile.vmmDomP.attributes.ownerTag }}
### Preferred Encapsulation Mode: {{ profile.vmmDomP.attributes.prefEncapMode }}
### Status: {{ profile.vmmDomP.attributes.status }}
### TX ID: {{ profile.vmmDomP.attributes.txId }}
### UID: {{ profile.vmmDomP.attributes.uid }}
### Unique ID: {{ profile.vmmDomP.attributes.uniqueId }}
{%-          endfor %}
{%- elif "vmmProvP" in api %}
# VMM Provider Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.vmmProvP.attributes.name }}
### Name Alias: {{ profile.vmmProvP.attributes.nameAlias }}
### Annotation: {{ profile.vmmProvP.attributes.annotation }}
### Child Action: {{ profile.vmmProvP.attributes.childAction }}
### DN: {{ profile.vmmProvP.attributes.dn }}
### Externally Managed By: {{ profile.vmmProvP.attributes.extMngdBy }}
### Local Owner: {{ profile.vmmProvP.attributes.lcOwn }}
### Last Modified: {{ profile.vmmProvP.attributes.modTs }}
### Monitoring Policy DN: {{ profile.vmmProvP.attributes.monPolDn }}
### Owner
#### Key: {{ profile.vmmProvP.attributes.ownerKey }}
#### Tag: {{ profile.vmmProvP.attributes.ownerTag }}
### Status: {{ profile.vmmProvP.attributes.status }}
### Type: {{ profile.vmmProvP.attributes.type }}
### UID: {{ profile.vmmProvP.attributes.uid }}
### Vendor: {{ profile.vmmProvP.attributes.vendor }}
{%-          endfor %}
{%- elif "vmmUsrAccP" in api %}
# VMM User Profiles
{%-     for profile in data_to_template['imdata'] %}
## Name: {{ profile.vmmUsrAccP.attributes.name }}
### Name Alias: {{ profile.vmmUsrAccP.attributes.nameAlias }}
### Annotation{{ profile.vmmUsrAccP.attributes.annotation }}
### Child Action: {{ profile.vmmUsrAccP.attributes.childAction }}
### Description: {{ profile.vmmUsrAccP.attributes.descr }}
### DN: {{ profile.vmmUsrAccP.attributes.dn }}
### Externally Managed By: {{ profile.vmmUsrAccP.attributes.extMngdBy }}
### Local Owner: {{ profile.vmmUsrAccP.attributes.lcOwn }}
### Last Modified: {{ profile.vmmUsrAccP.attributes.modTs }}
### Owner
#### Key: {{ profile.vmmUsrAccP.attributes.ownerKey }}
#### Tag: {{ profile.vmmUsrAccP.attributes.ownerTag }}
### Status: {{ profile.vmmUsrAccP.attributes.status }}
### UID: {{ profile.vmmUsrAccP.attributes.uid }}
### User: {{ profile.vmmUsrAccP.attributes.usr }}
{%-          endfor %}
{%- elif "vpcDom" in api %}
# VPC Domains
{%-     for domain in data_to_template['imdata'] %}
## Name: {{ domain.vpcDom.attributes.name }}
### Batched VPC Inv: {{ domain.vpcDom.attributes.batchedVpcInv }}
### Child Action: {{ domain.vpcDom.attributes.childAction }}
### Compatibility
#### Quality: {{ domain.vpcDom.attributes.compatQual }}
#### Quality State: {{ domain.vpcDom.attributes.compatQualStr }}
### Compatibility State: {{ domain.vpcDom.attributes.compatSt }}
### Dead Interval: {{ domain.vpcDom.attributes.deadIntvl }}
### DN: {{ domain.vpcDom.attributes.dn }}
### Dual Active State: {{ domain.vpcDom.attributes.dualActiveSt }}
### ID: {{ domain.vpcDom.attributes.id }}
### ISSU
#### From Version: {{ domain.vpcDom.attributes.issuFromVer }}
#### To Version: {{ domain.vpcDom.attributes.issuToVer }}
### LACP Role: {{ domain.vpcDom.attributes.lacpRole }}
### Local
#### Owner: {{ domain.vpcDom.attributes.lcOwn }}
#### MAC: {{ domain.vpcDom.attributes.localMAC }}
#### Priority: {{ domain.vpcDom.attributes.localPrio }}
### Last Modified: {{ domain.vpcDom.attributes.modTs }}
### Monitoring Policy DN: {{ domain.vpcDom.attributes.monPolDn }}
### Old Role: {{ domain.vpcDom.attributes.oldRole }}
### Oper
#### Role: {{ domain.vpcDom.attributes.operRole }}
#### State: {{ domain.vpcDom.attributes.operSt }}
### Orphan Port List: {{ domain.vpcDom.attributes.orphanPortList }}
### Peer
#### IP: {{ domain.vpcDom.attributes.peerIp }}
#### MAC: {{ domain.vpcDom.attributes.peerMAC }}
#### Priority: {{ domain.vpcDom.attributes.peerPrio }}
#### State: {{ domain.vpcDom.attributes.peerSt }}
#### State Quality: {{ domain.vpcDom.attributes.peerStQual }}
#### Version: {{ domain.vpcDom.attributes.peerVersion }}
### Role Priority: {{ domain.vpcDom.attributes.rolePrio }}
### Self Init Fabric Link Flap Count: {{ domain.vpcDom.attributes.selfIniFabLinkFlapCnt }}
### Split Brain Timer
#### Duration: {{ domain.vpcDom.attributes.splitBrainTimerDuration }}
#### Is Running: {{ domain.vpcDom.attributes.splitBrainTimerIsRun }}
#### Start Time: {{ domain.vpcDom.attributes.splitBrainTimerStartTime }}
### Status: {{ domain.vpcDom.attributes.status }}
### Summary Oper Role: {{ domain.vpcDom.attributes.summOperRole }}
### System
#### MAC: {{ domain.vpcDom.attributes.sysMac }}
#### Priority: {{ domain.vpcDom.attributes.sysPrio }}
### Try Role Establish Timer
#### Duration: {{ domain.vpcDom.attributes.tryRoleEstabTimerDuration }}
#### Is Running: {{ domain.vpcDom.attributes.tryRoleEstabTimerIsRun }}
#### Start Time: {{ domain.vpcDom.attributes.tryRoleEstabTimerStartTime }}
### Type2 Compatibility
#### Quality: {{ domain.vpcDom.attributes.type2CompatQual }}
#### Quality String: {{ domain.vpcDom.attributes.type2CompatQualStr }}
#### State: {{ domain.vpcDom.attributes.type2CompatSt }}
### Virtual IP
#### Announce Delay: {{ domain.vpcDom.attributes.vIpAnnounceDelay }}
#### IP: {{ domain.vpcDom.attributes.virtualIp }}
### VPC Config
#### Failed Bmp: {{ domain.vpcDom.attributes.vpcCfgFailedBmp }}
#### Failed Timestamp: {{ domain.vpcDom.attributes.vpcCfgFailedTs }}
#### State: {{ domain.vpcDom.attributes.vpcCfgState }}
### VPC
#### MAC: {{ domain.vpcDom.attributes.vpcMAC }}
#### Priority: {{ domain.vpcDom.attributes.vpcPrio }}
{%-          endfor %}
{%- elif "vpcEntity" in api %}
# VPC Entities
{%-     for entity in data_to_template['imdata'] %}
## Name: {{ entity.vpcEntity.attributes.name }}
### Admin State: {{ entity.vpcEntity.attributes.adminSt }}
### Child Action: {{ entity.vpcEntity.attributes.childAction }}
### DN: {{ entity.vpcEntity.attributes.dn }}
### Local Owner: {{ entity.vpcEntity.attributes.locOwn }}
### Last Modified: {{ entity.vpcEntity.attributes.modTs }}
### Monitoring Policy DN: {{ entity.vpcEntity.attributes.monPolDn }}
### Oper
#### Error: {{ entity.vpcEntity.attributes.operErr }}
#### State: {{ entity.vpcEntity.attributes.operSt }}
### Status: {{ entity.vpcEntity.attributes.status }}
{%-          endfor %}
{%- elif "vpcIf" in api %}
# VPC Interfaces
{%-     for interface in data_to_template['imdata'] %}
## Name: {{ interface.vpcIf.attributes.name }}
### Access Bundle Group DN: {{ interface.vpcIf.attributes.accBndlGrpDn }}
### Configured
#### Access VLAN: {{ interface.vpcIf.attributes.cfgdAccessVlan }}
#### Trunk VLANs: {{ interface.vpcIf.attributes.cfgdTrunkVlans }}
#### VLANs: {{ interface.vpcIf.attributes.cfgdVlans }}
### Child Action: {{ interface.vpcIf.attributes.childAction }}
### Compatibility
#### Quality: {{ interface.vpcIf.attributes.compatQual }}
#### Quality String: {{ interface.vpcIf.attributes.compatQualStr }}
#### State: {{ interface.vpcIf.attributes.compatSt }}
### Description: {{ interface.vpcIf.attributes.descr }}
### DN: {{ interface.vpcIf.attributes.dn }}
### Fabric Mismatch
#### VLANs: {{ interface.vpcIf.attributes.fabEncMismatchVlans }}
#### VLANs Set: {{ interface.vpcIf.attributes.fabEncMismatchVlansSet }}
### Fabric Path DN: {{ interface.vpcIf.attributes.fabricPathDn }}
### ID: {{ interface.vpcIf.attributes.id }}
### Local Owner: {{ interface.vpcIf.attributes.lcOwn }}
### Local Oper State: {{ interface.vpcIf.attributes.localOperSt }}
### Last Modified: {{ interface.vpcIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.vpcIf.attributes.monPolDn }}
### Port Channel Mode: {{ interface.vpcIf.attributes.pcMode }}
### Peer VLANs
#### Configured: {{ interface.vpcIf.attributes.peerCfgdVlans }}
#### Up: {{ interface.vpcIf.attributes.peerUpVlans }}
### Remote Oper State: {{ interface.vpcIf.attributes.remoteOperSt }}
### Status: {{ interface.vpcIf.attributes.status }}
### VLANs
#### Suspended: {{ interface.vpcIf.attributes.suspVlans }}
#### Up: {{ interface.vpcIf.attributes.upVlans }}
### Usage: {{ interface.vpcIf.attributes.usage }}
{%-          endfor %}
{%- elif "vpcInst" in api %}
# VPC Instances
{%-     for instance in data_to_template['imdata'] %}
## Name: {{ instance.vpcInst.attributes.name }}
### Admin State: {{ instance.vpcInst.attributes.adminSt }}
### Child Action: {{ instance.vpcInst.attributes.childAction }}
### Control: {{ instance.vpcInst.attributes.ctrl }}
### DN: {{ instance.vpcInst.attributes.dn }}
### Local Owner: {{ instance.vpcInst.attributes.lcOwn }}
### Last Modified: {{ instance.vpcInst.attributes.modTs }}
### Monitoring Policy DN: {{ instance.vpcInst.attributes.monPolDn }}
### Oper Error: {{ instance.vpcInst.attributes.operErr }}
### Status: {{ instance.vpcInst.attributes.status }}
{%-          endfor %}
{%- elif "vpcRsVpcConf" in api %}
# VPC Configurations
{%-     for configuration in data_to_template['imdata'] %}
## DN: {{ configuration.vpcRsVpcConf.attributes.dn }}
### Child Action: {{ configuration.vpcRsVpcConf.attributes.childAction }}
### Force Resolve: {{ configuration.vpcRsVpcConf.attributes.forceResolve }}
### Local Owner: {{ configuration.vpcRsVpcConf.attributes.lcOwn }}
### Last Modified: {{ configuration.vpcRsVpcConf.attributes.modTs }}
### Monitoring Policy DN: {{ configuration.vpcRsVpcConf.attributes.monPolDn }}
### Parent SKey: {{ configuration.vpcRsVpcConf.attributes.parentSKey }}
### rType: {{ configuration.vpcRsVpcConf.attributes.rType }}
### State: {{ configuration.vpcRsVpcConf.attributes.state }}
### State Quality: {{ configuration.vpcRsVpcConf.attributes.stateQual }}
### Status: {{ configuration.vpcRsVpcConf.attributes.status }}
### t
#### Cl: {{ configuration.vpcRsVpcConf.attributes.tCl }}
#### DN: {{ configuration.vpcRsVpcConf.attributes.tDn }}
#### SKey: {{ configuration.vpcRsVpcConf.attributes.tSKey }}
#### Type: {{ configuration.vpcRsVpcConf.attributes.tType }}
### VPC Config 
#### Failed Bmp: {{ configuration.vpcRsVpcConf.attributes.vpcCfgFailedBmp }}
#### Failed Timestamp: {{ configuration.vpcRsVpcConf.attributes.vpcCfgFailedTs }}
#### State: {{ configuration.vpcRsVpcConf.attributes.vpcCfgState }}
{%-          endfor %}
{%- elif "vzAny" in api %}
# vzAny
{%-     for any in data_to_template['imdata'] %}
## Name: {{ any.vzAny.attributes.name }}
### Name Alias: {{ any.vzAny.attributes.nameAlias }}
### Annotation: {{ any.vzAny.attributes.annotation }}
### Child Action: {{ any.vzAny.attributes.childAction }}
### Config State: {{ any.vzAny.attributes.configSt }}
### Description: {{ any.vzAny.attributes.descr }}
### DN: {{ any.vzAny.attributes.dn }}
### Externally Managed By: {{ any.vzAny.attributes.extMngdBy }}
### Local Owner: {{ any.vzAny.attributes.lcOwn }}
### Match Type: {{ any.vzAny.attributes.matchT }}
### Last Modified: {{ any.vzAny.attributes.modTs }}
### Monitoring Policy DN: {{ any.vzAny.attributes.monPolDn }}
### Port Channel Tag: {{ any.vzAny.attributes.pcTag }}
### Preferred Group Member: {{ any.vzAny.attributes.prefGrMemb }}
### Status: {{ any.vzAny.attributes.status }}
### TX ID: {{ any.vzAny.attributes.txId }}
### UID: {{ any.vzAny.attributes.uid }}
### Use Any Def: {{ any.vzAny.attributes.useAnyDef }}
{%-          endfor %}
{%- elif "vzFilter" in api %}
# vzFilters
{%-     for vzfilter in data_to_template['imdata'] %}
## Name: {{ vzfilter.vzFilter.attributes.name }}
### Name Alias: {{ vzfilter.vzFilter.attributes.nameAlias }}
### Annotation: {{ vzfilter.vzFilter.attributes.annotation }}
### Child Action: {{ vzfilter.vzFilter.attributes.childAction }}
### Description: {{ vzfilter.vzFilter.attributes.descr }}
### DN: {{ vzfilter.vzFilter.attributes.dn }}
### Externally Managed By: {{ vzfilter.vzFilter.attributes.extMngdBy }}
### Forward ID: {{ vzfilter.vzFilter.attributes.fwdId }}
### ID: {{ vzfilter.vzFilter.attributes.id }}
### Local Owner: {{ vzfilter.vzFilter.attributes.lcOwn }}
### Last Modified: {{ vzfilter.vzFilter.attributes.modTs }}
### Monitoring Policy DN: {{ vzfilter.vzFilter.attributes.monPolDn }}
### Owner
#### Key: {{ vzfilter.vzFilter.attributes.ownerKey }}
#### Tag: {{ vzfilter.vzFilter.attributes.ownerTag }}
### Revision ID: {{ vzfilter.vzFilter.attributes.revId }}
### Status: {{ vzfilter.vzFilter.attributes.status }}
### TX ID: {{ vzfilter.vzFilter.attributes.txId }}
### UID: {{ vzfilter.vzFilter.attributes.uid }}
### Unsupported
#### Entries: {{ vzfilter.vzFilter.attributes.unsupportedEntries }}
#### Management Entries: {{ vzfilter.vzFilter.attributes.unsupportedMgmtEntries }}
### Uses IDs: {{ vzfilter.vzFilter.attributes.usesIds }}
{%-          endfor %}
{%- elif "vzRsAnyToCons" in api %}
# vzAny To Consumers
{%-     for consumer in data_to_template['imdata'] %}
## UID: {{ consumer.vzRsAnyToCons.attributes.uid }}
### Annotation: {{ consumer.vzRsAnyToCons.attributes.annotation }}
### Child Action: {{ consumer.vzRsAnyToCons.attributes.childAction }}
### Deployment Info: {{ consumer.vzRsAnyToCons.attributes.deplInfo }}
### DN: {{ consumer.vzRsAnyToCons.attributes.dn }}
### Externally Managed By: {{ consumer.vzRsAnyToCons.attributes.extMngdBy }}
### Force Resolve: {{ consumer.vzRsAnyToCons.attributes.forceResolve }}
### Intent: {{ consumer.vzRsAnyToCons.attributes.intent }}
### Local Owner: {{ consumer.vzRsAnyToCons.attributes.lcOwn }}
### Last Modified: {{ consumer.vzRsAnyToCons.attributes.modTs }}
### Monitoring Policy DN: {{ consumer.vzRsAnyToCons.attributes.monPolDn }}
### Priority: {{ consumer.vzRsAnyToCons.attributes.prio }}
### rType: {{ consumer.vzRsAnyToCons.attributes.rType }}
### State: {{ consumer.vzRsAnyToCons.attributes.state }}
### State Quality: {{ consumer.vzRsAnyToCons.attributes.stateQual }}
### Status: {{ consumer.vzRsAnyToCons.attributes.status }}
### t
#### Cl: {{ consumer.vzRsAnyToCons.attributes.tCl }}
#### Context DN: {{ consumer.vzRsAnyToCons.attributes.tContextDn }}
#### DN: {{ consumer.vzRsAnyToCons.attributes.tDn }}
#### RN: {{ consumer.vzRsAnyToCons.attributes.tRn }}
#### Type: {{ consumer.vzRsAnyToCons.attributes.tType }}
### Contract Name: {{ consumer.vzRsAnyToCons.attributes.tnVzBrCPName }}
### Update Collection: {{ consumer.vzRsAnyToCons.attributes.updateCollection }}
{%-          endfor %}
{%- elif "vzRsAnyToProv" in api %}
# vzAny To Providers
{%-     for provider in data_to_template['imdata'] %}
## UID: {{ provider.vzRsAnyToProv.attributes.uid }}
### Annotation: {{ provider.vzRsAnyToProv.attributes.annotation }}
### Child Action: {{ provider.vzRsAnyToProv.attributes.childAction }}
### DN: {{ provider.vzRsAnyToProv.attributes.dn }}
### Externally Managed By: {{ provider.vzRsAnyToProv.attributes.extMngdBy }}
### Force Resolve: {{ provider.vzRsAnyToProv.attributes.forceResolve }}
### Intent: {{ provider.vzRsAnyToProv.attributes.intent }}
### Local Owner: {{ provider.vzRsAnyToProv.attributes.lcOwn }}
### Match Type: {{ provider.vzRsAnyToProv.attributes.matchT }}
### Last Modified: {{ provider.vzRsAnyToProv.attributes.modTs }}
### Monitoring Policy DN: {{ provider.vzRsAnyToProv.attributes.monPolDn }}
### Priority: {{ provider.vzRsAnyToProv.attributes.prio }}
### rType: {{ provider.vzRsAnyToProv.attributes.rType }}
### State: {{ provider.vzRsAnyToProv.attributes.state }}
### State Quality: {{ provider.vzRsAnyToProv.attributes.stateQual }}
### Status: {{ provider.vzRsAnyToProv.attributes.status }}
### t
#### Cl: {{ provider.vzRsAnyToProv.attributes.tCl }}
#### Context DN: {{ provider.vzRsAnyToProv.attributes.tContextDn }}
#### DN: {{ provider.vzRsAnyToProv.attributes.tDn }}
#### RN: {{ provider.vzRsAnyToProv.attributes.tRn }}
#### Type: {{ provider.vzRsAnyToProv.attributes.tType }}
### Contract Name: {{ provider.vzRsAnyToProv.attributes.tnVzBrCPName }}
### Update Collection: {{ provider.vzRsAnyToProv.attributes.updateCollection }}
{%-          endfor %}
{%- elif "vzRsDenyRule" in api %}
# vzDeny Rules
{%-     for rule in data_to_template['imdata'] %}
## UID: {{ rule.vzRsDenyRule.attributes.uid }}
### Annotation: {{ rule.vzRsDenyRule.attributes.annotation }}
### Child Action: {{ rule.vzRsDenyRule.attributes.childAction }}
### Directives: {{ rule.vzRsDenyRule.attributes.directives }}
### DN: {{ rule.vzRsDenyRule.attributes.dn }}
### Externally Managed By: {{ rule.vzRsDenyRule.attributes.extMngdBy }}
### Force Resolve: {{ rule.vzRsDenyRule.attributes.forceResolve }}
### Local Owner: {{ rule.vzRsDenyRule.attributes.lcOwn }}
### Last Modified: {{ rule.vzRsDenyRule.attributes.modTs }}
### Monitoring Policy DN: {{ rule.vzRsDenyRule.attributes.monPolDn }}
### rType: {{ rule.vzRsDenyRule.attributes.rType }}
### State: {{ rule.vzRsDenyRule.attributes.state }}
### State Quality: {{ rule.vzRsDenyRule.attributes.stateQual }}
### Status: {{ rule.vzRsDenyRule.attributes.status }}
### t
#### Cl: {{ rule.vzRsDenyRule.attributes.tCl }}
#### Context DN: {{ rule.vzRsDenyRule.attributes.tContextDn }}
#### DN: {{ rule.vzRsDenyRule.attributes.tDn }}
#### RN: {{ rule.vzRsDenyRule.attributes.tRn }}
#### Type: {{ rule.vzRsDenyRule.attributes.tType }}
### tnVz Filter Name: {{ rule.vzRsDenyRule.attributes.tnVzFilterName }}
{%-          endfor %}
{%- elif "vzRsIf" in api %}
# vzInterface Source Relationships
{%-     for interface in data_to_template['imdata'] %}
## UID: {{ interface.vzRsIf.attributes.uid }}
### Annotation: {{ interface.vzRsIf.attributes.annotation }}
### Child Action: {{ interface.vzRsIf.attributes.childAction }}
### DN: {{ interface.vzRsIf.attributes.dn }}
### Externally Managed By: {{ interface.vzRsIf.attributes.extMngdBy }}
### Force Resolve: {{ interface.vzRsIf.attributes.forceResolve }}
### Intent: {{ interface.vzRsIf.attributes.intent }}
### Local Owner: {{ interface.vzRsIf.attributes.lcOwn }}
### Last Modified: {{ interface.vzRsIf.attributes.modTs }}
### Monitoring Policy DN: {{ interface.vzRsIf.attributes.monPolDn }}
### Priority: {{ interface.vzRsIf.attributes.prio }}
### rType: {{ interface.vzRsIf.attributes.rType }}
### State: {{ interface.vzRsIf.attributes.state }}
### State Quality: {{ interface.vzRsIf.attributes.stateQual }}
### Status: {{ interface.vzRsIf.attributes.status }}
### t
#### Cl: {{ interface.vzRsIf.attributes.tCl }}
#### DN: {{ interface.vzRsIf.attributes.tDn }}
#### Type: {{ interface.vzRsIf.attributes.tType }}
### Update Collection: {{ interface.vzRsIf.attributes.updateCollection }}
{%-          endfor %}
{%- elif "vzRsSubjFiltAtt" in api %}
# Contract Subjects Filter Attributes
{%-     for subject_filter in data_to_template['imdata'] %}
## UID: {{ subject_filter.vzRsSubjFiltAtt.attributes.uid }}
### Action: {{ subject_filter.vzRsSubjFiltAtt.attributes.action }}
### Annotation: {{ subject_filter.vzRsSubjFiltAtt.attributes.annotation }}
### Child Action: {{ subject_filter.vzRsSubjFiltAtt.attributes.childAction }}
### Directives: {{ subject_filter.vzRsSubjFiltAtt.attributes.directives }}
### DN: {{ subject_filter.vzRsSubjFiltAtt.attributes.dn }}
### Externally Managed By: {{ subject_filter.vzRsSubjFiltAtt.attributes.extMngdBy }}
### Force Resolve: {{ subject_filter.vzRsSubjFiltAtt.attributes.forceResolve }}
### Local Owner: {{ subject_filter.vzRsSubjFiltAtt.attributes.lcOwn }}
### Last Modified: {{ subject_filter.vzRsSubjFiltAtt.attributes.modTs }}
### Monitoring Policy DN: {{ subject_filter.vzRsSubjFiltAtt.attributes.monPolDn }}
### Priority Override: {{ subject_filter.vzRsSubjFiltAtt.attributes.priorityOverride }}
### rType: {{ subject_filter.vzRsSubjFiltAtt.attributes.rType }}
### State: {{ subject_filter.vzRsSubjFiltAtt.attributes.state }}
### State Quality: {{ subject_filter.vzRsSubjFiltAtt.attributes.stateQual }}
### Status: {{ subject_filter.vzRsSubjFiltAtt.attributes.status }}
### t
#### Cl: {{ subject_filter.vzRsSubjFiltAtt.attributes.tCl }}
#### Context DN: {{ subject_filter.vzRsSubjFiltAtt.attributes.tContextDn }}
#### DN: {{ subject_filter.vzRsSubjFiltAtt.attributes.tDn }}
#### RN: {{ subject_filter.vzRsSubjFiltAtt.attributes.tRn }}
#### Type: {{ subject_filter.vzRsSubjFiltAtt.attributes.tType }}
### tnVz Filter Name: {{ subject_filter.vzRsSubjFiltAtt.attributes.tnVzFilterName }}
{%-          endfor %}
{%- elif "vzRtCons" in api %}
# Contract Consumers Root
{%-     for consumer in data_to_template['imdata'] %}
## DN: {{ consumer.vzRtCons.attributes.dn }}
### Child Action: {{ consumer.vzRtCons.attributes.childAction }}
### Local Owner: {{ consumer.vzRtCons.attributes.lcOwn }}
### Last Modified: {{ consumer.vzRtCons.attributes.modTs }}
### Status: {{ consumer.vzRtCons.attributes.status }}
### t
#### Cl: {{ consumer.vzRtCons.attributes.tCl }}
#### DN: {{ consumer.vzRtCons.attributes.tDn }}
{%-          endfor %}
{%- elif "vzRtProv" in api %}
# Contract Providers Root
{%-     for provider in data_to_template['imdata'] %}
## DN: {{ provider.vzRtProv.attributes.dn }}
### Child Action: {{ provider.vzRtProv.attributes.childAction }}
### Local Owner: {{ provider.vzRtProv.attributes.lcOwn }}
### Last Modified: {{ provider.vzRtProv.attributes.modTs }}
### Status: {{ provider.vzRtProv.attributes.status }}
### t
#### Cl: {{ provider.vzRtProv.attributes.tCl }}
#### DN: {{ provider.vzRtProv.attributes.tDn }}
{%-          endfor %}
{%- elif "vzRuleOwner" in api %}
# vzRule Owner
{%-     for owner in data_to_template['imdata'] %}
## Name: {{ owner.vzRuleOwner.attributes.name }}
### Name Alias: {{ owner.vzRuleOwner.attributes.nameAlias }}
### Action: {{ owner.vzRuleOwner.attributes.action }}
### Child Action: {{ owner.vzRuleOwner.attributes.childAction }}
### Creator DN: {{ owner.vzRuleOwner.attributes.creatorDn }}
### Contract Name: {{ owner.vzRuleOwner.attributes.ctrctName }}
### Direction: {{ owner.vzRuleOwner.attributes.direction }}
### DN: {{ owner.vzRuleOwner.attributes.dn }}
### Intent: {{ owner.vzRuleOwner.attributes.intent }}
### Local Owner: {{ owner.vzRuleOwner.attributes.lcOwn }}
### Mark DSCP: {{ owner.vzRuleOwner.attributes.markDscp }}
### Last Modified: {{ owner.vzRuleOwner.attributes.modTs }}
### Monitor DN: {{ owner.vzRuleOwner.attributes.monitorDn }}
### Priority: {{ owner.vzRuleOwner.attributes.prio }}
### QoS Group: {{ owner.vzRuleOwner.attributes.qosGrp }}
### Status: {{ owner.vzRuleOwner.attributes.status }}
### Tag: {{ owner.vzRuleOwner.attributes.tag }}
### Type: {{ owner.vzRuleOwner.attributes.type }}
{%-          endfor %}
{%- endif %}